@@ -78,19 +78,36 @@ gint comment_write(const gchar *path, GList *keywords, const gchar *comment)
 
 gint comment_cache_write(const gchar *path, GList *keywords, const gchar *comment)
 {
-	gchar *comment_dir;
+	gchar *comment_path;
 	gint success = FALSE;
-	mode_t mode = 0755;
 
-	comment_dir = cache_get_location(CACHE_TYPE_METADATA, path, FALSE, &mode);
-
-	if (cache_ensure_dir_exists(comment_dir, mode))
+	/* If an existing metadata file exists, we will try writing to
+	 * it's location regardless of the user's preference.
+	 */
+	comment_path = cache_find_location(CACHE_TYPE_METADATA, path);
+	if (comment_path && !access_file(comment_path, W_OK))
 		{
-		gchar *comment_path;
-		gchar *comment_pathl;
+		g_free(comment_path);
+		comment_path = NULL;
+		}
 
-		comment_path = g_strconcat(comment_dir, "/", filename_from_path(path),
-					   GQVIEW_CACHE_EXT_METADATA, NULL);
+	if (!comment_path)
+		{
+		gchar *comment_dir;
+		mode_t mode = 0755;
+
+		comment_dir = cache_get_location(CACHE_TYPE_METADATA, path, FALSE, &mode);
+		if (cache_ensure_dir_exists(comment_dir, mode))
+			{
+			comment_path = g_strconcat(comment_dir, "/", filename_from_path(path),
+						   GQVIEW_CACHE_EXT_METADATA, NULL);
+			}
+		g_free(comment_dir);
+		}
+
+	if (comment_path)
+		{
+		gchar *comment_pathl;
 
 		if (debug) printf("Saving comment: %s\n", comment_path);
 
@@ -102,8 +119,6 @@ gint comment_cache_write(const gchar *path, GList *keywords, const gchar *commen
 		g_free(comment_path);
 		}
 
-	g_free(comment_dir);
-
 	return success;
 }
 
@@ -171,24 +186,19 @@ gint comment_read(const gchar *path, GList **keywords, gchar **comment)
 
 gint comment_cache_read(const gchar *path, GList **keywords, gchar **comment)
 {
-	gchar *comment_dir;
 	gchar *comment_path;
 	gchar *comment_pathl;
 	gint success = FALSE;
-	mode_t mode = 0755;
 
-	comment_dir = cache_get_location(CACHE_TYPE_METADATA, path, FALSE, &mode);
-	if (!comment_dir) return FALSE;
+	comment_path = cache_find_location(CACHE_TYPE_METADATA, path);
+	if (!comment_path) return FALSE;
 
-	comment_path = g_strconcat(comment_dir, "/", filename_from_path(path),
-				   GQVIEW_CACHE_EXT_METADATA, NULL);
 	comment_pathl = path_from_utf8(comment_path);
 
 	success = comment_read(comment_pathl, keywords, comment);
 
 	g_free(comment_pathl);
 	g_free(comment_path);
-	g_free(comment_dir);
 
 	return success;
 }
@@ -492,11 +502,12 @@ static void keyword_dialog_show(void)
 
 	keyword_dialog = g_new0(KeywordDlg, 1);
 
-	keyword_dialog->gd = generic_dialog_new(_("Keyword Presets"), _("Favorite keywords list."),
+	keyword_dialog->gd = generic_dialog_new(_("Keyword Presets"),
 						"GQview", "keyword_presets", NULL, TRUE,
 						keyword_dialog_cancel_cb, keyword_dialog);
+	generic_dialog_add_message(keyword_dialog->gd, NULL, _("Favorite keywords list"), NULL);
 
-	generic_dialog_add_stock(keyword_dialog->gd, NULL, GTK_STOCK_OK,
+	generic_dialog_add_button(keyword_dialog->gd, GTK_STOCK_OK, NULL,
 				 keyword_dialog_ok_cb, TRUE);
 
 	scrolled = gtk_scrolled_window_new(NULL, NULL);
@@ -512,6 +523,7 @@ static void keyword_dialog_show(void)
 	g_object_unref(store);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(keyword_dialog->treeview), FALSE);
+	gtk_tree_view_set_search_column(GTK_TREE_VIEW(keyword_dialog->treeview), 0);
 	gtk_tree_view_set_reorderable(GTK_TREE_VIEW(keyword_dialog->treeview), TRUE);
 
 	column = gtk_tree_view_column_new();
@@ -576,7 +588,8 @@ typedef struct _BarInfoData BarInfoData;
 struct _BarInfoData
 {
 	GtkWidget *vbox;
-	GtkWidget *entry_file_name;
+	GtkWidget *group_box;
+	GtkWidget *label_file_name;
 	GtkWidget *label_file_time;
 
 	GtkWidget *keyword_view;
@@ -620,6 +633,30 @@ static void bar_info_write(BarInfoData *bd)
 	gtk_widget_set_sensitive(bd->button_save, FALSE);
 }
 
+static gint bar_info_autosave(gpointer data)
+{
+	BarInfoData *bd = data;
+
+	bar_info_write(bd);
+
+	bd->save_timeout_id = -1;
+
+	return FALSE;
+}
+
+static void bar_info_save_update(BarInfoData *bd, gint enable)
+{
+	if (bd->save_timeout_id != -1)
+		{
+		g_source_remove(bd->save_timeout_id);
+		bd->save_timeout_id = -1;
+		}
+	if (enable)
+		{
+		bd->save_timeout_id = g_timeout_add(BAR_KEYWORD_AUTOSAVE_TIME, bar_info_autosave, bd);
+		}
+}
+
 static gint bar_keyword_list_find(GList *list, const gchar *keyword)
 {
 	while (list)
@@ -697,9 +734,9 @@ static void bar_info_update(BarInfoData *bd)
 	GList *keywords = NULL;
 	gchar *comment = NULL;
 
-	if (bd->entry_file_name)
+	if (bd->label_file_name)
 		{
-		gtk_entry_set_text(GTK_ENTRY(bd->entry_file_name), (bd->path) ? filename_from_path(bd->path) : "");
+		gtk_label_set_text(GTK_LABEL(bd->label_file_name), (bd->path) ? filename_from_path(bd->path) : "");
 		}
 	if (bd->label_file_time)
 		{
@@ -725,10 +762,11 @@ static void bar_info_update(BarInfoData *bd)
 		bar_keyword_list_sync(bd, NULL);
 		}
 
+	bar_info_save_update(bd, FALSE);
 	bd->changed = FALSE;
 	gtk_widget_set_sensitive(bd->button_save, FALSE);
 
-	gtk_widget_set_sensitive(bd->vbox, (bd->path != NULL));
+	gtk_widget_set_sensitive(bd->group_box, (bd->path != NULL));
 }
 
 void bar_info_set(GtkWidget *bar, const gchar *path)
@@ -746,6 +784,22 @@ void bar_info_set(GtkWidget *bar, const gchar *path)
 	bar_info_update(bd);
 }
 
+void bar_info_maint_renamed(GtkWidget *bar, const gchar *path)
+{
+	BarInfoData *bd;
+
+	bd = g_object_get_data(G_OBJECT(bar), "bar_info_data");
+	if (!bd) return;
+
+	g_free(bd->path);
+	bd->path = g_strdup(path);
+
+	if (bd->label_file_name)
+		{
+		gtk_label_set_text(GTK_LABEL(bd->label_file_name), (bd->path) ? filename_from_path(bd->path) : "");
+		}
+}
+
 gint bar_info_event(GtkWidget *bar, GdkEvent *event)
 {
 	BarInfoData *bd;
@@ -822,30 +876,6 @@ static void bar_info_keyword_toggle(GtkCellRendererToggle *toggle, const gchar *
 	g_free(key);
 }
 
-static gint bar_info_autosave(gpointer data)
-{
-	BarInfoData *bd = data;
-
-	bar_info_write(bd);
-
-	bd->save_timeout_id = -1;
-
-	return FALSE;
-}
-
-static void bar_info_save_update(BarInfoData *bd, gint enable)
-{
-	if (bd->save_timeout_id != -1)
-		{
-		g_source_remove(bd->save_timeout_id);
-		bd->save_timeout_id = -1;
-		}
-	if (enable)
-		{
-		bd->save_timeout_id = g_timeout_add(BAR_KEYWORD_AUTOSAVE_TIME, bar_info_autosave, bd);
-		}
-}
-
 static void bar_info_save(GtkWidget *button, gpointer data)
 {
 	BarInfoData *bd = data;
@@ -930,7 +960,7 @@ static void bar_info_destroy(GtkWidget *widget, gpointer data)
 GtkWidget *bar_info_new(const gchar *path, gint metadata_only, GtkWidget *bounding_widget)
 {
 	BarInfoData *bd;
-	GtkWidget *frame;
+	GtkWidget *box;
 	GtkWidget *hbox;
 	GtkWidget *table;
 	GtkWidget *scrolled;
@@ -946,62 +976,65 @@ GtkWidget *bar_info_new(const gchar *path, gint metadata_only, GtkWidget *boundi
 	bd->list_func = NULL;
 	bd->list_data = NULL;
 
-	bd->vbox = gtk_vbox_new(FALSE, 0);
+	bd->vbox = gtk_vbox_new(FALSE, PREF_PAD_GAP);
 	g_object_set_data(G_OBJECT(bd->vbox), "bar_info_data", bd);
 	g_signal_connect(G_OBJECT(bd->vbox), "destroy",
 			 G_CALLBACK(bar_info_destroy), bd);
 
 	if (!metadata_only)
 		{
-		hbox = gtk_hbox_new(FALSE, 2);
-		gtk_box_pack_start(GTK_BOX(bd->vbox), hbox, FALSE, FALSE, 0);
-		gtk_widget_show(hbox);
+		hbox = pref_box_new(bd->vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
 
 		label = sizer_new(bd->vbox, bounding_widget, SIZER_POS_LEFT);
 		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 		gtk_widget_show(label);
 
 		label = gtk_label_new(_("Keywords"));
+		pref_label_bold(label, TRUE, FALSE);
 		gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 		gtk_widget_show(label);
-		
-		bd->entry_file_name = gtk_entry_new();
-		gtk_editable_set_editable(GTK_EDITABLE(bd->entry_file_name), FALSE);
-		gtk_box_pack_start(GTK_BOX(bd->vbox), bd->entry_file_name, FALSE, FALSE, 0);
-		gtk_widget_show(bd->entry_file_name);
+		}
 
-		table = gtk_table_new(2, 8, FALSE);
-		gtk_container_set_border_width(GTK_CONTAINER(table), 5);
-		gtk_box_pack_start(GTK_BOX(bd->vbox), table, FALSE, FALSE, 0);
-		gtk_widget_show(table);
+	bd->group_box = pref_box_new(bd->vbox, TRUE, GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
 
-		bd->label_file_time = table_add_line(table, 0, 0, _("File date:"), NULL);
+	if (!metadata_only)
+		{
+		GtkWidget *table;
+
+		table = pref_table_new(bd->group_box, 2, 2, FALSE, FALSE);
+
+		bd->label_file_name = table_add_line(table, 0, 0, _("Filename:"), NULL);
+		bd->label_file_time = table_add_line(table, 0, 1, _("File date:"), NULL);
 		}
 	else
 		{
-		bd->entry_file_name = NULL;
+		bd->label_file_name = NULL;
 		bd->label_file_time = NULL;
 		}
 
+	table = gtk_table_new(3, 1, TRUE);
+	gtk_table_set_row_spacings(GTK_TABLE(table), PREF_PAD_GAP);
+	gtk_box_pack_start(GTK_BOX(bd->group_box), table, TRUE, TRUE, 0);
+	gtk_widget_show(table);
+
 	/* keyword entry */
 
-	frame = gtk_frame_new(_("Keywords:"));
-	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_NONE);
-	gtk_box_pack_start(GTK_BOX(bd->vbox), frame, TRUE, TRUE, 5);
-	gtk_widget_show(frame);
+	box = gtk_vbox_new(FALSE, 0);
+	gtk_table_attach(GTK_TABLE(table), box, 0, 1, 0, 2,
+			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+	gtk_widget_show(box);
 
-	hbox = gtk_hbox_new(FALSE, 2);
-	gtk_container_add(GTK_CONTAINER(frame), hbox);
-	gtk_widget_show(hbox);
+	label = pref_label_new(box, _("Keywords:"));
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+	pref_label_bold(label, TRUE, FALSE);
+
+	hbox = pref_box_new(box, TRUE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
 
 	scrolled = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
 				       GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_box_pack_start(GTK_BOX(hbox), scrolled, TRUE, TRUE, 0);
-#if 0
-	gtk_container_add(GTK_CONTAINER(frame), scrolled);
-#endif
 	gtk_widget_show(scrolled);
 
 	bd->keyword_view = gtk_text_view_new();
@@ -1025,6 +1058,15 @@ GtkWidget *bar_info_new(const gchar *path, gint metadata_only, GtkWidget *boundi
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(bd->keyword_treeview), FALSE);
 
+	if (metadata_only)
+		{
+		gtk_tree_view_set_search_column(GTK_TREE_VIEW(bd->keyword_treeview), KEYWORD_COLUMN_TEXT);
+		}
+	else
+		{
+		gtk_tree_view_set_enable_search(GTK_TREE_VIEW(bd->keyword_treeview), FALSE);
+		}
+
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 
@@ -1045,16 +1087,20 @@ GtkWidget *bar_info_new(const gchar *path, gint metadata_only, GtkWidget *boundi
 
 	/* comment entry */
 
-	frame = gtk_frame_new(_("Comment:"));
-	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_NONE);
-	gtk_box_pack_start(GTK_BOX(bd->vbox), frame, TRUE, TRUE, 0);
-	gtk_widget_show(frame);
+	box = gtk_vbox_new(FALSE, 0);
+	gtk_table_attach(GTK_TABLE(table), box, 0, 1, 2, 3,
+			 GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+	gtk_widget_show(box);
+
+	label = pref_label_new(box, _("Comment:"));
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+	pref_label_bold(label, TRUE, FALSE);
 
 	scrolled = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
 				       GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_container_add(GTK_CONTAINER(frame), scrolled);
+	gtk_box_pack_start(GTK_BOX(box), scrolled, TRUE, TRUE, 0);
 	gtk_widget_show(scrolled);
 
 	bd->comment_view = gtk_text_view_new();
@@ -1065,59 +1111,30 @@ GtkWidget *bar_info_new(const gchar *path, gint metadata_only, GtkWidget *boundi
 	g_signal_connect(G_OBJECT(buffer), "changed",
 			 G_CALLBACK(bar_info_changed), bd);
 
-#if 0
-	tbar = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(bd->vbox), tbar, FALSE, FALSE, 0);
-	gtk_widget_show(tbar);
+	/* toolbar */
 
-	tooltips = gtk_tooltips_new();
-	g_object_ref(G_OBJECT(tooltips));
-	gtk_object_sink(GTK_OBJECT(tooltips));
+	tbar = pref_toolbar_new(bd->group_box, GTK_TOOLBAR_ICONS);
 
-	bd->button_set_add = layout_button(tbar, NULL, GTK_STOCK_ADD, FALSE,
-				tooltips, _("Add keywords to selected files"),
-				G_CALLBACK(bar_info_set_add), bd);
-	bd->button_set_replace = layout_button(tbar, NULL, GTK_STOCK_CONVERT, FALSE,
-				tooltips, _("Add keywords to selected files, replacing the existing ones."),
-				G_CALLBACK(bar_info_set_replace), bd);
-	label = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(tbar), label, TRUE, TRUE, 0);
-	gtk_widget_show(label);
-	bd->button_save = layout_button(tbar, NULL, GTK_STOCK_SAVE, FALSE,
-				tooltips, _("Save comment now"),
-				G_CALLBACK(bar_info_save), bd);
-
-	/* note this currently leaks the tootips widget */
-#endif
-
-	tbar = gtk_toolbar_new();
-	gtk_toolbar_set_style(GTK_TOOLBAR(tbar), GTK_TOOLBAR_ICONS);
-	gtk_toolbar_set_icon_size(GTK_TOOLBAR(tbar), GTK_ICON_SIZE_MENU);
-	gtk_box_pack_start(GTK_BOX(bd->vbox), tbar, FALSE, FALSE, 0);
-	gtk_widget_show(tbar);
-
-	gtk_toolbar_insert_stock(GTK_TOOLBAR(tbar), GTK_STOCK_INDEX,
-				 _("Edit favorite keywords list."), NULL,
-				 G_CALLBACK(bar_keyword_edit_cb), bd, -1);
-	gtk_toolbar_append_space(GTK_TOOLBAR(tbar));
-	bd->button_set_add = gtk_toolbar_insert_stock(GTK_TOOLBAR(tbar), GTK_STOCK_ADD,
-				_("Add keywords to selected files"), NULL,
-				G_CALLBACK(bar_info_set_add), bd, -1);
-	bd->button_set_replace = gtk_toolbar_insert_stock(GTK_TOOLBAR(tbar), GTK_STOCK_CONVERT,
-				_("Add keywords to selected files, replacing the existing ones."), NULL,
-				G_CALLBACK(bar_info_set_replace), bd, -1);
-	gtk_toolbar_append_space(GTK_TOOLBAR(tbar));
-	bd->button_save = gtk_toolbar_insert_stock(GTK_TOOLBAR(tbar), GTK_STOCK_SAVE,
-				_("Save comment now"), NULL,
-				G_CALLBACK(bar_info_save), bd, -1);
+	pref_toolbar_button(tbar, GTK_STOCK_INDEX, NULL,
+			_("Edit favorite keywords list."),
+			G_CALLBACK(bar_keyword_edit_cb), bd);
+	pref_toolbar_spacer(tbar);
+	bd->button_set_add = pref_toolbar_button(tbar, GTK_STOCK_ADD, NULL,
+			_("Add keywords to selected files"),
+			G_CALLBACK(bar_info_set_add), bd);
+	bd->button_set_replace = pref_toolbar_button(tbar, GTK_STOCK_CONVERT, NULL,
+			_("Add keywords to selected files, replacing the existing ones."),
+			G_CALLBACK(bar_info_set_replace), bd);
+	pref_toolbar_spacer(tbar);
+	bd->button_save = pref_toolbar_button(tbar, GTK_STOCK_SAVE, NULL,
+			_("Save comment now"),
+			G_CALLBACK(bar_info_save), bd);
 
 	bd->save_timeout_id = -1;
 
 	bd->path = g_strdup(path);
 	bar_info_update(bd);
 
-	g_object_set_data(G_OBJECT(bd->vbox), "bar_info_data", bd);
-
 	bar_info_selection(bd->vbox, 0);
 
 	bar_list = g_list_append(bar_list, bd);
@@ -1157,9 +1174,9 @@ void bar_info_size_request(GtkWidget *bar, gint width)
 	bd = g_object_get_data(G_OBJECT(bar), "bar_info_data");
 	if (!bd) return;
 
-	if (bd->entry_file_name)
+	if (bd->label_file_name)
 		{
-		gtk_widget_set_size_request(bd->entry_file_name, width, -1);
+		gtk_widget_set_size_request(bd->vbox, width, -1);
 		}
 }
 
