@@ -149,7 +149,11 @@ gint cache_sim_data_save(CacheData *cd)
 	f = fopen(pathl, "w");
 	g_free(pathl);
 
-	if (!f) return FALSE;
+	if (!f)
+		{
+		printf("Unable to save sim cache data: %s\n", cd->path);
+		return FALSE;
+		}
 
 	fprintf(f, "SIMcache\n#%s %s\n", PACKAGE, VERSION);
 	cache_sim_write_dimensions(f, cd);
@@ -573,7 +577,8 @@ gchar *cache_get_location(CacheType type, const gchar *source, gint include_name
 		cache_ext = NULL;
 		}
 
-	if (enable_thumb_dirs &&
+	if (((type != CACHE_TYPE_METADATA && enable_thumb_dirs) ||
+	     (type == CACHE_TYPE_METADATA && enable_metadata_dirs)) &&
 	    access_file(base, W_OK))
 		{
 		path = g_strconcat(base, "/", cache_local, name, cache_ext, NULL);
@@ -600,6 +605,7 @@ gchar *cache_find_location(CacheType type, const gchar *source)
 	const gchar *cache_rc;
 	const gchar *cache_local;
 	const gchar *cache_ext;
+	gint prefer_local;
 
 	if (!source) return NULL;
 
@@ -608,7 +614,16 @@ gchar *cache_find_location(CacheType type, const gchar *source)
 	name = filename_from_path(source);
 	base = remove_level_from_path(source);
 
-	if (enable_thumb_dirs)
+	if (type == CACHE_TYPE_METADATA)
+		{
+		prefer_local = enable_metadata_dirs;
+		}
+	else
+		{
+		prefer_local = enable_thumb_dirs;
+		}
+
+	if (prefer_local)
 		{
 		path = g_strconcat(base, "/", cache_local, "/", name, cache_ext, NULL);
 		}
@@ -622,7 +637,7 @@ gchar *cache_find_location(CacheType type, const gchar *source)
 		g_free(path);
 
 		/* try the opposite method if not found */
-		if (!enable_thumb_dirs)
+		if (!prefer_local)
 			{
 			path = g_strconcat(base, "/", cache_local, "/", name, cache_ext, NULL);
 			}
@@ -630,12 +645,12 @@ gchar *cache_find_location(CacheType type, const gchar *source)
 			{
 			path = g_strconcat(homedir(), "/", cache_rc, source, cache_ext, NULL);
 			}
-		}
 
-	if (!isfile(path))
-		{
-		g_free(path);
-		path = NULL;
+		if (!isfile(path))
+			{
+			g_free(path);
+			path = NULL;
+			}
 		}
 
 	g_free(base);
