@@ -25,6 +25,7 @@
 #include "layout.h"
 #include "layout_image.h"
 #include "menu.h"
+#include "print.h"
 #include "utilops.h"
 #include "ui_bookmark.h"
 #include "ui_fileops.h"
@@ -176,7 +177,7 @@ static void collection_table_update_status(CollectTable *ct)
 		}
 }
 
-static void collection_table_update_extras(CollectTable *ct, gint loading, gfloat value)
+static void collection_table_update_extras(CollectTable *ct, gint loading, gdouble value)
 {
 	if (ct->extra_label)
 		{
@@ -417,22 +418,12 @@ static void collection_table_select_region_util(CollectTable *ct, CollectInfo *s
 
 GList *collection_table_selection_get_list(CollectTable *ct)
 {
-	GList *list = NULL;
-	GList *work;
+	return collection_list_to_path_list(ct->selection);
+}
 
-	work = ct->selection;
-	while(work)
-		{
-		CollectInfo *info = work->data;
-
-		list = g_list_prepend(list, g_strdup(info->path));
-
-		work = work->next;
-		}
-
-	list = g_list_reverse(list);
-
-	return list;
+static GList *collection_table_get_list(CollectTable *ct)
+{
+	return collection_list_to_path_list(ct->cd->list);
 }
 
 /*
@@ -466,7 +457,7 @@ static void tip_show(CollectTable *ct)
 	gdk_window_get_pointer(NULL, &x, &y, NULL);
 
 	if (!GTK_WIDGET_REALIZED(ct->tip_window)) gtk_widget_realize(ct->tip_window);
-	gdk_window_move(ct->tip_window->window, x + 16, y + 16);
+	gtk_window_move(GTK_WINDOW(ct->tip_window), x + 16, y + 16);
 	gtk_widget_show(ct->tip_window);
 }
 
@@ -519,7 +510,7 @@ static void tip_update(CollectTable *ct, CollectInfo *info)
 		gint x, y;
 
 		gdk_window_get_pointer(NULL, &x, &y, NULL);
-		gdk_window_move(ct->tip_window->window, x + 16, y + 16);
+		gtk_window_move(GTK_WINDOW(ct->tip_window), x + 16, y + 16);
 
 		if (info != ct->tip_info)
 			{
@@ -739,6 +730,16 @@ static void collection_table_popup_find_dupes_cb(GtkWidget *widget, gpointer dat
 	dupe_window_add_collection(dw, ct->cd);
 }
 
+static void collection_table_popup_print_cb(GtkWidget *widget, gpointer data)
+{
+	CollectTable *ct = data;
+	const gchar *path;
+
+	path = (ct->click_info) ? ct->click_info->path : NULL;
+
+	print_window_new(path, collection_table_selection_get_list(ct), collection_table_get_list(ct), ct->listview);
+}
+
 static void collection_table_popup_show_names_cb(GtkWidget *widget, gpointer data)
 {
 	CollectTable *ct = data;
@@ -762,60 +763,62 @@ static void collection_table_popup_destroy_cb(GtkWidget *widget, gpointer data)
 static GtkWidget *collection_table_popup_menu(CollectTable *ct, gint over_icon)
 {
 	GtkWidget *menu;
+	GtkWidget *item;
 
 	menu = popup_menu_short_lived();
 
 	g_signal_connect(G_OBJECT(menu), "destroy",
 			 G_CALLBACK(collection_table_popup_destroy_cb), ct);
 
-	if (over_icon)
-		{
-		menu_item_add(menu, _("_View"),
-			      G_CALLBACK(collection_table_popup_view_cb), ct);
-		menu_item_add_stock(menu, _("View in _new window"), GTK_STOCK_NEW,
-			      G_CALLBACK(collection_table_popup_view_new_cb), ct);
-		menu_item_add_divider(menu);
-		menu_item_add_stock(menu, _("Rem_ove"), GTK_STOCK_REMOVE,
-			      G_CALLBACK(collection_table_popup_remove_cb), ct);
-		}
+	menu_item_add_sensitive(menu, _("_View"), over_icon,
+			G_CALLBACK(collection_table_popup_view_cb), ct);
+	menu_item_add_stock_sensitive(menu, _("View in _new window"), GTK_STOCK_NEW, over_icon,
+			G_CALLBACK(collection_table_popup_view_new_cb), ct);
+	menu_item_add_divider(menu);
+	menu_item_add_stock_sensitive(menu, _("Rem_ove"), GTK_STOCK_REMOVE, over_icon,
+			G_CALLBACK(collection_table_popup_remove_cb), ct);
+
 	menu_item_add_stock(menu, _("Append from file list"), GTK_STOCK_ADD,
-		      G_CALLBACK(collection_table_popup_add_filelist_cb), ct);
+			G_CALLBACK(collection_table_popup_add_filelist_cb), ct);
 	menu_item_add_stock(menu, _("Append from collection..."), GTK_STOCK_OPEN,
-		      G_CALLBACK(collection_table_popup_add_collection_cb), ct);
+			G_CALLBACK(collection_table_popup_add_collection_cb), ct);
 	menu_item_add_divider(menu);
 	menu_item_add(menu, _("Select all"),
-		      G_CALLBACK(collection_table_popup_selectall_cb), ct);
+			G_CALLBACK(collection_table_popup_selectall_cb), ct);
 	menu_item_add(menu, _("Select none"),
-		      G_CALLBACK(collection_table_popup_unselectall_cb), ct);
+			G_CALLBACK(collection_table_popup_unselectall_cb), ct);
 	menu_item_add_divider(menu);
-	if (over_icon)
-		{
-		submenu_add_edit(menu, NULL,
-				 G_CALLBACK(collection_table_popup_edit_cb), ct);
-		menu_item_add(menu, _("_Properties"),
-			      G_CALLBACK(collection_table_popup_info_cb), ct);
-		menu_item_add_divider(menu);
-		menu_item_add_stock(menu, _("_Copy..."), GTK_STOCK_COPY,
-			      G_CALLBACK(collection_table_popup_copy_cb), ct);
-		menu_item_add(menu, _("_Move..."),
-			      G_CALLBACK(collection_table_popup_move_cb), ct);
-		menu_item_add(menu, _("_Rename..."),
-			      G_CALLBACK(collection_table_popup_rename_cb), ct);
-		menu_item_add_stock(menu, _("_Delete..."), GTK_STOCK_DELETE,
-			      G_CALLBACK(collection_table_popup_delete_cb), ct);
-		menu_item_add_divider(menu);
-		}
+
+	submenu_add_edit(menu, &item,
+			G_CALLBACK(collection_table_popup_edit_cb), ct);
+	gtk_widget_set_sensitive(item, over_icon);
+
+	menu_item_add_sensitive(menu, _("_Properties"), over_icon,
+			G_CALLBACK(collection_table_popup_info_cb), ct);
+	menu_item_add_divider(menu);
+	menu_item_add_stock_sensitive(menu, _("_Copy..."), GTK_STOCK_COPY, over_icon,
+			G_CALLBACK(collection_table_popup_copy_cb), ct);
+	menu_item_add_sensitive(menu, _("_Move..."), over_icon,
+			G_CALLBACK(collection_table_popup_move_cb), ct);
+	menu_item_add_sensitive(menu, _("_Rename..."), over_icon,
+			G_CALLBACK(collection_table_popup_rename_cb), ct);
+	menu_item_add_stock_sensitive(menu, _("_Delete..."), GTK_STOCK_DELETE, over_icon,
+			G_CALLBACK(collection_table_popup_delete_cb), ct);
+	menu_item_add_divider(menu);
+
 	submenu_add_sort(menu, G_CALLBACK(collection_table_popup_sort_cb), ct, FALSE, TRUE, FALSE, 0);
 	menu_item_add_check(menu, _("Show filename _text"), ct->show_text,
-			    G_CALLBACK(collection_table_popup_show_names_cb), ct);
+			G_CALLBACK(collection_table_popup_show_names_cb), ct);
 	menu_item_add_divider(menu);
 	menu_item_add_stock(menu, _("_Save collection"), GTK_STOCK_SAVE,
-		      G_CALLBACK(collection_table_popup_save_cb), ct);
+			G_CALLBACK(collection_table_popup_save_cb), ct);
 	menu_item_add_stock(menu, _("Save collection _as..."), GTK_STOCK_SAVE_AS,
-		      G_CALLBACK(collection_table_popup_save_as_cb), ct);
+			G_CALLBACK(collection_table_popup_save_as_cb), ct);
 	menu_item_add_divider(menu);
 	menu_item_add_stock(menu, _("_Find duplicates..."), GTK_STOCK_FIND,
-		      G_CALLBACK(collection_table_popup_find_dupes_cb), ct);
+			G_CALLBACK(collection_table_popup_find_dupes_cb), ct);
+	menu_item_add_stock_sensitive(menu, _("Print..."), GTK_STOCK_PRINT, over_icon,
+			G_CALLBACK(collection_table_popup_print_cb), ct);		
 
 	return menu;
 }
@@ -1381,7 +1384,7 @@ static gint collection_table_auto_scroll_notify_cb(GtkWidget *widget, gint x, gi
 {
 	CollectTable *ct = data;
 
-	if (ct->drop_idle_id == -1) ct->drop_idle_id = gtk_idle_add(collection_table_auto_scroll_idle_cb, ct);
+	if (ct->drop_idle_id == -1) ct->drop_idle_id = g_idle_add(collection_table_auto_scroll_idle_cb, ct);
 
 	return TRUE;
 }
@@ -1839,7 +1842,7 @@ void collection_table_file_update(CollectTable *ct, CollectInfo *info)
 {
 	GtkTreeIter iter;
 	gint row, col;
-	gfloat value;
+	gdouble value;
 
 	if (!info)
 		{
@@ -1851,7 +1854,7 @@ void collection_table_file_update(CollectTable *ct, CollectInfo *info)
 
 	if (ct->columns != 0 && ct->rows != 0)
 		{
-		value = (float)(row * ct->columns + col) / (ct->columns * ct->rows);
+		value = (gdouble)(row * ct->columns + col) / (ct->columns * ct->rows);
 		}
 	else
 		{
@@ -2394,6 +2397,7 @@ CollectTable *collection_table_new(CollectionData *cd)
 	gtk_tree_selection_set_mode(GTK_TREE_SELECTION(selection), GTK_SELECTION_NONE);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(ct->listview), FALSE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(ct->listview), FALSE);
 
 	for (i = 0; i < COLLECT_TABLE_MAX_COLUMNS; i++)
 		{
