@@ -22,7 +22,6 @@
 #include "info.h"
 #include "layout.h"
 #include "layout_image.h"
-#include "thumb.h"
 #include "utilops.h"
 #include "ui_fileops.h"
 #include "ui_tree_edit.h"
@@ -257,12 +256,28 @@ static gint collection_list_find_index(GList *list, gchar *path)
 }
 #endif
 
+GList *collection_list_to_path_list(GList *list)
+{
+	GList *pathlist = NULL;
+	GList *work = list;
+
+	while (work)
+		{
+		CollectInfo *info = work->data;
+		pathlist = g_list_prepend(pathlist, g_strdup(info->path));
+		work = work->next;
+		}
+
+	pathlist = g_list_reverse(pathlist);
+	return pathlist;
+}
+
 CollectWindow *collection_window_find(CollectionData *cd)
 {
 	GList *work;
 
 	work = collection_window_list;
-	while(work)
+	while (work)
 		{
 		CollectWindow *cw = work->data;
 		if (cw->cd == cd) return cw;
@@ -272,6 +287,23 @@ CollectWindow *collection_window_find(CollectionData *cd)
 	return NULL;
 }
 
+CollectWindow *collection_window_find_by_path(const gchar *path)
+{
+	GList *work;
+
+	if (!path) return NULL;
+
+	work = collection_window_list;
+	while (work)
+		{
+		CollectWindow *cw = work->data;
+		if (cw->cd->path && strcmp(cw->cd->path, path) == 0) return cw;
+		work = work->next;
+		}
+
+	return NULL;
+}
+
 /*
  *-------------------------------------------------------------------
  * please use these to actually add/remove stuff
@@ -555,11 +587,23 @@ void collection_set_update_info_func(CollectionData *cd,
 	cd->info_updated_data = data;
 }
 
-gint collection_add(CollectionData *cd, const gchar *path, gint sorted)
+gint collection_add_check(CollectionData *cd, const gchar *path, gint sorted, gint must_exist)
 {
 	struct stat st;
+	gint valid;
 
-	if (stat_utf8(path, &st) && !S_ISDIR(st.st_mode))
+	if (must_exist)
+		{
+		valid = (stat_utf8(path, &st) && !S_ISDIR(st.st_mode));
+		}
+	else
+		{
+		valid = TRUE;
+		st.st_size = 0;
+		st.st_mtime = 0;
+		}
+
+	if (valid)
 		{
 		CollectInfo *ci;
 		ci = collection_info_new(path, &st, NULL);
@@ -574,11 +618,14 @@ gint collection_add(CollectionData *cd, const gchar *path, gint sorted)
 			{
 			collection_window_insert(collection_window_find(cd), ci);
 			}
-
-		return TRUE;
 		}
 
-	return FALSE;
+	return valid;
+}
+
+gint collection_add(CollectionData *cd, const gchar *path, gint sorted)
+{
+	return collection_add_check(cd, path, sorted, TRUE);
 }
 
 gint collection_insert(CollectionData *cd, const gchar *path, CollectInfo *insert_ci, gint sorted)
@@ -611,7 +658,7 @@ gint collection_remove(CollectionData *cd, const gchar *path)
 	if (!ci) return FALSE;
 
 	cd->list = g_list_remove(cd->list, ci);
-	cd->changed = (cd->list != NULL);
+	cd->changed = TRUE;
 
 	collection_window_remove(collection_window_find(cd), ci);
 	collection_info_free(ci);
@@ -654,7 +701,7 @@ void collection_remove_by_info_list(CollectionData *cd, GList *list)
 	collection_window_refresh(collection_window_find(cd));
 }
 
-static gint collection_rename(CollectionData *cd, const gchar *source, const gchar *dest)
+gint collection_rename(CollectionData *cd, const gchar *source, const gchar *dest)
 {
 	CollectInfo *ci;
 
@@ -694,6 +741,12 @@ void collection_maint_removed(const gchar *path)
 
 		while(collection_remove(cd, path));
 		}
+#if 0
+	/* Do we really need to do this? removed files are
+	 * automatically ignored when loading a collection.
+	 */
+	collect_manager_moved(path, NULL);
+#endif
 }
 
 void collection_maint_renamed(const gchar *source, const gchar *dest)
@@ -708,6 +761,8 @@ void collection_maint_renamed(const gchar *source, const gchar *dest)
 
 		while(collection_rename(cd, source, dest));
 		}
+
+	collect_manager_moved(source, dest);
 }
 
 /*
@@ -1004,7 +1059,7 @@ static void collection_close_save_cb(GenericDialog *gd, gpointer data)
 		{
 		gchar *buf;
 		buf = g_strdup_printf(_("Failed to save the collection:\n%s"), cw->cd->path);
-		warning_dialog(_("Save Failed"), buf, cw->window);
+		warning_dialog(_("Save Failed"), buf, GTK_STOCK_DIALOG_ERROR, cw->window);
 		g_free(buf);
 		return;
 		}
@@ -1036,16 +1091,19 @@ static void collection_close_dlg_show(CollectWindow *cw)
 
 	if (cw->close_dialog)
 		{
-		gdk_window_raise(cw->close_dialog->window);
+		gtk_window_present(GTK_WINDOW(cw->close_dialog));
 		return;
 		}
 
-	gd = generic_dialog_new(_("Close collection"), _("Collection has been modified.\nSave first?"),
+	gd = generic_dialog_new(_("Close collection"),
 				"GQview", "close_collection", cw->window, FALSE,
 				collection_close_cancel_cb, cw);
+	generic_dialog_add_message(gd, GTK_STOCK_DIALOG_QUESTION,
+				   _("Close collection"),
+				   _("Collection has been modified.\nSave first?"));
 
-	generic_dialog_add_stock(gd, _("Save"), GTK_STOCK_SAVE, collection_close_save_cb, TRUE);
-	generic_dialog_add_stock(gd, _("Close"), GTK_STOCK_CLOSE, collection_close_close_cb, FALSE);
+	generic_dialog_add_button(gd, GTK_STOCK_SAVE, NULL, collection_close_save_cb, TRUE);
+	generic_dialog_add_button(gd, GTK_STOCK_DELETE, _("_Discard"), collection_close_close_cb, FALSE);
 
 	cw->close_dialog = gd->dialog;
 
