@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2004 John Ellis
+ * (C) 2005 John Ellis
  *
  * Author: John Ellis
  *
@@ -26,11 +26,13 @@
 #include "layout_image.h"
 #include "md5-util.h"
 #include "menu.h"
+#include "print.h"
 #include "thumb.h"
 #include "utilops.h"
 #include "ui_bookmark.h"
 #include "ui_fileops.h"
 #include "ui_menu.h"
+#include "ui_misc.h"
 #include "ui_tree_edit.h"
 
 #include <gdk/gdkkeysyms.h> /* for keyboard values */
@@ -67,7 +69,7 @@ static GList *dupe_window_list = NULL;	/* list of open DupeWindow *s */
 static void dupe_match_unlink(DupeItem *a, DupeItem *b);
 static DupeItem *dupe_match_find_parent(DupeWindow *dw, DupeItem *child);
 
-static gint dupe_match(DupeItem *a, DupeItem *b, DupeMatchType mask, gfloat *rank, gint fast);
+static gint dupe_match(DupeItem *a, DupeItem *b, DupeMatchType mask, gdouble *rank, gint fast);
 
 static void dupe_thumb_step(DupeWindow *dw);
 static gint dupe_check_cb(gpointer data);
@@ -127,7 +129,7 @@ static gint dupe_iterations(gint n)
 	return (n * ((n + 1) / 2));
 }
 
-static void dupe_window_update_progress(DupeWindow *dw, const gchar *status, gfloat value, gint force)
+static void dupe_window_update_progress(DupeWindow *dw, const gchar *status, gdouble value, gint force)
 {
 	const gchar *status_text;
 
@@ -172,7 +174,7 @@ static void dupe_window_update_progress(DupeWindow *dw, const gchar *status, gfl
 				d = dw->setup_count - dw->setup_n;
 				}
 
-			rem = (t - d) ? ((float)(dw->setup_time_count / 1000000) / (t - d)) * d : 0;
+			rem = (t - d) ? ((gdouble)(dw->setup_time_count / 1000000) / (t - d)) * d : 0;
 
 			gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(dw->extra_label), value);
 
@@ -185,8 +187,10 @@ static void dupe_window_update_progress(DupeWindow *dw, const gchar *status, gfl
 		else if (force ||
 			 value == 0.0 ||
 			 dw->setup_count == 0 ||
+			 dw->setup_time_count == 0 ||
 			 (new_time > 0 && new_time - dw->setup_time_count >= 250000))
 			{
+			if (dw->setup_time_count == 0) dw->setup_time_count = 1;
 			if (new_time > 0) dw->setup_time_count = new_time;
 			gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(dw->extra_label), value);
 			status_text = status;
@@ -604,6 +608,29 @@ static void dupe_listview_remove(DupeWindow *dw, DupeItem *di)
 		}
 }
 
+
+static GList *dupe_listview_get_path_list(DupeWindow *dw, GtkWidget *listview)
+{
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+	gint valid;
+	GList *list = NULL;
+
+	store = gtk_tree_view_get_model(GTK_TREE_VIEW(listview));
+	valid = gtk_tree_model_get_iter_first(store, &iter);
+	while (valid)
+		{
+		DupeItem *di;
+		gtk_tree_model_get(store, &iter, DUPE_COLUMN_POINTER, &di, -1);
+		list = g_list_prepend(list, g_strdup(di->path));
+
+		valid = gtk_tree_model_iter_next(store, &iter);
+		}
+
+	return g_list_reverse(list);
+}
+
+
 static GList *dupe_listview_get_selection(DupeWindow *dw, GtkWidget *listview)
 {
 	GtkTreeModel *store;
@@ -708,7 +735,7 @@ static DupeMatch *dupe_match_find_match(DupeItem *child, DupeItem *parent)
 	return NULL;
 }
 
-static void dupe_match_link_child(DupeItem *child, DupeItem *parent, gfloat rank)
+static void dupe_match_link_child(DupeItem *child, DupeItem *parent, gdouble rank)
 {
 	DupeMatch *dm;
 
@@ -718,7 +745,7 @@ static void dupe_match_link_child(DupeItem *child, DupeItem *parent, gfloat rank
 	parent->group = g_list_append(parent->group, dm);
 }
 
-static void dupe_match_link(DupeItem *a, DupeItem *b, gfloat rank)
+static void dupe_match_link(DupeItem *a, DupeItem *b, gdouble rank)
 {
 	dupe_match_link_child(a, b, rank);
 	dupe_match_link_child(b, a, rank);
@@ -767,7 +794,7 @@ static gint dupe_match_link_exists(DupeItem *child, DupeItem *parent)
 	return (dupe_match_find_match(child, parent) != NULL);
 }
 
-static gfloat dupe_match_link_rank(DupeItem *child, DupeItem *parent)
+static gdouble dupe_match_link_rank(DupeItem *child, DupeItem *parent)
 {
 	DupeMatch *dm;
 
@@ -797,7 +824,7 @@ static DupeItem *dupe_match_highest_rank(DupeItem *child)
 static void dupe_match_rank_update(DupeItem *parent)
 {
 	GList *work;
-	gfloat rank = 0.0;
+	gdouble rank = 0.0;
 	gint c = 0;
 
 	work = parent->group;
@@ -910,7 +937,7 @@ static GList *dupe_match_unlink_by_rank(DupeItem *child, DupeItem *parent, GList
 	if (best == child || dupe_match_highest_rank(child) == parent)
 		{
 		GList *work;
-		gfloat rank;
+		gdouble rank;
 
 		if (debug > 1) printf("link found %s to %s [%d]\n", child->name, parent->name, g_list_length(parent->group));
 
@@ -1066,7 +1093,7 @@ static void dupe_match_rank(DupeWindow *dw)
  * ------------------------------------------------------------------
  */
 
-static gint dupe_match(DupeItem *a, DupeItem *b, DupeMatchType mask, gfloat *rank, gint fast)
+static gint dupe_match(DupeItem *a, DupeItem *b, DupeMatchType mask, gdouble *rank, gint fast)
 {
 	*rank = 0.0;
 
@@ -1107,12 +1134,12 @@ static gint dupe_match(DupeItem *a, DupeItem *b, DupeMatchType mask, gfloat *ran
 	    mask & DUPE_MATCH_SIM_LOW ||
 	    mask & DUPE_MATCH_SIM_CUSTOM)
 		{
-		gfloat f;
-		gfloat m;
+		gdouble f;
+		gdouble m;
 
 		if (mask & DUPE_MATCH_SIM_HIGH) m = 0.95;
 		else if (mask & DUPE_MATCH_SIM_MED) m = 0.90;
-		else if (mask & DUPE_MATCH_SIM_CUSTOM) m = (float)dupe_custom_threshold / 100.0;
+		else if (mask & DUPE_MATCH_SIM_CUSTOM) m = (gdouble)dupe_custom_threshold / 100.0;
 		else m = 0.85;
 
 		if (fast)
@@ -1163,7 +1190,7 @@ static void dupe_list_check_match(DupeWindow *dw, DupeItem *needle, GList *start
 
 		if (!dupe_match_link_exists(needle, di))
 			{
-			gfloat rank;
+			gdouble rank;
 
 			if (dupe_match(di, needle, dw->match_mask, &rank, TRUE))
 				{
@@ -1267,17 +1294,20 @@ static void dupe_thumb_step(DupeWindow *dw)
 		}
 
 	dupe_window_update_progress(dw, _("Loading thumbs..."),
-				    length == 0 ? 0.0 : (float)(row) / length, FALSE);
+				    length == 0 ? 0.0 : (gdouble)(row) / length, FALSE);
 
 	dw->thumb_item = di;
 	thumb_loader_free(dw->thumb_loader);
-	dw->thumb_loader = thumb_loader_new(di->path, thumb_max_width, thumb_max_height);
+	dw->thumb_loader = thumb_loader_new(thumb_max_width, thumb_max_height);
 
-	/* setup error */
-	thumb_loader_set_error_func(dw->thumb_loader, dupe_thumb_error_cb, dw);
+	thumb_loader_set_callbacks(dw->thumb_loader,
+				   dupe_thumb_done_cb,
+				   dupe_thumb_error_cb,
+				   NULL,
+				   dw);
 
 	/* start it */
-	if (!thumb_loader_start(dw->thumb_loader, dupe_thumb_done_cb, dw))
+	if (!thumb_loader_start(dw->thumb_loader, di->path))
 		{
 		/* error, handle it, do next */
 		if (debug) printf("error loading thumb for %s\n", di->path);
@@ -1296,7 +1326,7 @@ static void dupe_check_stop(DupeWindow *dw)
 {
 	if (dw->idle_id != -1 || dw->img_loader || dw->thumb_loader)
 		{
-		gtk_idle_remove(dw->idle_id);
+		g_source_remove(dw->idle_id);
 		dw->idle_id = -1;
 		dupe_window_update_progress(dw, NULL, 0.0, FALSE);
 		widget_set_cursor(dw->listview, -1);
@@ -1345,7 +1375,7 @@ static void dupe_loader_done_cb(ImageLoader *il, gpointer data)
 	image_loader_free(dw->img_loader);
 	dw->img_loader = NULL;
 
-	dw->idle_id = gtk_idle_add(dupe_check_cb, dw);
+	dw->idle_id = g_idle_add(dupe_check_cb, dw);
 }
 
 static void dupe_setup_reset(DupeWindow *dw)
@@ -1390,7 +1420,7 @@ static gint dupe_check_cb(gpointer data)
 				if (!di->md5sum)
 					{
 					dupe_window_update_progress(dw, _("Reading checksums..."),
-						dw->setup_count == 0 ? 0.0 : (float)(dw->setup_n - 1) / dw->setup_count, FALSE);
+						dw->setup_count == 0 ? 0.0 : (gdouble)(dw->setup_n - 1) / dw->setup_count, FALSE);
 
 					if (enable_thumb_caching)
 						{
@@ -1423,7 +1453,7 @@ static gint dupe_check_cb(gpointer data)
 				if (di->width == 0 && di->height == 0)
 					{
 					dupe_window_update_progress(dw, _("Reading dimensions..."),
-						dw->setup_count == 0 ? 0.0 : (float)(dw->setup_n - 1) / dw->setup_count, FALSE);
+						dw->setup_count == 0 ? 0.0 : (gdouble)(dw->setup_n - 1) / dw->setup_count, FALSE);
 
 					if (enable_thumb_caching)
 						{
@@ -1457,7 +1487,7 @@ static gint dupe_check_cb(gpointer data)
 				if (!di->simd)
 					{
 					dupe_window_update_progress(dw, _("Reading similarity data..."),
-						dw->setup_count == 0 ? 0.0 : (float)dw->setup_n / dw->setup_count, FALSE);
+						dw->setup_count == 0 ? 0.0 : (gdouble)dw->setup_n / dw->setup_count, FALSE);
 
 					if (enable_thumb_caching)
 						{
@@ -1522,7 +1552,7 @@ static gint dupe_check_cb(gpointer data)
 		}
 
 	dupe_list_check_match(dw, (DupeItem *)dw->working->data, dw->working);
-	dupe_window_update_progress(dw, _("Comparing..."), dw->setup_count == 0 ? 0.0 : (float) dw->setup_n / dw->setup_count, FALSE);
+	dupe_window_update_progress(dw, _("Comparing..."), dw->setup_count == 0 ? 0.0 : (gdouble) dw->setup_n / dw->setup_count, FALSE);
 	dw->setup_n++;
 
 	dw->working = dw->working->prev;
@@ -1547,7 +1577,7 @@ static void dupe_check_start(DupeWindow *dw)
 
 	if (dw->idle_id != -1) return;
 
-	dw->idle_id = gtk_idle_add(dupe_check_cb, dw);
+	dw->idle_id = g_idle_add(dupe_check_cb, dw);
 }
 
 /*
@@ -1576,7 +1606,7 @@ static void dupe_item_remove(DupeWindow *dw, DupeItem *di)
 			{
 			image_loader_free(dw->img_loader);
 			dw->img_loader = NULL;
-			dw->idle_id = gtk_idle_add(dupe_check_cb, dw);
+			dw->idle_id = g_idle_add(dupe_check_cb, dw);
 			}
 		}
 
@@ -1829,10 +1859,10 @@ static void dupe_display_stats(DupeWindow *dw, DupeItem *di)
 	
 	if (!di) return;
 
-	gd = file_util_gen_dlg("Image thumbprint debug info", NULL, "GQview", "thumbprint",
+	gd = file_util_gen_dlg("Image thumbprint debug info", "GQview", "thumbprint",
 			       dw->window, TRUE,
 			       NULL, NULL);
-	generic_dialog_add_stock(gd, _("Close"), GTK_STOCK_CLOSE, NULL, TRUE);
+	generic_dialog_add_button(gd, GTK_STOCK_CLOSE, NULL, NULL, TRUE);
 
 	dupe_display_label(gd->vbox, "name:", di->name);
 	buf = text_from_size(di->size);
@@ -1872,7 +1902,7 @@ static void dupe_display_stats(DupeWindow *dw, DupeItem *di)
 			}
 
 		image = gtk_image_new_from_pixbuf(pixbuf);
-		gtk_box_pack_start(GTK_BOX(gd->vbox), image, FALSE, FALSE, 5);
+		gtk_box_pack_start(GTK_BOX(gd->vbox), image, FALSE, FALSE, 0);
 		gtk_widget_show(image);
 		
 		gdk_pixbuf_unref(pixbuf);
@@ -2084,6 +2114,18 @@ static void dupe_menu_collection_cb(GtkWidget *widget, gpointer data)
 	dupe_window_collection_from_selection(dw);
 }
 
+static void dupe_menu_print_cb(GtkWidget *widget, gpointer data)
+{
+	DupeWindow *dw = data;
+	const gchar *path;
+
+	path = (dw->click_item) ? dw->click_item->path : NULL;
+
+	print_window_new(path,
+			 dupe_listview_get_selection(dw, dw->listview),
+			 dupe_listview_get_path_list(dw, dw->listview), dw->window);
+}
+
 static void dupe_menu_copy_cb(GtkWidget *widget, gpointer data)
 {
 	DupeWindow *dw = data;
@@ -2162,6 +2204,8 @@ static GtkWidget *dupe_menu_popup_main(DupeWindow *dw, DupeItem *di)
 				G_CALLBACK(dupe_menu_info_cb), dw);
 	menu_item_add_stock_sensitive(menu, _("Add to new collection"), GTK_STOCK_INDEX, on_row,
 				G_CALLBACK(dupe_menu_collection_cb), dw);
+	menu_item_add_stock_sensitive(menu, _("Print..."), GTK_STOCK_PRINT, on_row,
+				G_CALLBACK(dupe_menu_print_cb), dw);
 	menu_item_add_divider(menu);
 	menu_item_add_stock_sensitive(menu, _("_Copy..."), GTK_STOCK_COPY, on_row,
 				G_CALLBACK(dupe_menu_copy_cb), dw);
@@ -2480,7 +2524,7 @@ static void dupe_second_set_toggle_cb(GtkWidget *widget, gpointer data)
 	if (dw->second_set)
 		{
 		dupe_second_update_status(dw);
-		gtk_table_set_col_spacings(GTK_TABLE(dw->table), 5);
+		gtk_table_set_col_spacings(GTK_TABLE(dw->table), PREF_PAD_GAP);
 		gtk_widget_show(dw->second_vbox);
 		}
 	else
@@ -2499,85 +2543,62 @@ static void dupe_second_set_toggle_cb(GtkWidget *widget, gpointer data)
  *-------------------------------------------------------------------
  */
 
-static void dupe_menu_type_cb(GtkWidget *widget, gpointer data)
+enum {
+	DUPE_MENU_COLUMN_NAME = 0,
+	DUPE_MENU_COLUMN_MASK
+};
+
+static void dupe_menu_type_cb(GtkWidget *combo, gpointer data)
 {
 	DupeWindow *dw = data;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 
-	dw->match_mask = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "dupe_type"));
+	store = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) return;
+	gtk_tree_model_get(store, &iter, DUPE_MENU_COLUMN_MASK, &dw->match_mask, -1);
 
 	dupe_window_recompare(dw);
 }
 
-static void dupe_menu_add_item(GtkWidget *menu, const gchar *text, DupeMatchType type, DupeWindow *dw)
+static void dupe_menu_add_item(GtkListStore *store, const gchar *text, DupeMatchType type, DupeWindow *dw)
 {
-	GtkWidget *item;
+	GtkTreeIter iter;
 
-	item = gtk_menu_item_new_with_label(text);
-	g_object_set_data(G_OBJECT(item), "dupe_type", GINT_TO_POINTER(type));
-	g_signal_connect(G_OBJECT(item), "activate",
-			 G_CALLBACK(dupe_menu_type_cb), dw);
-	gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
-	gtk_widget_show(item);
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter, DUPE_MENU_COLUMN_NAME, text,
+					 DUPE_MENU_COLUMN_MASK, type, -1);
+
+	if (dw->match_mask == type) gtk_combo_box_set_active_iter(GTK_COMBO_BOX(dw->combo), &iter);
 }
 
 static void dupe_menu_setup(DupeWindow *dw)
 {
-	GtkWidget *menu;
-	gint n;
+	GtkListStore *store;
+	GtkCellRenderer *renderer;
 
-	menu = gtk_menu_new();
+	store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+	dw->combo = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
+	g_object_unref(store);
 
-	dupe_menu_add_item(menu, _("Name"), DUPE_MATCH_NAME, dw);
-	dupe_menu_add_item(menu, _("Size"), DUPE_MATCH_SIZE, dw);
-	dupe_menu_add_item(menu, _("Date"), DUPE_MATCH_DATE, dw);
-	dupe_menu_add_item(menu, _("Dimensions"), DUPE_MATCH_DIM, dw);
-	dupe_menu_add_item(menu, _("Checksum"), DUPE_MATCH_SUM, dw);
-	dupe_menu_add_item(menu, _("Path"), DUPE_MATCH_PATH, dw);
-	dupe_menu_add_item(menu, _("Similarity (high)"), DUPE_MATCH_SIM_HIGH, dw);
-	dupe_menu_add_item(menu, _("Similarity"), DUPE_MATCH_SIM_MED, dw);
-	dupe_menu_add_item(menu, _("Similarity (low)"), DUPE_MATCH_SIM_LOW, dw);
-	dupe_menu_add_item(menu, _("Similarity (custom)"), DUPE_MATCH_SIM_CUSTOM, dw);
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(dw->combo), renderer, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(dw->combo), renderer,
+				       "text", DUPE_MENU_COLUMN_NAME, NULL);
 
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(dw->dupe_omenu), menu);
+	dupe_menu_add_item(store, _("Name"), DUPE_MATCH_NAME, dw);
+	dupe_menu_add_item(store, _("Size"), DUPE_MATCH_SIZE, dw);
+	dupe_menu_add_item(store, _("Date"), DUPE_MATCH_DATE, dw);
+	dupe_menu_add_item(store, _("Dimensions"), DUPE_MATCH_DIM, dw);
+	dupe_menu_add_item(store, _("Checksum"), DUPE_MATCH_SUM, dw);
+	dupe_menu_add_item(store, _("Path"), DUPE_MATCH_PATH, dw);
+	dupe_menu_add_item(store, _("Similarity (high)"), DUPE_MATCH_SIM_HIGH, dw);
+	dupe_menu_add_item(store, _("Similarity"), DUPE_MATCH_SIM_MED, dw);
+	dupe_menu_add_item(store, _("Similarity (low)"), DUPE_MATCH_SIM_LOW, dw);
+	dupe_menu_add_item(store, _("Similarity (custom)"), DUPE_MATCH_SIM_CUSTOM, dw);
 
-	switch (dw->match_mask)
-		{
-		case DUPE_MATCH_NAME:
-			n = 0;
-			break;
-		case DUPE_MATCH_SIZE:
-			n = 1;
-			break;
-		case DUPE_MATCH_DATE:
-			n = 2;
-			break;
-		case DUPE_MATCH_DIM:
-			n = 3;
-			break;
-		case DUPE_MATCH_SUM:
-			n = 4;
-			break;
-		case DUPE_MATCH_PATH:
-			n = 5;
-			break;
-		case DUPE_MATCH_SIM_HIGH:
-			n = 6;
-			break;
-		case DUPE_MATCH_SIM_MED:
-			n = 7;
-			break;
-		case DUPE_MATCH_SIM_LOW:
-			n = 8;
-			break;
-		case DUPE_MATCH_SIM_CUSTOM:
-			n = 9;
-			break;
-		default:
-			n = 0;
-			break;
-		}
-
-	gtk_option_menu_set_history(GTK_OPTION_MENU(dw->dupe_omenu), n);
+	g_signal_connect(G_OBJECT(dw->combo), "changed",
+			 G_CALLBACK(dupe_menu_type_cb), dw);
 }
 
 /*
@@ -3028,7 +3049,6 @@ DupeWindow *dupe_window_new(DupeMatchType match_mask)
 	GtkWidget *status_box;
 	GtkWidget *label;
 	GtkWidget *button;
-	GtkWidget *sep;
 	GtkListStore *store;
 	GtkTreeSelection *selection;
 	GdkGeometry geometry;
@@ -3089,6 +3109,7 @@ DupeWindow *dupe_window_new(DupeMatchType match_mask)
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(dw->listview));
 	gtk_tree_selection_set_mode(GTK_TREE_SELECTION(selection), GTK_SELECTION_MULTIPLE);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(dw->listview), TRUE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(dw->listview), FALSE);
 
 	dupe_listview_add_column(dw, dw->listview, DUPE_COLUMN_RANK, "", FALSE, TRUE);
 	dupe_listview_add_column(dw, dw->listview, DUPE_COLUMN_THUMB, "", TRUE, FALSE);
@@ -3105,7 +3126,7 @@ DupeWindow *dupe_window_new(DupeMatchType match_mask)
 	gtk_table_attach_defaults(GTK_TABLE(dw->table), dw->second_vbox, 2, 3, 0, 1);
 	if (dw->second_set)
 		{
-		gtk_table_set_col_spacings(GTK_TABLE(dw->table), 5);
+		gtk_table_set_col_spacings(GTK_TABLE(dw->table), PREF_PAD_GAP);
 		gtk_widget_show(dw->second_vbox);
 		}
 	else
@@ -3126,6 +3147,7 @@ DupeWindow *dupe_window_new(DupeMatchType match_mask)
 	gtk_tree_selection_set_mode(GTK_TREE_SELECTION(selection), GTK_SELECTION_MULTIPLE);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(dw->second_listview), TRUE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(dw->second_listview), FALSE);
 
 	dupe_listview_add_column(dw, dw->second_listview, 1, _("Compare to:"), FALSE, FALSE);
 
@@ -3136,35 +3158,30 @@ DupeWindow *dupe_window_new(DupeMatchType match_mask)
 	gtk_box_pack_start(GTK_BOX(dw->second_vbox), dw->second_status_label, FALSE, FALSE, 0);
 	gtk_widget_show(dw->second_status_label);
 
-	sep = gtk_hseparator_new();
-	gtk_box_pack_start(GTK_BOX(dw->second_vbox), sep, FALSE, FALSE, 0);
-	gtk_widget_show(sep);
+	pref_line(dw->second_vbox, GTK_ORIENTATION_HORIZONTAL);
 
-	status_box = gtk_hbox_new(FALSE, 0);
-        gtk_box_pack_start(GTK_BOX(vbox), status_box, FALSE, FALSE, 0);
-        gtk_widget_show(status_box);
+	status_box = pref_box_new(vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, 0);
 
 	label = gtk_label_new(_("Compare by:"));
-	gtk_box_pack_start(GTK_BOX(status_box), label, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(status_box), label, FALSE, FALSE, PREF_PAD_SPACE);
 	gtk_widget_show(label);
 
-	dw->dupe_omenu = gtk_option_menu_new();
 	dupe_menu_setup(dw);
-	gtk_box_pack_start(GTK_BOX(status_box), dw->dupe_omenu, FALSE, FALSE, 0);
-	gtk_widget_show(dw->dupe_omenu);
+	gtk_box_pack_start(GTK_BOX(status_box), dw->combo, FALSE, FALSE, 0);
+	gtk_widget_show(dw->combo);
 
 	dw->button_thumbs = gtk_check_button_new_with_label(_("Thumbnails"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(dw->button_thumbs), dw->show_thumbs);
 	g_signal_connect(G_OBJECT(dw->button_thumbs), "toggled",
 			 G_CALLBACK(dupe_window_show_thumb_cb), dw);
-	gtk_box_pack_start(GTK_BOX(status_box), dw->button_thumbs, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(status_box), dw->button_thumbs, FALSE, FALSE, PREF_PAD_SPACE);
 	gtk_widget_show(dw->button_thumbs);
 
 	button = gtk_check_button_new_with_label(_("Compare two file sets"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), dw->second_set);
 	g_signal_connect(G_OBJECT(button), "toggled",
 			 G_CALLBACK(dupe_second_set_toggle_cb), dw);
-	gtk_box_pack_end(GTK_BOX(status_box), button, FALSE, FALSE, 0);
+	gtk_box_pack_end(GTK_BOX(status_box), button, FALSE, FALSE, PREF_PAD_SPACE);
 	gtk_widget_show(button);
 
 	status_box = gtk_hbox_new(FALSE, 0);
