@@ -14,7 +14,6 @@
 #include "image.h"
 
 
-#include "globals.h"
 #include "image-load.h"
 #include "collect.h"
 #include "exif.h"
@@ -445,12 +444,13 @@ static void image_tile_render(ImageWindow *imd, ImageTile *it,
 		else
 			{
 			/* faster, simple */
-			gdk_pixbuf_render_to_drawable(imd->pixbuf, it->pixmap,
-        		                              imd->image->style->fg_gc[GTK_WIDGET_STATE(imd->image)],
-        	        	                      it->x + x, it->y + y,
-        	                	              x, y,
-        	                        	      w, h,
-		                                      (GdkRgbDither)dither_quality, it->x + x, it->y + y);
+			gdk_draw_pixbuf(it->pixmap,
+					imd->image->style->fg_gc[GTK_WIDGET_STATE(imd->image)],
+					imd->pixbuf,
+					it->x + x, it->y + y,
+					x, y,
+					w, h,
+					(GdkRgbDither)dither_quality, it->x + x, it->y + y);
 			}
 		}
 	else
@@ -489,12 +489,13 @@ static void image_tile_render(ImageWindow *imd, ImageTile *it,
 
 	if (draw && it->pixbuf && !it->blank)
 		{
-		gdk_pixbuf_render_to_drawable(it->pixbuf, it->pixmap,
-					      imd->image->style->fg_gc[GTK_WIDGET_STATE(imd->image)],
-					      x, y,
-					      x, y,
-					      w, h,
-					      (GdkRgbDither)dither_quality, it->x + x, it->y + y);
+		gdk_draw_pixbuf(it->pixmap,
+				imd->image->style->fg_gc[GTK_WIDGET_STATE(imd->image)],
+				it->pixbuf,
+				x, y,
+				x, y,
+				w, h,
+				(GdkRgbDither)dither_quality, it->x + x, it->y + y);
 		}
 }
 
@@ -554,8 +555,8 @@ static gint image_queue_draw_idle_cb(gpointer data)
 			{
 			/* still loading, wait till done (also drops the higher priority) */
 
-			imd->draw_idle_id = gtk_idle_add_priority(G_PRIORITY_DEFAULT_IDLE,
-								  image_queue_draw_idle_cb, imd);
+			imd->draw_idle_id = g_idle_add_full(G_PRIORITY_DEFAULT_IDLE,
+							    image_queue_draw_idle_cb, imd, NULL);
 			imd->draw_idle_high = FALSE;
 			return FALSE;
 			}
@@ -770,8 +771,9 @@ static void image_queue(ImageWindow *imd, gint x, gint y, gint w, gint h,
 	if (image_queue_to_tiles(imd, nx, ny, w, h, clamp, render, new_data) &&
 	    ((!imd->draw_queue && !imd->draw_queue_2pass) || imd->draw_idle_id == -1 || !imd->draw_idle_high))
 		{
-		if (imd->draw_idle_id != -1) gtk_idle_remove(imd->draw_idle_id);
-		imd->draw_idle_id = gtk_idle_add_priority(G_PRIORITY_HIGH_IDLE, image_queue_draw_idle_cb, imd);
+		if (imd->draw_idle_id != -1) g_source_remove(imd->draw_idle_id);
+		imd->draw_idle_id = g_idle_add_full(GDK_PRIORITY_REDRAW,
+						    image_queue_draw_idle_cb, imd, NULL);
 		imd->draw_idle_high = TRUE;
 		}
 }
@@ -801,7 +803,7 @@ static void image_queue_clear(ImageWindow *imd)
 	image_queue_list_free(imd->draw_queue_2pass);
 	imd->draw_queue_2pass = NULL;
 
-	if (imd->draw_idle_id != -1) gtk_idle_remove(imd->draw_idle_id);
+	if (imd->draw_idle_id != -1) g_source_remove(imd->draw_idle_id);
 	imd->draw_idle_id = -1;
 }
 
@@ -816,7 +818,7 @@ static gint image_top_window_sizable(ImageWindow *imd)
 	if (!imd->top_window) return FALSE;
 	if (!fit_window) return FALSE;
 	if (!imd->top_window_sync) return FALSE;
-	if (!imd->eventbox->window) return FALSE;
+	if (!imd->image->window) return FALSE;
 	if (window_maximized(imd->top_window)) return FALSE;
 
 	return TRUE;
@@ -837,8 +839,8 @@ static gint image_size_top_window(ImageWindow *imd, gint w, gint h)
 		if (h > sh) h = sh;
 		}
 
-	w += (imd->top_window->allocation.width - imd->eventbox->allocation.width);
-	h += (imd->top_window->allocation.height - imd->eventbox->allocation.height);
+	w += (imd->top_window->allocation.width - imd->image->allocation.width);
+	h += (imd->top_window->allocation.height - imd->image->allocation.height);
 
 	gdk_drawable_get_size(imd->top_window->window, &ww, &wh);
 	if (w == ww && h == wh) return FALSE;
@@ -860,6 +862,19 @@ static void image_border_draw(ImageWindow *imd, gint x, gint y, gint w, gint h)
 
 	if (!imd->image->window) return;
 
+	if (!imd->pixbuf)
+		{
+		if (util_clip_region(x, y, w, h,
+			0, 0,
+			imd->window_width, imd->window_height,
+			&rx, &ry, &rw, &rh))
+			{
+			gdk_window_clear_area(imd->image->window, rx, ry, rw, rh);
+			image_overlay_draw(imd, rx, ry, rw, rh);
+			}
+		return;
+		}
+
 	if (imd->vis_width < imd->window_width)
 		{
 		if (imd->x_offset > 0 &&
@@ -945,10 +960,10 @@ static gint image_scroll_clamp(ImageWindow *imd)
 	return (old_xs != imd->x_scroll || old_ys != imd->y_scroll);
 }
 
-static gint image_zoom_clamp(ImageWindow *imd, gfloat zoom, gint force, gint new)
+static gint image_zoom_clamp(ImageWindow *imd, gdouble zoom, gint force, gint new)
 {
 	gint w, h;
-	gfloat scale;
+	gdouble scale;
 
 	zoom = CLAMP(zoom, IMAGE_ZOOM_MIN, IMAGE_ZOOM_MAX);
 
@@ -988,16 +1003,16 @@ static gint image_zoom_clamp(ImageWindow *imd, gfloat zoom, gint force, gint new
 
 		if ((zoom_to_fit_expands && !sizeable) || w > max_w || h > max_h)
 			{
-			if ((gfloat)max_w / w > (gfloat)max_h / h)
+			if ((gdouble)max_w / w > (gdouble)max_h / h)
 				{
-				scale = (gfloat)max_h / h;
+				scale = (gdouble)max_h / h;
 				h = max_h;
 				w = w * scale + 0.5;
 				if (w > max_w) w = max_w;
 				}
 			else
 				{
-				scale = (gfloat)max_w / w;
+				scale = (gdouble)max_w / w;
 				w = max_w;
 				h = h * scale + 0.5;
 				if (h > max_h) h = max_h;
@@ -1078,17 +1093,36 @@ static void image_size_sync(ImageWindow *imd, gint new_width, gint new_height)
 	gtk_widget_set_size_request(imd->image, imd->window_width, imd->window_height);
 
 	/* ensure scroller remains visible */
-	if (imd->scroller_id != -1)
+	if (imd->scroller_overlay != -1)
 		{
+		gint update = FALSE;
+
 		if (imd->scroller_x > new_width)
 			{
 			imd->scroller_x = new_width;
 			imd->scroller_xpos = new_width;
+			update = TRUE;
 			}
 		if (imd->scroller_y > new_height)
 			{
 			imd->scroller_y = new_height;
 			imd->scroller_ypos = new_height;
+			update = TRUE;
+			}
+
+		if (update)
+			{
+			GdkPixbuf *pixbuf;
+
+			if (image_overlay_get(imd, imd->scroller_overlay, &pixbuf, NULL, NULL))
+				{
+				gint w, h;
+
+				w = gdk_pixbuf_get_width(pixbuf);
+				h = gdk_pixbuf_get_height(pixbuf);
+				image_overlay_set(imd, imd->scroller_overlay, pixbuf,
+						  imd->scroller_x - w / 2, imd->scroller_y - h / 2);
+				}
 			}
 		}
 
@@ -1177,6 +1211,8 @@ static void image_scroll_real(ImageWindow *imd, gint x, gint y)
 	gint x_off, y_off;
 	gint w, h;
 
+	if (!imd->pixbuf) return;
+
 	old_x = imd->x_scroll;
 	old_y = imd->y_scroll;
 
@@ -1297,12 +1333,13 @@ static void widget_set_cursor(GtkWidget *widget, gint icon)
  *-------------------------------------------------------------------
  */
 
-static void image_zoom_sync(ImageWindow *imd, gfloat zoom,
+static void image_zoom_sync(ImageWindow *imd, gdouble zoom,
 			    gint force, gint blank, gint new,
 			    gint center_point, gint px, gint py)
 {
-	gfloat old_scale;
+	gdouble old_scale;
 	gint old_cx, old_cy;
+	gint clamped;
 	gint sized;
 
 	old_scale = imd->scale;
@@ -1322,15 +1359,8 @@ static void image_zoom_sync(ImageWindow *imd, gfloat zoom,
 
 	if (!image_zoom_clamp(imd, zoom, force, new)) return;
 
-	if (image_size_clamp(imd))
-		{
-		sized = image_size_top_window(imd, imd->width, imd->height);
-		if (!sized) image_border_clear(imd);
-		}
-	else
-		{
-		sized = image_size_top_window(imd, imd->width, imd->height);
-		}
+	clamped = image_size_clamp(imd);
+	sized = image_size_top_window(imd, imd->width, imd->height);
 
 	if (force)
 		{
@@ -1371,17 +1401,18 @@ static void image_zoom_sync(ImageWindow *imd, gfloat zoom,
 
 	image_tile_sync(imd, imd->width, imd->height, blank);
 
-	/* Only call redraw if the window size was not adjusted, since that will call the
-	 * window size signal, which in turn will call a redraw with everything at a valid size.
-	 * (imd->image is not adjusted until return to main loop)
+	/* If the window was not sized, redraw the image - we know there will be no size/expose signal.
+	 * But even if a size is claimed, there is no guarantee that the window manager will allow it,
+	 * so redraw the window anyway :/
 	 */
-	if (!sized) image_redraw(imd, FALSE);
+	if (sized || clamped) image_border_clear(imd);
+	image_redraw(imd, FALSE);
 
 	if (imd->title_show_zoom) image_update_title(imd);
 	image_update_util(imd);
 }
 
-static void image_pixbuf_sync(ImageWindow *imd, gfloat zoom, gint blank, gint new)
+static void image_pixbuf_sync(ImageWindow *imd, gdouble zoom, gint blank, gint new)
 {
 	if (!imd->pixbuf)
 		{
@@ -1413,7 +1444,7 @@ static void image_pixbuf_sync(ImageWindow *imd, gfloat zoom, gint blank, gint ne
 	image_zoom_sync(imd, zoom, TRUE, blank, new, FALSE, 0, 0);
 }
 
-static void image_set_pixbuf(ImageWindow *imd, GdkPixbuf *pixbuf, gfloat zoom, gint new)
+static void image_set_pixbuf(ImageWindow *imd, GdkPixbuf *pixbuf, gdouble zoom, gint new)
 {
 	if (pixbuf) g_object_ref(pixbuf);
 	if (imd->pixbuf) g_object_unref(imd->pixbuf);
@@ -1585,7 +1616,7 @@ static void image_read_ahead_done_cb(ImageLoader *il, gpointer data)
 		}
 	else
 		{
-		imd->read_ahead_pixbuf = gdk_pixbuf_new_from_xpm_data(img_unknown);
+		imd->read_ahead_pixbuf = pixbuf_inline(PIXBUF_INLINE_BROKEN);
 		}
 	image_loader_free(imd->read_ahead_il);
 	imd->read_ahead_il = NULL;
@@ -1715,10 +1746,10 @@ static void image_load_area_cb(ImageLoader *il, guint x, guint y, guint w, guint
 
 	if (imd->scale != 1.0)
 		{
-		x = (guint) floor((float)x * imd->scale);
-		y = (guint) floor((float)y * imd->scale);
-		w = (guint) ceil((float)w * imd->scale);
-		h = (guint) ceil((float)h * imd->scale);
+		x = (guint) floor((double)x * imd->scale);
+		y = (guint) floor((double)y * imd->scale);
+		w = (guint) ceil((double)w * imd->scale);
+		h = (guint) ceil((double)h * imd->scale);
 
 		if (w == 0) w = 1;
 		if (h == 0) h = 1;
@@ -1917,7 +1948,7 @@ static void image_reset(ImageWindow *imd)
  *-------------------------------------------------------------------
  */
 
-static void image_change_complete(ImageWindow *imd, gfloat zoom, gint new)
+static void image_change_complete(ImageWindow *imd, gdouble zoom, gint new)
 {
 	gint sync = TRUE;
 
@@ -1935,7 +1966,7 @@ static void image_change_complete(ImageWindow *imd, gfloat zoom, gint new)
 		else
 			{
 			if (imd->pixbuf) g_object_unref(imd->pixbuf);
-			imd->pixbuf = gdk_pixbuf_new_from_xpm_data(img_unknown);
+			imd->pixbuf = pixbuf_inline(PIXBUF_INLINE_BROKEN);
 			imd->unknown = TRUE;
 			}
 		imd->size = filesize(imd->image_path);
@@ -1948,7 +1979,7 @@ static void image_change_complete(ImageWindow *imd, gfloat zoom, gint new)
 
 		if (imd->image_path)
 			{
-			imd->pixbuf = gdk_pixbuf_new_from_xpm_data(img_unknown);
+			imd->pixbuf = pixbuf_inline(PIXBUF_INLINE_BROKEN);
 			imd->mtime = filetime(imd->image_path);
 			}
 		else
@@ -1971,7 +2002,7 @@ static void image_change_complete(ImageWindow *imd, gfloat zoom, gint new)
 }
 
 static void image_change_real(ImageWindow *imd, const gchar *path,
-			      CollectionData *cd, CollectInfo *info, gfloat zoom)
+			      CollectionData *cd, CollectInfo *info, gdouble zoom)
 {
 	GdkPixbuf *prev_pixbuf = NULL;
 	gchar *prev_path = NULL;
@@ -2028,20 +2059,8 @@ static gint image_expose_cb(GtkWidget *widget, GdkEventExpose *event, gpointer d
 
 	ImageWindow *imd = data;
 
-	if (!imd->pixbuf)
-		{
-		image_overlay_draw(imd, event->area.x, event->area.y,
-					event->area.width, event->area.height);
-		return TRUE;
-		}
-
-	/* border */
-
-	if (imd->overlay_list)
-		{
-		image_border_draw(imd, event->area.x, event->area.y,
-				  event->area.width, event->area.height);
-		}
+	image_border_draw(imd, event->area.x, event->area.y,
+			  event->area.width, event->area.height);
 
 	/* image */
 	x = MAX(0, (gint)event->area.x - imd->x_offset + imd->x_scroll);
@@ -2155,11 +2174,12 @@ static void image_overlay_draw(ImageWindow *imd, gint x, gint y, gint w, gint h)
 
 		if (util_clip_region(x, y, w, h, px, py, pw, ph, &rx, &ry, &rw, &rh))
 			{
-			gdk_pixbuf_render_to_drawable(od->pixbuf, imd->image->window,
-						      imd->image->style->fg_gc[GTK_WIDGET_STATE(imd->image)],
-						      rx - px, ry - py,
-						      rx, ry, rw, rh,
-						      (GdkRgbDither)dither_quality, rx, ry);
+			gdk_draw_pixbuf(imd->image->window,
+					imd->image->style->fg_gc[GTK_WIDGET_STATE(imd->image)],
+					od->pixbuf,
+					rx - px, ry - py,
+					rx, ry, rw, rh,
+					(GdkRgbDither)dither_quality, rx, ry);
 			}
 		}
 }
@@ -2419,13 +2439,13 @@ static void image_scroller_timer_set(ImageWindow *imd, gint start)
 {
 	if (imd->scroller_id != -1)
 		{
-		gtk_timeout_remove(imd->scroller_id);
+		g_source_remove(imd->scroller_id);
 		imd->scroller_id = -1;
 		}
 
 	if (start)
 		{
-		imd->scroller_id = gtk_timeout_add(1000 / SCROLLER_UPDATES_PER_SEC,
+		imd->scroller_id = g_timeout_add(1000 / SCROLLER_UPDATES_PER_SEC,
 						   image_scroller_update_cb, imd);
 		}
 }
@@ -2437,7 +2457,7 @@ static void image_scroller_start(ImageWindow *imd, gint x, gint y)
 		GdkPixbuf *pixbuf;
 		gint w, h;
 
-		pixbuf = gdk_pixbuf_new_from_inline(-1, icon_scroller, FALSE, NULL);
+		pixbuf = pixbuf_inline(PIXBUF_INLINE_SCROLLER);
 		w = gdk_pixbuf_get_width(pixbuf);
 		h = gdk_pixbuf_get_height(pixbuf);
 
@@ -2701,7 +2721,7 @@ void image_set_path(ImageWindow *imd, const gchar *newpath)
 
 /* load a new image */
 
-void image_change_path(ImageWindow *imd, const gchar *path, gfloat zoom)
+void image_change_path(ImageWindow *imd, const gchar *path, gdouble zoom)
 {
 	if (imd->image_path == path ||
 	    (path && imd->image_path && !strcmp(path, imd->image_path)) ) return;
@@ -2709,13 +2729,13 @@ void image_change_path(ImageWindow *imd, const gchar *path, gfloat zoom)
 	image_change_real(imd, path, NULL, NULL, zoom);
 }
 
-void image_change_pixbuf(ImageWindow *imd, GdkPixbuf *pixbuf, gfloat zoom)
+void image_change_pixbuf(ImageWindow *imd, GdkPixbuf *pixbuf, gdouble zoom)
 {
 	image_set_pixbuf(imd, pixbuf, zoom, TRUE);
 	image_new_util(imd);
 }
 
-void image_change_from_collection(ImageWindow *imd, CollectionData *cd, CollectInfo *info, gfloat zoom)
+void image_change_from_collection(ImageWindow *imd, CollectionData *cd, CollectInfo *info, gdouble zoom)
 {
 	if (!cd || !info || !g_list_find(cd->list, info)) return;
 
@@ -2818,10 +2838,10 @@ void image_area_changed(ImageWindow *imd, gint x, gint y, gint width, gint heigh
 {
 	gint sx, sy, sw, sh;
 
-	sx = (gint)floor((float)x * imd->scale);
-	sy = (gint)floor((float)y * imd->scale);
-	sw = (gint)ceil((float)width * imd->scale);
-	sh = (gint)ceil((float)height * imd->scale);
+	sx = (gint)floor((double)x * imd->scale);
+	sy = (gint)floor((double)y * imd->scale);
+	sw = (gint)ceil((double)width * imd->scale);
+	sh = (gint)ceil((double)height * imd->scale);
 
 	image_queue(imd, sx, sy, sw, sh, FALSE, TILE_RENDER_AREA, TRUE);
 }
@@ -2850,10 +2870,10 @@ void image_alter(ImageWindow *imd, AlterType type)
 
 /* zoom */
 
-static void image_zoom_adjust_real(ImageWindow *imd, gfloat increment,
+static void image_zoom_adjust_real(ImageWindow *imd, gdouble increment,
 				   gint center_point, gint x, gint y)
 {
-	gfloat zoom = imd->zoom;
+	gdouble zoom = imd->zoom;
 
 	if (increment == 0.0) return; /* avoid possible div by zero, a no-op anyway... */
 
@@ -2895,34 +2915,34 @@ static void image_zoom_adjust_real(ImageWindow *imd, gfloat increment,
 	image_zoom_sync(imd, zoom, FALSE, FALSE, FALSE, center_point, x, y);
 }
 
-void image_zoom_adjust(ImageWindow *imd, gfloat increment)
+void image_zoom_adjust(ImageWindow *imd, gdouble increment)
 {
 	image_zoom_adjust_real(imd, increment, FALSE, 0, 0);
 }
 
-void image_zoom_adjust_at_point(ImageWindow *imd, gfloat increment, gint x, gint y)
+void image_zoom_adjust_at_point(ImageWindow *imd, gdouble increment, gint x, gint y)
 {
 	image_zoom_adjust_real(imd, increment, TRUE, x, y);
 }
 
-void image_zoom_set(ImageWindow *imd, gfloat zoom)
+void image_zoom_set(ImageWindow *imd, gdouble zoom)
 {
 	image_zoom_sync(imd, zoom, FALSE, FALSE, FALSE, FALSE, 0, 0);
 }
 
 void image_zoom_set_fill_geometry(ImageWindow *imd, gint vertical)
 {
-	gfloat zoom;
+	gdouble zoom;
 
 	if (!imd->pixbuf || imd->image_width < 1 || imd->image_height < 1) return;
 
 	if (vertical)
 		{
-		zoom = (gfloat)imd->window_height / imd->image_height;
+		zoom = (gdouble)imd->window_height / imd->image_height;
 		}
 	else
 		{
-		zoom = (gfloat)imd->window_width / imd->image_width;
+		zoom = (gdouble)imd->window_width / imd->image_width;
 		}
 
 	if (zoom < 1.0)
@@ -2933,20 +2953,20 @@ void image_zoom_set_fill_geometry(ImageWindow *imd, gint vertical)
 	image_zoom_set(imd, zoom);
 }
 
-gfloat image_zoom_get(ImageWindow *imd)
+gdouble image_zoom_get(ImageWindow *imd)
 {
 	return imd->zoom;
 }
 
-gfloat image_zoom_get_real(ImageWindow *imd)
+gdouble image_zoom_get_real(ImageWindow *imd)
 {
 	return imd->scale;
 }
 
 gchar *image_zoom_get_as_text(ImageWindow *imd)
 {
-	gfloat l = 1.0;
-	gfloat r = 1.0;
+	gdouble l = 1.0;
+	gdouble r = 1.0;
 	gint pl = 0;
 	gint pr = 0;
 	gchar *approx = " ";
@@ -2978,9 +2998,9 @@ gchar *image_zoom_get_as_text(ImageWindow *imd)
 	return g_strdup_printf("%.*f :%s%.*f", pl, l, approx, pr, r);
 }
 
-gfloat image_zoom_get_default(ImageWindow *imd, gint mode)
+gdouble image_zoom_get_default(ImageWindow *imd, gint mode)
 {
-	gfloat zoom;
+	gdouble zoom;
 
 	if (mode == ZOOM_RESET_ORIGINAL)
 		{
@@ -3046,7 +3066,7 @@ void image_auto_refresh(ImageWindow *imd, gint interval)
 
 	if (imd->auto_refresh_id > -1)
 		{
-		gtk_timeout_remove(imd->auto_refresh_id);
+		g_source_remove(imd->auto_refresh_id);
 		imd->auto_refresh_id = -1;
 		imd->auto_refresh_interval = -1;
 		}
@@ -3055,7 +3075,7 @@ void image_auto_refresh(ImageWindow *imd, gint interval)
 
 	if (interval == 0) interval = IMAGE_AUTO_REFRESH_TIME;
 
-	imd->auto_refresh_id = gtk_timeout_add((guint32)interval, image_auto_refresh_cb, imd);
+	imd->auto_refresh_id = g_timeout_add((guint32)interval, image_auto_refresh_cb, imd);
 	imd->auto_refresh_interval = interval;
 }
 
@@ -3249,17 +3269,15 @@ ImageWindow *image_new(gint frame)
 	imd->scroller_id = -1;
 	imd->scroller_overlay = -1;
 
-	imd->eventbox = gtk_event_box_new();
-
-	g_signal_connect_after(G_OBJECT(imd->eventbox), "size_allocate",
-			       G_CALLBACK(image_size_cb), imd);
+	imd->image = gtk_drawing_area_new();
+	gtk_widget_set_double_buffered(imd->image, FALSE);
 
 	if (imd->has_frame)
 		{
 		imd->widget = gtk_frame_new(NULL);
 		gtk_frame_set_shadow_type(GTK_FRAME(imd->widget), GTK_SHADOW_IN);
-		gtk_container_add(GTK_CONTAINER(imd->widget), imd->eventbox);
-		gtk_widget_show(imd->eventbox);
+		gtk_container_add(GTK_CONTAINER(imd->widget), imd->image);
+		gtk_widget_show(imd->image);
 
 		GTK_WIDGET_SET_FLAGS(imd->widget, GTK_CAN_FOCUS);
 		g_signal_connect(G_OBJECT(imd->widget), "focus_in_event",
@@ -3272,11 +3290,9 @@ ImageWindow *image_new(gint frame)
 		}
 	else
 		{
-		imd->widget = imd->eventbox;
+		imd->widget = imd->image;
 		}
 
-	imd->image = gtk_drawing_area_new();
-
 	g_signal_connect(G_OBJECT(imd->image), "motion_notify_event",
 			 G_CALLBACK(image_mouse_motion_cb), imd);
 	g_signal_connect(G_OBJECT(imd->image), "button_press_event",
@@ -3291,15 +3307,14 @@ ImageWindow *image_new(gint frame)
 
 	g_signal_connect(G_OBJECT(imd->image), "expose_event",
 			 G_CALLBACK(image_expose_cb), imd);
+	g_signal_connect_after(G_OBJECT(imd->image), "size_allocate",
+			 G_CALLBACK(image_size_cb), imd);
+
 	g_signal_connect(G_OBJECT(imd->image), "drag_begin",
 			 G_CALLBACK(image_mouse_drag_cb), imd);
-
 	g_signal_connect(G_OBJECT(imd->image), "scroll_event",
 			 G_CALLBACK(image_scroll_cb), imd);
 
-	gtk_container_add(GTK_CONTAINER(imd->eventbox), imd->image);
-	gtk_widget_show(imd->image);
-
 	g_signal_connect(G_OBJECT(imd->widget), "destroy",
 			 G_CALLBACK(image_destroy_cb), imd);
 
