@@ -21,6 +21,7 @@
 #include "image-load.h"
 #include "ui_bookmark.h"
 #include "ui_fileops.h"
+#include "ui_misc.h"
 
 #include <pwd.h>
 #include <grp.h>
@@ -29,8 +30,8 @@
 #define IMAGE_SIZE_W 200
 #define IMAGE_SIZE_H 200
 
-#define DEF_PROPERTY_WIDTH  500
-#define DEF_PROPERTY_HEIGHT 350
+#define DEF_PROPERTY_WIDTH  510
+#define DEF_PROPERTY_HEIGHT 390
 
 typedef struct _TabData TabData;
 struct _TabData
@@ -55,21 +56,10 @@ GtkWidget *table_add_line(GtkWidget *table, gint x, gint y,
 
 	if (!text) text = "";
 
-	label = gtk_label_new(description);
-	gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-	gtk_table_attach(GTK_TABLE(table), label,
-			 x, x + 1, y, y + 1,
-			 GTK_FILL, 0,
-			 2, 2);
-	gtk_widget_show(label);
+	label = pref_table_label(table, x, y, description, 1.0);
+	pref_label_bold(label, TRUE, FALSE);
 
-	label = gtk_label_new(text);
-	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-	gtk_table_attach(GTK_TABLE(table), label,
-			 x + 1, x + 2, y, y + 1,
-			 GTK_FILL, 0,
-			 2, 2);
-	gtk_widget_show(label);
+	label = pref_table_label(table, x + 1, y, text, 0.0);
 	return label;
 }
 
@@ -110,6 +100,7 @@ static TabData *info_tab_exif_new(InfoData *id)
 	GtkWidget *label;
 
 	bar = bar_exif_new(FALSE, NULL, FALSE, NULL);
+	gtk_container_set_border_width(GTK_CONTAINER(bar), PREF_PAD_BORDER);
 
 	label = gtk_label_new(_("Exif"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(id->notebook), bar, label);
@@ -170,6 +161,8 @@ static TabData *info_tab_meta_new(InfoData *id)
 	bar_info_set_selection_func(tab->bar_info, info_tab_meta_list_cb, id);
 	bar_info_selection(tab->bar_info, g_list_length(id->list) - 1);
 
+	gtk_container_set_border_width(GTK_CONTAINER(tab->bar_info), PREF_PAD_BORDER);
+
 	label = gtk_label_new(_("Keywords"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(id->notebook), tab->bar_info, label);
 	gtk_widget_show(tab->bar_info);
@@ -361,8 +354,8 @@ static TabData *info_tab_general_new(InfoData *id)
 
 	tab = g_new0(InfoTabGeneral, 1);
 
-	table = gtk_table_new(2, 11, FALSE);
-	gtk_container_set_border_width(GTK_CONTAINER(table), 5);
+	table = pref_table_new(NULL, 2, 11, FALSE, FALSE);
+	gtk_container_set_border_width(GTK_CONTAINER(table), PREF_PAD_BORDER);
 
 	tab->label_file_time = table_add_line(table, 0, 0, _("File date:"), NULL);
 	tab->label_file_size = table_add_line(table, 0, 1, _("File size:"), NULL);
@@ -660,9 +653,8 @@ void info_window_new(const gchar *path, GList *list)
 	GtkWidget *main_vbox;
 	GtkWidget *paned;
 	GtkWidget *hbox;
-	GtkWidget *label;
 	GtkWidget *button;
-	GtkWidget *arrow;
+	GtkWidget *label;
 	GdkGeometry geometry;
 
 	if (!path && !list) return;
@@ -695,7 +687,7 @@ void info_window_new(const gchar *path, GList *list)
 
 
 	gtk_window_set_default_size(GTK_WINDOW(id->window), info_window_last_width, info_window_last_height);
-	gtk_container_set_border_width(GTK_CONTAINER(id->window), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(id->window), PREF_PAD_BORDER);
 
 	g_signal_connect(G_OBJECT(id->window), "delete_event",
 			 G_CALLBACK(info_window_delete_cb), id);
@@ -720,13 +712,9 @@ void info_window_new(const gchar *path, GList *list)
 	gtk_paned_pack2(GTK_PANED(paned), main_vbox, TRUE, TRUE);
 	gtk_widget_show(main_vbox);
 
-	hbox = gtk_hbox_new(FALSE, 5);
-	gtk_box_pack_start(GTK_BOX(main_vbox), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
-
-	label = gtk_label_new(_("Filename:"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	hbox = pref_box_new(main_vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_SPACE);
+	label = pref_label_new(hbox, _("Filename:"));
+	pref_label_bold(label, TRUE, FALSE);
 
 	id->name_entry = gtk_entry_new();
 	gtk_editable_set_editable(GTK_EDITABLE(id->name_entry), FALSE);
@@ -738,42 +726,25 @@ void info_window_new(const gchar *path, GList *list)
 	gtk_box_pack_start(GTK_BOX(main_vbox), id->notebook, TRUE, TRUE, 5);
 	gtk_widget_show(id->notebook);
 
-	hbox = gtk_hbox_new(FALSE, 5);
-	gtk_box_pack_start(GTK_BOX(main_vbox), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
+	pref_spacer(main_vbox, PREF_PAD_GAP);
 
-	id->button_back = gtk_button_new();
-	arrow = gtk_image_new_from_stock(GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON);
-	gtk_container_add(GTK_CONTAINER(id->button_back), arrow);
-	gtk_widget_show(arrow);
-	
-	g_signal_connect(G_OBJECT(id->button_back), "clicked",
-			 G_CALLBACK(info_window_back_cb), id);
+	hbox = pref_box_new(main_vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
+
+	id->button_back = pref_button_new(hbox, GTK_STOCK_GO_BACK, NULL, TRUE,
+					  G_CALLBACK(info_window_back_cb), id);
 	gtk_widget_set_sensitive(id->button_back, FALSE);
-	gtk_box_pack_start(GTK_BOX(hbox), id->button_back, FALSE, FALSE, 0);
-	gtk_widget_show(id->button_back);
 
-	id->button_next = gtk_button_new();
-	arrow = gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON);
-	gtk_container_add(GTK_CONTAINER(id->button_next), arrow);
-	gtk_widget_show(arrow);
-
-	g_signal_connect(G_OBJECT(id->button_next), "clicked",
-			 G_CALLBACK(info_window_next_cb), id);
+	id->button_next = pref_button_new(hbox, GTK_STOCK_GO_FORWARD, NULL, TRUE,
+					  G_CALLBACK(info_window_next_cb), id);
 	gtk_widget_set_sensitive(id->button_next, (id->list->next != NULL));
-	gtk_box_pack_start(GTK_BOX(hbox), id->button_next, FALSE, FALSE, 0);
-	gtk_widget_show(id->button_next);
 
 	if (id->list->next)
 		{
-		id->label_count = gtk_label_new("");
-		gtk_box_pack_start(GTK_BOX(hbox), id->label_count, FALSE, FALSE, 0);
-		gtk_widget_show(id->label_count);
+		id->label_count = pref_label_new(hbox, "");
 		}
 
-	button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(info_window_close_cb), id);
+	button = pref_button_new(NULL, GTK_STOCK_CLOSE, NULL, FALSE,
+				 G_CALLBACK(info_window_close_cb), id);
 	gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
