@@ -12,12 +12,12 @@
 #include "gqview.h"
 #include "layout.h"
 
-#include "globals.h"
 #include "image.h"
 #include "layout_config.h"
 #include "layout_image.h"
 #include "layout_util.h"
 #include "menu.h"
+#include "pixbuf_util.h"
 #include "view_dir_list.h"
 #include "view_dir_tree.h"
 #include "view_file_list.h"
@@ -25,11 +25,12 @@
 #include "ui_bookmark.h"
 #include "ui_fileops.h"
 #include "ui_menu.h"
+#include "ui_misc.h"
 #include "ui_tabcomp.h"
 
 #include "icons/tools.xpm"
 
-#define MAINWINDOW_DEF_WIDTH 500
+#define MAINWINDOW_DEF_WIDTH 620
 #define MAINWINDOW_DEF_HEIGHT 400
 
 #define MAIN_WINDOW_DIV_HPOS -1
@@ -91,9 +92,10 @@ LayoutWindow *layout_find_by_image(ImageWindow *imd)
 static void layout_path_entry_changed_cb(GtkWidget *widget, gpointer data)
 {
 	LayoutWindow *lw = data;
-	GList *work;
 	gchar *buf;
 
+	if (gtk_combo_box_get_active(GTK_COMBO_BOX(widget)) < 0) return;
+
 	buf = g_strdup(gtk_entry_get_text(GTK_ENTRY(lw->path_entry)));
 	if (!buf || (lw->path && strcmp(buf, lw->path) == 0))
 		{
@@ -101,18 +103,7 @@ static void layout_path_entry_changed_cb(GtkWidget *widget, gpointer data)
 		return;
 		}
 
-	work = history_list_get_by_key("path_list");
-	while (work)
-		{
-		gchar *path = work->data;
-		work = work->next;
-
-		if (strcmp(path, buf) == 0)
-			{
-			layout_set_path(lw, buf);
-			work = NULL;
-			}
-		}
+	layout_set_path(lw, buf);
 
         g_free(buf);
 }
@@ -179,11 +170,13 @@ static GtkWidget *layout_tool_setup(LayoutWindow *lw)
 	GtkWidget *box;
 	GtkWidget *menu_bar;
 	GtkWidget *tabcomp;
+#if 0
 	GtkWidget *popwin;
+#endif
 
 	box = gtk_vbox_new(FALSE, 0);
 
-	menu_bar = layout_menu_bar(lw);
+	menu_bar = layout_actions_menu_bar(lw);
 	gtk_box_pack_start(GTK_BOX(box), menu_bar, FALSE, FALSE, 0);
 	gtk_widget_show(menu_bar);
 
@@ -191,15 +184,17 @@ static GtkWidget *layout_tool_setup(LayoutWindow *lw)
 	gtk_box_pack_start(GTK_BOX(box), lw->toolbar, FALSE, FALSE, 0);
 	if (!lw->toolbar_hidden) gtk_widget_show(lw->toolbar);
 
-	tabcomp = tab_completion_new_with_history(&lw->path_entry, NULL, "path_list", 32,
+	tabcomp = tab_completion_new_with_history(&lw->path_entry, NULL, "path_list", -1,
 						  layout_path_entry_cb, lw);
 	tab_completion_add_tab_func(lw->path_entry, layout_path_entry_tab_cb, lw);
 	gtk_box_pack_start(GTK_BOX(box), tabcomp, FALSE, FALSE, 0);
 	gtk_widget_show(tabcomp);
 
+#if 0
 	popwin = gtk_widget_get_toplevel(GTK_COMBO(tabcomp)->list);
-	g_signal_connect_after(G_OBJECT(popwin), "hide",
-			       G_CALLBACK(layout_path_entry_changed_cb), lw);
+#endif
+	g_signal_connect(G_OBJECT(lw->path_entry->parent), "changed",
+			 G_CALLBACK(layout_path_entry_changed_cb), lw);
 
 	if (lw->tree_view)
 		{
@@ -310,13 +305,13 @@ static GtkWidget *layout_sort_button(LayoutWindow *lw)
  *-----------------------------------------------------------------------------
  */
 
-void layout_status_update_progress(LayoutWindow *lw, gfloat val, const gchar *text)
+void layout_status_update_progress(LayoutWindow *lw, gdouble val, const gchar *text)
 {
 	if (!layout_valid(&lw)) return;
 	if (!lw->info_progress_bar) return;
 
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(lw->info_progress_bar), val);
-	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(lw->info_progress_bar), text);
+	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(lw->info_progress_bar), (text) ? text : " ");
 }
 
 void layout_status_update_info(LayoutWindow *lw, const gchar *text)
@@ -376,6 +371,8 @@ void layout_status_update_info(LayoutWindow *lw, const gchar *text)
 			}
 
 		text = buf;
+
+		layout_image_overlay_update(lw);
 		}
 
 	gtk_label_set_text(GTK_LABEL(lw->info_status), text);
@@ -521,7 +518,7 @@ static void layout_list_status_cb(ViewFileList *vfl, gpointer data)
 	layout_status_update_info(lw, NULL);
 }
 
-static void layout_list_thumb_cb(ViewFileList *vfl, gfloat val, const gchar *text, gpointer data)
+static void layout_list_thumb_cb(ViewFileList *vfl, gdouble val, const gchar *text, gpointer data)
 {
 	LayoutWindow *lw = data;
 
@@ -535,7 +532,7 @@ static void layout_icon_status_cb(ViewFileIcon *vfi, gpointer data)
         layout_status_update_info(lw, NULL);
 }
 
-static void layout_icon_thumb_cb(ViewFileIcon *vfi, gfloat val, const gchar *text, gpointer data)
+static void layout_icon_thumb_cb(ViewFileIcon *vfi, gdouble val, const gchar *text, gpointer data)
 {
         LayoutWindow *lw = data;
 
@@ -1107,7 +1104,6 @@ static void layout_tools_setup(LayoutWindow *lw, GtkWidget *tools, GtkWidget *fi
         	gtk_window_set_title(GTK_WINDOW(lw->tools), _("GQview Tools"));
         	gtk_window_set_wmclass(GTK_WINDOW(lw->tools), "tools", "GQview");
         	gtk_container_set_border_width(GTK_CONTAINER(lw->tools), 0);
-	        gtk_window_add_accel_group(GTK_WINDOW(lw->tools), lw->accel_grp);
 
 		window_set_icon(lw->tools, (const gchar **)tools_xpm, NULL);
 
@@ -1120,6 +1116,8 @@ static void layout_tools_setup(LayoutWindow *lw, GtkWidget *tools, GtkWidget *fi
 		gtk_widget_destroy(GTK_BIN(lw->tools)->child);
 		}
 
+	layout_actions_add_window(lw, lw->tools);
+
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(lw->tools), vbox);
 	gtk_widget_show(vbox);
@@ -1245,6 +1243,9 @@ static void layout_grid_setup(LayoutWindow *lw)
 	GtkWidget *tools;
 	GtkWidget *files;
 
+	layout_actions_setup(lw);
+	layout_actions_add_window(lw, lw->window);
+
 	lw->group_box = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(lw->main_box), lw->group_box, TRUE, TRUE, 0);
 	gtk_widget_show(lw->group_box);
@@ -1319,6 +1320,15 @@ static void layout_grid_setup(LayoutWindow *lw)
 	gtk_widget_show(v);
 	gtk_widget_show(h);
 
+	/* fix to have image pane visible when it is left and priority widget */
+	if (lw->div_h == -1 &&
+	    w1 == image &&
+	    !layout_location_vertical(priority_location) &&
+	    layout_location_first(priority_location))
+		{
+		gtk_widget_set_size_request(image, 200, -1);
+		}
+
 	gtk_paned_set_position(GTK_PANED(lw->h_pane), lw->div_h);
 	gtk_paned_set_position(GTK_PANED(lw->v_pane), lw->div_v);
 
@@ -1387,8 +1397,13 @@ void layout_style_set(LayoutWindow *lw, gint style, const gchar *order)
 	lw->info_details = NULL;
 	lw->info_zoom = NULL;
 
+#if 0
 	if (lw->menu_fact) g_object_unref(G_OBJECT(lw->menu_fact));
 	lw->menu_fact = NULL;
+#endif
+	if (lw->ui_manager) g_object_unref(lw->ui_manager);
+	lw->ui_manager = NULL;
+	lw->action_group = NULL;
 
 	gtk_container_remove(GTK_CONTAINER(lw->main_box), lw->group_box);
 	lw->group_box = NULL;
@@ -1569,12 +1584,14 @@ void layout_free(LayoutWindow *lw)
 
 	if (lw->last_time_id != -1)
 		{
-		gtk_timeout_remove(lw->last_time_id);
+		g_source_remove(lw->last_time_id);
 		}
 
 	layout_bars_close(lw);
 
+#if 0
 	if (lw->menu_fact) g_object_unref(G_OBJECT(lw->menu_fact));
+#endif
 	if (lw->tooltips) g_object_unref(G_OBJECT(lw->tooltips));
 	gtk_widget_destroy(lw->window);
 
@@ -1691,9 +1708,6 @@ LayoutWindow *layout_new(const gchar *path, gint popped, gint hidden)
 	gtk_widget_realize(lw->window);
 #endif
 
-	lw->accel_grp = gtk_accel_group_new();
-	gtk_window_add_accel_group(GTK_WINDOW(lw->window), lw->accel_grp);
-
 	lw->tooltips = gtk_tooltips_new();
 	g_object_ref(G_OBJECT(lw->tooltips));
 	gtk_object_sink(GTK_OBJECT(lw->tooltips));
@@ -1716,14 +1730,14 @@ LayoutWindow *layout_new(const gchar *path, gint popped, gint hidden)
 		{
 		GdkPixbuf *pixbuf;
 
-		pixbuf = gdk_pixbuf_new_from_xpm_data(logo);
+		pixbuf = pixbuf_inline(PIXBUF_INLINE_LOGO);
 		image_change_pixbuf(lw->image, pixbuf, 1.0);
 		gdk_pixbuf_unref(pixbuf);
 		}
 
 	/* set up the time stat timeout */
 	lw->last_time = 0;
-	lw->last_time_id = gtk_timeout_add(5000, layout_check_for_update_cb, lw);
+	lw->last_time_id = g_timeout_add(5000, layout_check_for_update_cb, lw);
 
 	gtk_widget_show(lw->window);
 	layout_tools_hide(lw, lw->tools_hidden);
