@@ -28,7 +28,7 @@ LayoutWindow *layout_find_by_image(ImageWindow *imd);
 const gchar *layout_get_path(LayoutWindow *lw);
 gint layout_set_path(LayoutWindow *lw, const gchar *path);
 
-void layout_status_update_progress(LayoutWindow *lw, gfloat val, const gchar *text);
+void layout_status_update_progress(LayoutWindow *lw, gdouble val, const gchar *text);
 void layout_status_update_info(LayoutWindow *lw, const gchar *text);
 void layout_status_update_image(LayoutWindow *lw);
 void layout_status_update_all(LayoutWindow *lw);
