@@ -14,6 +14,7 @@
 
 #include "cache.h"
 #include "collect.h"
+#include "collect-io.h"
 #include "dnd.h"
 #include "editors.h"
 #include "filelist.h"
@@ -110,9 +111,9 @@ gint window_maximized(GtkWidget *window)
 	return (state & GDK_WINDOW_STATE_MAXIMIZED);
 }
 
-gfloat get_zoom_increment(void)
+gdouble get_zoom_increment(void)
 {
-	return (zoom_increment ? zoom_increment / 10.0 : 1.0);
+	return ((zoom_increment != 0) ? (gdouble)zoom_increment / 10.0 : 1.0);
 }
 
 /*
@@ -162,7 +163,7 @@ static void help_browser_command(const gchar *command, const gchar *path)
 
 	if (!command || !path) return;
 
-	printf("Help command pre \"%s\", \"%s\"\n", command, path);
+	if (debug) printf("Help command pre \"%s\", \"%s\"\n", command, path);
 
 	buf = g_strdup(command);
 	begin = strstr(buf, "%s");
@@ -180,7 +181,7 @@ static void help_browser_command(const gchar *command, const gchar *path)
 		}
 	g_free(buf);
 
-	printf("Help command post [%s]\n", result);
+	if (debug) printf("Help command post [%s]\n", result);
 
 	system(result);
 
@@ -257,7 +258,7 @@ void help_window_show(const gchar *key)
 
 	if (help_window)
 		{
-		gdk_window_raise(help_window->window);
+		gtk_window_present(GTK_WINDOW(help_window));
 		if (key) help_window_set_key(help_window, key);
 		return;
 		}
@@ -281,6 +282,16 @@ void keyboard_scroll_calc(gint *x, gint *y, GdkEventKey *event)
 	static guint32 time_old = 0;
 	static guint keyval_old = 0;
 
+	if (event->state & GDK_CONTROL_MASK)
+		{
+		if (*x < 0) *x = G_MININT / 2;
+		if (*x > 0) *x = G_MAXINT / 2;
+		if (*y < 0) *y = G_MININT / 2;
+		if (*y > 0) *y = G_MAXINT / 2;
+
+		return;
+		}
+
 	if (progressive_key_scrolling)
 		{
 		guint32 time_diff;
@@ -346,6 +357,17 @@ static void gr_fullscreen_stop(const gchar *text, gpointer data)
 	layout_image_full_screen_stop(NULL);
 }
 
+static void gr_slideshow_start_rec(const gchar *text, gpointer data)
+{
+	GList *list;
+
+	list = path_list_recursive(text);
+	if (!list) return;
+printf("length: %d\n", g_list_length(list));
+	layout_image_slideshow_stop(NULL);
+	layout_image_slideshow_start_from_list(NULL, list);
+}
+
 static void gr_slideshow_toggle(const gchar *text, gpointer data)
 {
 	layout_image_slideshow_toggle(NULL);
@@ -402,9 +424,19 @@ static void gr_tools_hide(const gchar *text, gpointer data)
 		}
 }
 
-static void gr_quit(const gchar *text, gpointer data)
+static gint gr_quit_idle_cb(gpointer data)
 {
 	exit_gqview();
+
+	return FALSE;
+}
+
+static void gr_quit(const gchar *text, gpointer data)
+{
+	/* schedule exit when idle, if done from within a
+	 * remote handler remote_close will crash
+	 */
+	g_idle_add(gr_quit_idle_cb, NULL);
 }
 
 static void gr_file_load(const gchar *text, gpointer data)
@@ -470,6 +502,16 @@ static void gr_list_add(const gchar *text, gpointer data)
 		}
 }
 
+static void gr_raise(const gchar *text, gpointer data)
+{
+	LayoutWindow *lw = NULL;
+
+	if (layout_valid(&lw))
+		{
+		gtk_window_present(GTK_WINDOW(lw->window));
+		}
+}
+
 typedef struct _RemoteCommandEntry RemoteCommandEntry;
 struct _RemoteCommandEntry {
 	gchar *opt_s;
@@ -492,14 +534,16 @@ static RemoteCommandEntry remote_commands[] = {
 	{ "-s", "--slideshow",          gr_slideshow_toggle,	FALSE, TRUE,  N_("toggle slide show") },
 	{ "-ss","--slideshow-start",    gr_slideshow_start,     FALSE, FALSE, N_("start slide show") },
 	{ "-sS","--slideshow-stop",     gr_slideshow_stop,      FALSE, FALSE, N_("stop slide show") },
+	{ "-sr","--slideshow-recurse",  gr_slideshow_start_rec, TRUE,  FALSE, N_("start recursive slide show") },
 	{ "-d", "--delay=",             gr_slideshow_delay,     TRUE,  FALSE, N_("set slide show delay in seconds") },
 	{ "+t", "--tools-show",         gr_tools_show,          FALSE, TRUE,  N_("show tools") },
 	{ "-t", "--tools-hide",	        gr_tools_hide,          FALSE, TRUE,  N_("hide tools") },
-	{ "-q", "--quit",               gr_quit,                FALSE, FALSE, N_("exit") },
+	{ "-q", "--quit",               gr_quit,                FALSE, FALSE, N_("quit") },
 	{ NULL, "file:",                gr_file_load,           TRUE,  FALSE, N_("open file") },
 	{ NULL, "view:",		gr_file_view,		TRUE,  FALSE, N_("open file in new window") },
 	{ NULL, "--list-clear",         gr_list_clear,          FALSE, FALSE, NULL },
 	{ NULL, "--list-add:",          gr_list_add,            TRUE,  FALSE, NULL },
+	{ NULL, "raise",		gr_raise,		FALSE, FALSE, NULL },
 	{ NULL, NULL, NULL, FALSE, FALSE, NULL }
 };
 
@@ -608,6 +652,7 @@ static void gqview_remote_control(const gchar *arg_exec, GList *remote_list, con
 				  GList *cmd_list, GList *collection_list)
 {
 	RemoteConnection *rc;
+	gint started = FALSE;
 	gchar *buf;
 
 	buf = g_strconcat(homedir(), "/", GQVIEW_RC_DIR, "/.command", NULL);
@@ -619,7 +664,7 @@ static void gqview_remote_control(const gchar *arg_exec, GList *remote_list, con
 		gint retry_count = 12;
 		gint blank = FALSE;
 
-		print_term(_("Remote GQview not running, starting...\n"));
+		print_term(_("Remote GQview not running, starting..."));
 		command = g_string_new(arg_exec);
 
 		work = remote_list;
@@ -658,8 +703,13 @@ static void gqview_remote_control(const gchar *arg_exec, GList *remote_list, con
 			{
 			usleep((retry_count > 10) ? 500000 : 1000000);
 			rc = remote_client_open(buf);
+			if (!rc) print_term(".");
 			retry_count--;
 			}
+
+		print_term("\n");
+
+		started = TRUE;
 		}
 	g_free(buf);
 
@@ -668,6 +718,7 @@ static void gqview_remote_control(const gchar *arg_exec, GList *remote_list, con
 		GList *work;
 		const gchar *prefix;
 		gint use_path = TRUE;
+		gint sent = FALSE;
 
 		work = remote_list;
 		while (work)
@@ -684,6 +735,8 @@ static void gqview_remote_control(const gchar *arg_exec, GList *remote_list, con
 			    strcmp(entry->opt_l, "file:") == 0) use_path = FALSE;
 
 			remote_client_send(rc, text);
+
+			sent = TRUE;
 			}
 
 		if (cmd_list && cmd_list->next)
@@ -708,6 +761,8 @@ static void gqview_remote_control(const gchar *arg_exec, GList *remote_list, con
 			text = g_strconcat(prefix, name, NULL);
 			remote_client_send(rc, text);
 			g_free(text);
+
+			sent = TRUE;
 			}
 
 		if (path && !cmd_list && use_path)
@@ -717,6 +772,8 @@ static void gqview_remote_control(const gchar *arg_exec, GList *remote_list, con
 			text = g_strdup_printf("file:%s", path);
 			remote_client_send(rc, text);
 			g_free(text);
+
+			sent = TRUE;
 			}
 
 		work = collection_list;
@@ -731,6 +788,13 @@ static void gqview_remote_control(const gchar *arg_exec, GList *remote_list, con
 			text = g_strdup_printf("file:%s", name);
 			remote_client_send(rc, text);
 			g_free(text);
+
+			sent = TRUE;
+			}
+
+		if (!started && !sent)
+			{
+			remote_client_send(rc, "raise");
 			}
 		}
 	else
@@ -1014,6 +1078,8 @@ static void exit_gqview_final(void)
 
 	remote_close(gqview_remote);
 
+	collect_manager_flush();
+
 	if (layout_valid(&lw))
 		{
 		main_window_maximized =  window_maximized(lw->window);
@@ -1070,7 +1136,7 @@ static gint exit_confirm_dlg(void)
 
 	if (exit_dialog)
 		{
-		gdk_window_raise(exit_dialog->dialog->window);
+		gtk_window_present(GTK_WINDOW(exit_dialog->dialog));
 		return TRUE;
 		}
 
@@ -1083,10 +1149,12 @@ static gint exit_confirm_dlg(void)
 		parent = lw->window;
 		}
 
-	exit_dialog = generic_dialog_new(_("GQview - exit"), _("Collections have been modified.\nExit anyway?"),
+	exit_dialog = generic_dialog_new(_("GQview - exit"),
 				"GQview", "exit", parent, FALSE,
 				exit_confirm_cancel_cb, NULL);
-	generic_dialog_add_stock(exit_dialog, _("Exit"), GTK_STOCK_QUIT, exit_confirm_exit_cb, TRUE);
+	generic_dialog_add_message(exit_dialog, GTK_STOCK_DIALOG_QUESTION,
+				   _("Quit GQview"), _("Collections have been modified. Quit anyway?"));
+	generic_dialog_add_button(exit_dialog, GTK_STOCK_QUIT, NULL, exit_confirm_exit_cb, TRUE);
 
 	gtk_widget_show(exit_dialog->dialog);
 
@@ -1110,20 +1178,21 @@ int main (int argc, char *argv[])
 	gchar *cmd_file = NULL;
 	GList *cmd_list = NULL;
 	GList *collection_list = NULL;
+	CollectionData *first_collection = NULL;
 	gchar *buf;
 	gchar *bufl;
 
 	/* setup locale, i18n */
 	gtk_set_locale();
-	bindtextdomain (PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (PACKAGE, "UTF-8");
-	textdomain (PACKAGE);
+	bindtextdomain(PACKAGE, GQVIEW_LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE, "UTF-8");
+	textdomain(PACKAGE);
 
 	/* setup random seed for random slideshow */
         srand(time(NULL));
 
-#if 1
-	printf("GQview %s, This is a development release! Expect bugs.\n", VERSION);
+#if 0
+	printf("GQview %s, This is a beta release.\n", VERSION);
 #endif
 
 	layout_order = g_strdup("123");
@@ -1134,6 +1203,21 @@ int main (int argc, char *argv[])
 
 	gtk_init (&argc, &argv);
 
+	if (gtk_major_version < GTK_MAJOR_VERSION ||
+	    (gtk_major_version == GTK_MAJOR_VERSION && gtk_minor_version < GTK_MINOR_VERSION) )
+		{
+		gchar *msg;
+		print_term("!!! This is a friendly warning.\n");
+		print_term("!!! The version of GTK+ in use now is older than when GQview was compiled.\n");
+		msg = g_strdup_printf("!!!  compiled with GTK+-%d.%d\n", GTK_MAJOR_VERSION, GTK_MINOR_VERSION);
+		print_term(msg);
+		g_free(msg);
+		msg = g_strdup_printf("!!!   running with GTK+-%d.%d\n", gtk_major_version, gtk_minor_version);
+		print_term(msg);
+		g_free(msg);
+		print_term("!!! GQview may quit unexpectedly with a relocation error.\n");
+		}
+
 	check_for_home_path(GQVIEW_RC_DIR);
 	check_for_home_path(GQVIEW_RC_DIR_COLLECTIONS);
 	check_for_home_path(GQVIEW_CACHE_RC_THUMB);
@@ -1178,7 +1262,26 @@ int main (int argc, char *argv[])
 	lw = layout_new(NULL, tools_float, tools_hidden);
 	layout_sort_set(lw, file_sort_method, file_sort_ascending);
 
-	if (cmd_list)
+	if (collection_list && !startup_command_line_collection)
+		{
+		GList *work;
+
+		work = collection_list;
+		while (work)
+			{
+			CollectWindow *cw;
+			const gchar *path;
+
+			path = work->data;
+			work = work->next;
+
+			cw = collection_window_new(path);
+			if (!first_collection && cw) first_collection = cw->cd;
+			}
+		}
+
+	if (cmd_list ||
+	    (startup_command_line_collection && collection_list))
 		{
 		CollectionData *cd;
 		GList *work;
@@ -1210,6 +1313,13 @@ int main (int argc, char *argv[])
 			work = work->next;
 			}
 
+		work = collection_list;
+		while (work)
+			{
+			collection_load(cd, (gchar *)work->data, TRUE);
+			work = work->next;
+			}
+
 		layout_set_path(lw, path);
 		if (cd->list) layout_image_set_collection(lw, cd, cd->list->data);
 
@@ -1229,19 +1339,10 @@ int main (int argc, char *argv[])
 	else
 		{
 		layout_set_path(lw, path);
-		}
-
-	if (collection_list)
-		{
-		GList *work;
-
-		work = collection_list;
-		while (work)
+		if (first_collection)
 			{
-			const gchar *path = work->data;
-			work = work->next;
-
-			collection_window_new(path);
+			layout_image_set_collection(lw, first_collection,
+						    collection_get_first(first_collection));
 			}
 		}
 
