@@ -18,6 +18,17 @@ gboolean pixbuf_to_file_as_png (GdkPixbuf *pixbuf, const char *filename);
 gboolean pixbuf_to_file_as_jpg(GdkPixbuf *pixbuf, const gchar *filename, gint quality);
 
 
+GdkPixbuf *pixbuf_inline(const gchar *key);
+
+#define PIXBUF_INLINE_FOLDER_CLOSED	"folder_closed"
+#define PIXBUF_INLINE_FOLDER_LOCKED	"folder_locked"
+#define PIXBUF_INLINE_FOLDER_OPEN	"folder_open"
+#define PIXBUF_INLINE_FOLDER_UP		"folder_up"
+#define PIXBUF_INLINE_SCROLLER		"scroller"
+#define PIXBUF_INLINE_BROKEN		"broken"
+#define PIXBUF_INLINE_LOGO		"logo"
+
+
 GdkPixbuf *pixbuf_copy_rotate_90(GdkPixbuf *src, gint counter_clockwise);
 GdkPixbuf *pixbuf_copy_mirror(GdkPixbuf *src, gint mirror, gint flip);
 
