@@ -239,6 +239,10 @@ void save_options(void)
 	write_bool_option(f, "cache_thumbnails", enable_thumb_caching);
 	write_bool_option(f, "cache_thumbnails_into_dirs", enable_thumb_dirs);
 	write_bool_option(f, "use_xvpics_thumbnails", use_xvpics_thumbnails);
+	write_bool_option(f, "thumbnail_spec_standard", thumbnail_spec_standard);
+	fprintf(f,"\n");
+
+	write_bool_option(f, "local_metadata", enable_metadata_dirs);
 	fprintf(f,"\n");
 
 	write_int_option(f, "sort_method", (gint)file_sort_method);
@@ -280,6 +284,7 @@ void save_options(void)
 	write_int_option(f, "fullscreen_screen", fullscreen_screen);
 	write_bool_option(f, "fullscreen_clean_flip", fullscreen_clean_flip);
 	write_bool_option(f, "fullscreen_disable_saver", fullscreen_disable_saver);
+	write_bool_option(f, "fullscreen_above", fullscreen_above);
 
 	write_int_option(f, "custom_similarity_threshold", dupe_custom_threshold);
 
@@ -447,6 +452,11 @@ void load_options(void)
 			"cache_thumbnails_into_dirs", value, enable_thumb_dirs);
 		use_xvpics_thumbnails = read_bool_option(f, option,
 			"use_xvpics_thumbnails", value, use_xvpics_thumbnails);
+		thumbnail_spec_standard = read_bool_option(f, option,
+			"thumbnail_spec_standard", value, thumbnail_spec_standard);
+
+		enable_metadata_dirs = read_bool_option(f, option,
+			"local_metadata", value, enable_metadata_dirs);
 
 		file_sort_method = (SortType)read_int_option(f, option,
 			"sort_method", value, (gint)file_sort_method);
@@ -512,6 +522,8 @@ void load_options(void)
 			"fullscreen_clean_flip", value, fullscreen_clean_flip);
 		fullscreen_disable_saver = read_bool_option(f, option,
 			"fullscreen_disable_saver", value, fullscreen_disable_saver);
+		fullscreen_above = read_bool_option(f, option,
+			"fullscreen_above", value, fullscreen_above);
 
 		dupe_custom_threshold = read_int_option(f, option,
 			"custom_similarity_threshold", value, dupe_custom_threshold);
