@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2004 John Ellis
+ * (C) 2005 John Ellis
  *
  * Author: John Ellis
  *
@@ -26,6 +26,7 @@
 #include "filelist.h"
 #include "layout_image.h"
 #include "menu.h"
+#include "print.h"
 #include "thumb.h"
 #include "utilops.h"
 #include "ui_bookmark.h"
@@ -196,7 +197,7 @@ struct _MatchList
 };
 
 static const MatchList text_search_menu_path[] = {
-	{ N_("path"),		SEARCH_MATCH_NONE },
+	{ N_("folder"),		SEARCH_MATCH_NONE },
 	{ N_("comments"),	SEARCH_MATCH_ALL },
 	{ N_("results"),	SEARCH_MATCH_CONTAINS }
 };
@@ -288,7 +289,7 @@ static void search_status_update(SearchData *sd)
 	g_free(buf);
 }
 
-static void search_progress_update(SearchData *sd, gint search, gfloat thumbs)
+static void search_progress_update(SearchData *sd, gint search, gdouble thumbs)
 {
 
 	if (search || thumbs >= 0.0)
@@ -426,13 +427,14 @@ static gint search_result_selection_count(SearchData *sd, gint64 *bytes)
 	return search_result_selection_util(sd, bytes, NULL);
 }
 
-static gint search_result_count(SearchData *sd, gint64 *bytes)
+static gint search_result_util(SearchData *sd, gint64 *bytes, GList **list)
 {
 	GtkTreeModel *store;
 	GtkTreeIter iter;
 	gint valid;
 	gint n = 0;
 	gint64 total = 0;
+	GList *plist = NULL;
 
 	store = gtk_tree_view_get_model(GTK_TREE_VIEW(sd->result_view));
 
@@ -440,21 +442,37 @@ static gint search_result_count(SearchData *sd, gint64 *bytes)
 	while (valid)
 		{
 		n++;
-		if (bytes)
+		if (bytes || list)
 			{
 			FileData *fd;
 
 			gtk_tree_model_get(store, &iter, SEARCH_COLUMN_POINTER, &fd, -1);
 			total += fd->size;
+
+			if (list) plist = g_list_prepend(plist, g_strdup(fd->path));
 			}
 		valid = gtk_tree_model_iter_next(store, &iter);
 		}
 
 	if (bytes) *bytes = total;
+	if (list) *list = g_list_reverse(plist);
 
 	return n;
 }
 
+static GList *search_result_get_path_list(SearchData *sd)
+{
+	GList *list = NULL;
+
+	search_result_util(sd, NULL, &list);
+	return list;
+}
+
+static gint search_result_count(SearchData *sd, gint64 *bytes)
+{
+	return search_result_util(sd, bytes, NULL);
+}
+
 static void search_result_append(SearchData *sd, MatchFileData *mfd)
 {
 	FileData *fd;
@@ -651,7 +669,7 @@ static gint search_result_update_idle_cb(gpointer data)
 
 static void search_result_update_idle_cancel(SearchData *sd)
 {
-	if (sd->update_idle_id != -1) gtk_idle_remove(sd->update_idle_id);
+	if (sd->update_idle_id != -1) g_source_remove(sd->update_idle_id);
 	sd->update_idle_id = -1;
 }
 
@@ -755,14 +773,18 @@ static void search_result_thumb_step(SearchData *sd)
 		return;
 		}
 
-	search_progress_update(sd, FALSE, (gfloat)row/length);
+	search_progress_update(sd, FALSE, (gdouble)row/length);
 
 	sd->thumb_fd = fd;
 	thumb_loader_free(sd->thumb_loader);
-	sd->thumb_loader = thumb_loader_new(fd->path, thumb_max_width, thumb_max_height);
+	sd->thumb_loader = thumb_loader_new(thumb_max_width, thumb_max_height);
 
-	thumb_loader_set_error_func(sd->thumb_loader, search_result_thumb_done_cb, sd);
-	if (!thumb_loader_start(sd->thumb_loader, search_result_thumb_done_cb, sd))
+	thumb_loader_set_callbacks(sd->thumb_loader,
+				   search_result_thumb_done_cb,
+				   search_result_thumb_done_cb,
+				   NULL,
+				   sd);
+	if (!thumb_loader_start(sd->thumb_loader, fd->path))
 		{
 		search_result_thumb_do(sd);
 		search_result_thumb_step(sd);
@@ -885,6 +907,17 @@ static void sr_menu_collection_cb(GtkWidget *widget, gpointer data)
 	search_result_collection_from_selection(sd);
 }
 
+static void sr_menu_print_cb(GtkWidget *widget, gpointer data)
+{
+	SearchData *sd = data;
+	const gchar *path;
+
+	path = (sd->click_fd) ? sd->click_fd->path : NULL;
+
+	print_window_new(path, search_result_selection_list(sd),
+			 search_result_get_path_list(sd), sd->window);
+}
+
 static void sr_menu_copy_cb(GtkWidget *widget, gpointer data)
 {
 	SearchData *sd = data;
@@ -949,6 +982,8 @@ static GtkWidget *search_result_menu(SearchData *sd, gint on_row, gint empty)
 				      G_CALLBACK(sr_menu_info_cb), sd);
 	menu_item_add_stock_sensitive(menu, _("Add to new collection"), GTK_STOCK_INDEX, on_row,
 				      G_CALLBACK(sr_menu_collection_cb), sd);
+	menu_item_add_stock_sensitive(menu, _("Print..."), GTK_STOCK_PRINT, on_row,
+				      G_CALLBACK(sr_menu_print_cb), sd);
 	menu_item_add_divider(menu);
 	menu_item_add_stock_sensitive(menu, _("_Copy..."), GTK_STOCK_COPY, on_row,
 				      G_CALLBACK(sr_menu_copy_cb), sd);
@@ -1421,7 +1456,7 @@ static void search_stop(SearchData *sd)
 {
 	if (sd->search_idle_id != -1)
 		{
-		gtk_idle_remove(sd->search_idle_id);
+		g_source_remove(sd->search_idle_id);
 		sd->search_idle_id = -1;
 		}
 
@@ -1476,16 +1511,31 @@ static void search_file_load_process(SearchData *sd, CacheData *cd)
 			}
 
 		if (enable_thumb_caching &&
-		    cache_sim_data_save(cd))
+		    sd->img_loader && sd->img_loader->path)
 			{
-			filetime_set(cd->path, filetime(sd->img_loader->path));
+			gchar *base;
+			const gchar *path;
+			mode_t mode = 0755;
+
+			path = sd->img_loader->path;
+			base = cache_get_location(CACHE_TYPE_SIM, path, FALSE, &mode);
+			if (cache_ensure_dir_exists(base, mode))
+				{
+				g_free(cd->path);
+				cd->path = cache_get_location(CACHE_TYPE_SIM, path, TRUE, NULL);
+				if (cache_sim_data_save(cd))
+					{
+					filetime_set(cd->path, filetime(sd->img_loader->path));
+					}
+				}
+			g_free(base);
 			}
 		}
 
 	image_loader_free(sd->img_loader);
 	sd->img_loader = NULL;
 
-	sd->search_idle_id = gtk_idle_add(search_step_cb, sd);
+	sd->search_idle_id = g_idle_add(search_step_cb, sd);
 }
 
 static void search_file_load_done_cb(ImageLoader *il, gpointer data)
@@ -1518,7 +1568,6 @@ static gint search_file_do_extra(SearchData *sd, FileData *fd, gint *match,
 	if (!sd->img_cd)
 		{
 		sd->img_cd = cache_sim_data_new();
-		sd->img_cd->path = cache_get_location(CACHE_TYPE_SIM, fd->path, TRUE, NULL);
 		}
 
 	if (new_data)
@@ -1568,7 +1617,7 @@ static gint search_file_do_extra(SearchData *sd, FileData *fd, gint *match,
 
 	if (tmatch && sd->match_similarity_enable && sd->img_cd->similarity)
 		{
-		gfloat value = 0;
+		gdouble value = 0.0;
 
 		tmatch = FALSE;
 		tested = TRUE;
@@ -1576,12 +1625,12 @@ static gint search_file_do_extra(SearchData *sd, FileData *fd, gint *match,
 		/* fixme: implement similarity checking */
 		if (sd->search_similarity_cd && sd->search_similarity_cd->similarity)
 			{
-			gfloat result;
+			gdouble result;
 
 			result = image_sim_compare_fast(sd->search_similarity_cd->sim, sd->img_cd->sim,
-							(gfloat)sd->search_similarity / 100.0);
+							(gdouble)sd->search_similarity / 100.0);
 			result *= 100.0;
-			if (result >= (gfloat)sd->search_similarity)
+			if (result >= (gdouble)sd->search_similarity)
 				{
 				tmatch = TRUE;
 				value = (gint)result;
@@ -1748,7 +1797,8 @@ static gint search_file_next(SearchData *sd)
 					haystack = list;
 					while (haystack && !found)
 						{
-						found = (strcmp((gchar *)needle->data, (gchar*)haystack->data) == 0);
+						found = (strcasecmp((gchar *)needle->data,
+								    (gchar *)haystack->data) == 0);
 						haystack = haystack->next;
 						}
 					needle = needle->next;
@@ -1766,7 +1816,8 @@ static gint search_file_next(SearchData *sd)
 					haystack = list;
 					while (haystack && !found)
 						{
-						found = (strcmp((gchar *)needle->data, (gchar*)haystack->data) == 0);
+						found = (strcasecmp((gchar *)needle->data,
+								    (gchar *)haystack->data) == 0);
 						haystack = haystack->next;
 						}
 					needle = needle->next;
@@ -1784,7 +1835,8 @@ static gint search_file_next(SearchData *sd)
 					haystack = list;
 					while (haystack && !found)
 						{
-						found = (strcmp((gchar *)needle->data, (gchar*)haystack->data) == 0);
+						found = (strcasecmp((gchar *)needle->data,
+								    (gchar *)haystack->data) == 0);
 						haystack = haystack->next;
 						}
 					needle = needle->next;
@@ -1998,8 +2050,6 @@ static void search_start(SearchData *sd)
 			if (!sd->search_similarity_cd)
 				{
 				sd->search_similarity_cd = cache_sim_data_new();
-				sd->search_similarity_cd->path = cache_get_location(CACHE_TYPE_SIM,
-								 sd->search_similarity_path, TRUE, NULL);
 				}
 
 			sd->img_loader = image_loader_new(sd->search_similarity_path);
@@ -2014,7 +2064,7 @@ static void search_start(SearchData *sd)
 			
 		}
 
-	sd->search_idle_id = gtk_idle_add(search_step_cb, sd);
+	sd->search_idle_id = g_idle_add(search_step_cb, sd);
 }
 
 static void search_start_cb(GtkWidget *widget, gpointer data)
@@ -2041,7 +2091,8 @@ static void search_start_cb(GtkWidget *widget, gpointer data)
 		if (!isfile(sd->search_similarity_path))
 			{
 			file_util_warning_dialog(_("File not found"),
-						 _("Please enter an existing file for image content."), sd->window);
+						 _("Please enter an existing file for image content."),
+						 GTK_STOCK_DIALOG_WARNING, sd->window);
 			return;
 			}
 		tab_completion_append_to_history(sd->entry_similarity, sd->search_similarity_path);
@@ -2087,7 +2138,8 @@ static void search_start_cb(GtkWidget *widget, gpointer data)
 		else
 			{
 			file_util_warning_dialog(_("Folder not found"),
-						 _("Please enter an existing folder to search."), sd->window);
+						 _("Please enter an existing folder to search."),
+						 GTK_STOCK_DIALOG_WARNING, sd->window);
 			}
 
 		g_free(path);
@@ -2123,6 +2175,11 @@ static void search_start_cb(GtkWidget *widget, gpointer data)
  *-------------------------------------------------------------------
  */
 
+enum {
+	MENU_CHOICE_COLUMN_NAME = 0,
+	MENU_CHOICE_COLUMN_VALUE
+};
+
 static void search_thumb_toggle_cb(GtkWidget *button, gpointer data)
 {
 	SearchData *sd = data;
@@ -2232,52 +2289,82 @@ static void menu_choice_set_visible(GtkWidget *widget, gint visible)
 		}
 }
 
-static void menu_choice_path_cb(GtkWidget *widget, gpointer data)
+static void menu_choice_path_cb(GtkWidget *combo, gpointer data)
 {
 	SearchData *sd = data;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+
+	store = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) return;
+	gtk_tree_model_get(store, &iter, MENU_CHOICE_COLUMN_VALUE, &sd->search_type, -1);
 
-	sd->search_type = (MatchType)GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "item_number"));
 	menu_choice_set_visible(gtk_widget_get_parent(sd->check_recurse),
 				(sd->search_type == SEARCH_MATCH_NONE));
 }
 
-static void menu_choice_name_cb(GtkWidget *widget, gpointer data)
+static void menu_choice_name_cb(GtkWidget *combo, gpointer data)
 {
 	SearchData *sd = data;
-	sd->match_name = (MatchType)GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "item_number"));
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+
+	store = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) return;
+	gtk_tree_model_get(store, &iter, MENU_CHOICE_COLUMN_VALUE, &sd->match_name, -1);
 }
 
-static void menu_choice_size_cb(GtkWidget *widget, gpointer data)
+static void menu_choice_size_cb(GtkWidget *combo, gpointer data)
 {
 	SearchData *sd = data;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+
+	store = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) return;
+	gtk_tree_model_get(store, &iter, MENU_CHOICE_COLUMN_VALUE, &sd->match_size, -1);
 
-	sd->match_size = (MatchType)GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "item_number"));
 	menu_choice_set_visible(gtk_widget_get_parent(sd->spin_size_end),
 				(sd->match_size == SEARCH_MATCH_BETWEEN));
 }
 
-static void menu_choice_date_cb(GtkWidget *widget, gpointer data)
+static void menu_choice_date_cb(GtkWidget *combo, gpointer data)
 {
 	SearchData *sd = data;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+
+	store = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) return;
+	gtk_tree_model_get(store, &iter, MENU_CHOICE_COLUMN_VALUE, &sd->match_date, -1);
 
-	sd->match_date = (MatchType)GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "item_number"));
 	menu_choice_set_visible(gtk_widget_get_parent(sd->date_sel_end),
 				(sd->match_date == SEARCH_MATCH_BETWEEN));
 }
 
-static void menu_choice_dimensions_cb(GtkWidget *widget, gpointer data)
+static void menu_choice_dimensions_cb(GtkWidget *combo, gpointer data)
 {
 	SearchData *sd = data;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+
+	store = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) return;
+	gtk_tree_model_get(store, &iter, MENU_CHOICE_COLUMN_VALUE, &sd->match_dimensions, -1);
 
-	sd->match_dimensions = (MatchType)GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "item_number"));
 	menu_choice_set_visible(gtk_widget_get_parent(sd->spin_width_end),
 				(sd->match_dimensions == SEARCH_MATCH_BETWEEN));
 }
 
-static void menu_choice_keyword_cb(GtkWidget *widget, gpointer data)
+static void menu_choice_keyword_cb(GtkWidget *combo, gpointer data)
 {
 	SearchData *sd = data;
-	sd->match_keywords = (MatchType)GPOINTER_TO_INT(g_object_get_data(G_OBJECT(widget), "item_number"));
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+
+	store = gtk_combo_box_get_model(GTK_COMBO_BOX(combo));
+	if (!gtk_combo_box_get_active_iter(GTK_COMBO_BOX(combo), &iter)) return;
+	gtk_tree_model_get(store, &iter, MENU_CHOICE_COLUMN_VALUE, &sd->match_keywords, -1);
 }
 
 static void menu_choice_spin_cb(GtkAdjustment *adjustment, gpointer data)
@@ -2304,27 +2391,6 @@ static GtkWidget *menu_spin(GtkWidget *box, gdouble min, gdouble max, gint value
 	return spin;
 }
 
-static void menu_check_cb(GtkWidget *button, gpointer data)
-{
-	gint *value = data;
-
-	*value = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
-}
-
-static GtkWidget *menu_check(GtkWidget *box, const gchar *text, gint *value)
-{
-	GtkWidget *button;
-
-	button = gtk_check_button_new_with_label(text);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), *value);
-	g_signal_connect(G_OBJECT(button), "toggled",
-			 G_CALLBACK(menu_check_cb), value);
-	gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 5);
-	gtk_widget_show(button);
-
-	return button;
-}
-
 static void menu_choice_check_cb(GtkWidget *button, gpointer data)
 {
 	GtkWidget *widget = data;
@@ -2341,23 +2407,35 @@ static void menu_choice_check_cb(GtkWidget *button, gpointer data)
 static GtkWidget *menu_choice_menu(const MatchList *items, gint item_count,
 				   GCallback func, gpointer data)
 {
-	GtkWidget *option;
-	GtkWidget *menu;
+	GtkWidget *combo;
+	GtkCellRenderer *renderer;
+	GtkListStore *store;
 	gint i;
 
-	option = gtk_option_menu_new();
+	store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+	combo = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
+	g_object_unref(store);
+
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo), renderer, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo), renderer,
+				       "text", MENU_CHOICE_COLUMN_NAME, NULL);
 
-	menu = gtk_menu_new();
 	for (i = 0; i < item_count; i++)
 		{
-		GtkWidget *item;
+		GtkTreeIter iter;
 
-		item = menu_item_add(menu, _(items[i].text), func, data);
-		g_object_set_data(G_OBJECT(item), "item_number", GINT_TO_POINTER((gint)items[i].type));
+		gtk_list_store_append(store, &iter);
+		gtk_list_store_set(store, &iter, MENU_CHOICE_COLUMN_NAME, _(items[i].text),
+						 MENU_CHOICE_COLUMN_VALUE, items[i].type, -1);
 		}
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(option), menu);
 
-	return option;
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
+
+	if (func) g_signal_connect(G_OBJECT(combo), "changed",
+				   G_CALLBACK(func), data);
+
+	return combo;
 }
 
 static GtkWidget *menu_choice(GtkWidget *box, GtkWidget **check, GtkWidget **menu,
@@ -2367,22 +2445,21 @@ static GtkWidget *menu_choice(GtkWidget *box, GtkWidget **check, GtkWidget **men
 {
 	GtkWidget *base_box;
 	GtkWidget *hbox;
-	GtkWidget *label;
 	GtkWidget *button;
 	GtkWidget *option;
 
-	base_box = gtk_hbox_new(FALSE, 0);
+	base_box = gtk_hbox_new(FALSE, PREF_PAD_GAP);
 	gtk_box_pack_start(GTK_BOX(box), base_box, FALSE, FALSE, 0);
 	gtk_widget_show(base_box);
 
 	button = gtk_check_button_new();
 	if (value) gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), *value);
-	gtk_box_pack_start(GTK_BOX(base_box), button, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(base_box), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 	if (check) *check = button;
 	if (value) g_object_set_data(G_OBJECT(button), "check_var", value);
 
-	hbox = gtk_hbox_new(FALSE, 5);
+	hbox = gtk_hbox_new(FALSE, PREF_PAD_SPACE);
 	gtk_box_pack_start(GTK_BOX(base_box), hbox, TRUE, TRUE, 0);
 	gtk_widget_show(hbox);
 
@@ -2390,9 +2467,7 @@ static GtkWidget *menu_choice(GtkWidget *box, GtkWidget **check, GtkWidget **men
 			 G_CALLBACK(menu_choice_check_cb), hbox);
 	gtk_widget_set_sensitive(hbox, (value) ? *value : FALSE);
 
-	label = gtk_label_new(text);
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	pref_label_new(hbox, text);
 
 	if (!items && !menu) return hbox;
 
@@ -2439,14 +2514,14 @@ static void search_window_destroy_cb(GtkWidget *widget, gpointer data)
 	g_free(sd);
 }
 
-void search_new(const gchar *path, GList *list)
+void search_new(const gchar *path, const gchar *example_file)
 {
 	SearchData *sd;
 	GtkWidget *vbox;
 	GtkWidget *hbox;
 	GtkWidget *hbox2;
+	GtkWidget *pad_box;
 	GtkWidget *frame;
-	GtkWidget *label;
 	GtkWidget *scrolled;
 	GtkListStore *store;
 	GtkTreeSortable *sortable;
@@ -2472,7 +2547,7 @@ void search_new(const gchar *path, GList *list)
 	sd->match_size = SEARCH_MATCH_EQUAL;
 	sd->match_date = SEARCH_MATCH_EQUAL;
 	sd->match_dimensions = SEARCH_MATCH_EQUAL;
-	sd->match_keywords = SEARCH_MATCH_ANY;
+	sd->match_keywords = SEARCH_MATCH_ALL;
 
 	sd->match_name_enable = TRUE;
 	sd->match_size_enable = FALSE;
@@ -2482,7 +2557,7 @@ void search_new(const gchar *path, GList *list)
 	sd->match_keywords_enable = FALSE;
 
 	sd->search_similarity = 95;
-	sd->search_similarity_path = NULL;
+	sd->search_similarity_path = g_strdup(example_file);
 	sd->search_similarity_cd = NULL;
 
 	sd->search_idle_id = -1;
@@ -2512,39 +2587,31 @@ void search_new(const gchar *path, GList *list)
 	g_signal_connect(G_OBJECT(sd->window), "key_press_event",
 			 G_CALLBACK(search_window_keypress_cb), sd);
 
-	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
+	vbox = gtk_vbox_new(FALSE, PREF_PAD_GAP);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), PREF_PAD_GAP);
 	gtk_container_add(GTK_CONTAINER(sd->window), vbox);
 	gtk_widget_show(vbox);
 
-	sd->box_search = gtk_vbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), sd->box_search, FALSE, FALSE, 0);
-	gtk_widget_show(sd->box_search);
+	sd->box_search = pref_box_new(vbox, FALSE, GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
 
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(sd->box_search), hbox, FALSE, FALSE, 5);
-	gtk_widget_show(hbox);
+	hbox = pref_box_new(sd->box_search, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_SPACE);
 
-	label = gtk_label_new(_("Search"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
-	gtk_widget_show(label);
+	pref_label_new(hbox, _("Search:"));
 
 	sd->menu_path = menu_choice_menu(text_search_menu_path, sizeof(text_search_menu_path) / sizeof(MatchList),
 					 G_CALLBACK(menu_choice_path_cb), sd);
 	gtk_box_pack_start(GTK_BOX(hbox), sd->menu_path, FALSE, FALSE, 0);
 	gtk_widget_show(sd->menu_path);
 
-	hbox2 = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(hbox), hbox2, TRUE, TRUE, 0);
-	gtk_widget_show(hbox2);
-
+	hbox2 = pref_box_new(hbox, TRUE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_SPACE);
 	combo = tab_completion_new_with_history(&sd->path_entry, sd->search_path,
 						"search_path", -1,
 						NULL, NULL);
 	tab_completion_add_select_button(sd->path_entry, NULL, TRUE);
-	gtk_box_pack_start(GTK_BOX(hbox2), combo, TRUE, TRUE, 5);
+	gtk_box_pack_start(GTK_BOX(hbox2), combo, TRUE, TRUE, 0);
 	gtk_widget_show(combo);
-	sd->check_recurse = menu_check(hbox2, _("Recurse"), &sd->search_path_recurse);
+	sd->check_recurse = pref_checkbox_new_int(hbox2, _("Recurse"),
+						  sd->search_path_recurse, &sd->search_path_recurse);
 
 	hbox = menu_choice(sd->box_search, &sd->check_name, &sd->menu_name,
 			   _("File name"), &sd->match_name_enable,
@@ -2553,7 +2620,8 @@ void search_new(const gchar *path, GList *list)
 	combo = history_combo_new(&sd->entry_name, "", "search_name", -1);
 	gtk_box_pack_start(GTK_BOX(hbox), combo, TRUE, TRUE, 0);
 	gtk_widget_show(combo);
-	menu_check(hbox, _("Match case"), &sd->search_name_match_case);
+	pref_checkbox_new_int(hbox, _("Match case"),
+			      sd->search_name_match_case, &sd->search_name_match_case);
 
 	hbox = menu_choice(sd->box_search, &sd->check_size, &sd->menu_size,
 			   _("File size is"), &sd->match_size_enable,
@@ -2561,11 +2629,9 @@ void search_new(const gchar *path, GList *list)
 			   G_CALLBACK(menu_choice_size_cb), sd);
 	sd->spin_size = menu_spin(hbox, 0, 1024*1024*1024, sd->search_size,
 				  G_CALLBACK(menu_choice_spin_cb), &sd->search_size);
-	hbox2 = gtk_hbox_new(FALSE, 5);
+	hbox2 = gtk_hbox_new(FALSE, PREF_PAD_SPACE);
 	gtk_box_pack_start(GTK_BOX(hbox), hbox2, FALSE, FALSE, 0);
-	label = gtk_label_new(_("and"));
-	gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	pref_label_new(hbox2, _("and"));
 	sd->spin_size_end = menu_spin(hbox2, 0, 1024*1024*1024, sd->search_size_end,
 				      G_CALLBACK(menu_choice_spin_cb), &sd->search_size_end);
 
@@ -2578,11 +2644,9 @@ void search_new(const gchar *path, GList *list)
 	gtk_box_pack_start(GTK_BOX(hbox), sd->date_sel, FALSE, FALSE, 0);
 	gtk_widget_show(sd->date_sel);
 
-	hbox2 = gtk_hbox_new(FALSE, 5);
+	hbox2 = gtk_hbox_new(FALSE, PREF_PAD_SPACE);
 	gtk_box_pack_start(GTK_BOX(hbox), hbox2, FALSE, FALSE, 0);
-	label = gtk_label_new(_("and"));
-	gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	pref_label_new(hbox2, _("and"));
 	sd->date_sel_end = date_selection_new();
 	date_selection_time_set(sd->date_sel_end, time(NULL));
 	gtk_box_pack_start(GTK_BOX(hbox2), sd->date_sel_end, FALSE, FALSE, 0);
@@ -2592,23 +2656,19 @@ void search_new(const gchar *path, GList *list)
 			   _("Image dimensions are"), &sd->match_dimensions_enable,
 			   text_search_menu_size, sizeof(text_search_menu_size) / sizeof(MatchList),
 			   G_CALLBACK(menu_choice_dimensions_cb), sd);
-	sd->spin_width = menu_spin(hbox, 0, 1000000, sd->search_width,
+	pad_box = pref_box_new(hbox, FALSE, GTK_ORIENTATION_HORIZONTAL, 2);
+	sd->spin_width = menu_spin(pad_box, 0, 1000000, sd->search_width,
 				   G_CALLBACK(menu_choice_spin_cb), &sd->search_width);
-	label = gtk_label_new("x");
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
-	sd->spin_height = menu_spin(hbox, 0, 1000000, sd->search_height,
+	pref_label_new(pad_box, "x");
+	sd->spin_height = menu_spin(pad_box, 0, 1000000, sd->search_height,
 				    G_CALLBACK(menu_choice_spin_cb), &sd->search_height);
-	hbox2 = gtk_hbox_new(FALSE, 5);
+	hbox2 = gtk_hbox_new(FALSE, 2);
 	gtk_box_pack_start(GTK_BOX(hbox), hbox2, FALSE, FALSE, 0);
-	label = gtk_label_new(_("and"));
-	gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	pref_label_new(hbox2, _("and"));
+	pref_spacer(hbox2, PREF_PAD_SPACE - 2*2);
 	sd->spin_width_end = menu_spin(hbox2, 0, 1000000, sd->search_width_end,
 				       G_CALLBACK(menu_choice_spin_cb), &sd->search_width_end);
-	label = gtk_label_new("x");
-	gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	pref_label_new(hbox2, "x");
 	sd->spin_height_end = menu_spin(hbox2, 0, 1000000, sd->search_height_end,
 					G_CALLBACK(menu_choice_spin_cb), &sd->search_height_end);
 
@@ -2619,11 +2679,10 @@ void search_new(const gchar *path, GList *list)
 					G_CALLBACK(menu_choice_spin_cb), &sd->search_similarity);
 
 	/* xgettext:no-c-format */
-	label = gtk_label_new(_("% similar to"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	pref_label_new(hbox, _("% similar to"));
 
-	combo = tab_completion_new_with_history(&sd->entry_similarity, "",
+	combo = tab_completion_new_with_history(&sd->entry_similarity,
+						(sd->search_similarity_path) ? sd->search_similarity_path : "",
 						"search_similarity_path", -1, NULL, NULL);
 	tab_completion_add_select_button(sd->entry_similarity, NULL, FALSE);
 	gtk_box_pack_start(GTK_BOX(hbox), combo, TRUE, TRUE, 0);
@@ -2644,7 +2703,7 @@ void search_new(const gchar *path, GList *list)
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
 				       GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_box_pack_start(GTK_BOX(vbox), scrolled, TRUE, TRUE, 5);
+	gtk_box_pack_start(GTK_BOX(vbox), scrolled, TRUE, TRUE, 0);
 	gtk_widget_show(scrolled);
 
 	store = gtk_list_store_new(8, G_TYPE_POINTER, G_TYPE_INT, GDK_TYPE_PIXBUF,
@@ -2683,6 +2742,11 @@ void search_new(const gchar *path, GList *list)
 	gtk_tree_selection_set_select_function(selection, search_result_select_cb, sd, NULL);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(sd->result_view), TRUE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(sd->result_view), FALSE);
+
+#if 0
+	gtk_tree_view_set_search_column(GTK_TREE_VIEW(sd->result_view), SEARCH_COLUMN_NAME);
+#endif
 
 	search_result_add_column(sd, SEARCH_COLUMN_RANK, _("Rank"), FALSE, FALSE);
 	search_result_add_column(sd, SEARCH_COLUMN_THUMB, "", TRUE, FALSE);
@@ -2701,19 +2765,14 @@ void search_new(const gchar *path, GList *list)
 	g_signal_connect(G_OBJECT(sd->result_view), "key_press_event",
 			 G_CALLBACK(search_result_keypress_cb), sd);
 
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
+	hbox = pref_box_new(vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, 0);
 
-	sd->button_thumbs = gtk_check_button_new_with_label(_("Thumbnails"));
-	g_signal_connect(G_OBJECT(sd->button_thumbs), "toggled",
-			 G_CALLBACK(search_thumb_toggle_cb), sd);
-	gtk_box_pack_start(GTK_BOX(hbox), sd->button_thumbs, FALSE, FALSE, 5);
-	gtk_widget_show(sd->button_thumbs);
+	sd->button_thumbs = pref_checkbox_new(hbox, _("Thumbnails"), FALSE,
+					      G_CALLBACK(search_thumb_toggle_cb), sd);
 
 	frame = gtk_frame_new(NULL);
 	gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-	gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, PREF_PAD_SPACE);
 	gtk_widget_show(frame);
 
 	sd->label_status = gtk_label_new("");
@@ -2730,18 +2789,12 @@ void search_new(const gchar *path, GList *list)
 	gtk_box_pack_start(GTK_BOX(hbox), sd->spinner, FALSE, FALSE, 0);
 	gtk_widget_show(sd->spinner);
 
-	sd->button_start = gtk_button_new_from_stock(GTK_STOCK_FIND);
-	g_signal_connect(G_OBJECT(sd->button_start), "clicked",
-			 G_CALLBACK(search_start_cb), sd);
-	gtk_box_pack_start(GTK_BOX(hbox), sd->button_start, FALSE, FALSE, 0);
-	gtk_widget_show(sd->button_start);
-
-	sd->button_stop = gtk_button_new_from_stock(GTK_STOCK_STOP);
+	sd->button_start = pref_button_new(hbox, GTK_STOCK_FIND, NULL, FALSE,
+					   G_CALLBACK(search_start_cb), sd);
+	pref_spacer(hbox, PREF_PAD_BUTTON_GAP);
+	sd->button_stop = pref_button_new(hbox, GTK_STOCK_STOP, NULL, FALSE,
+					  G_CALLBACK(search_start_cb), sd);
 	gtk_widget_set_sensitive(sd->button_stop, FALSE);
-	g_signal_connect(G_OBJECT(sd->button_stop), "clicked",
-			G_CALLBACK(search_start_cb), sd);
-	gtk_box_pack_start(GTK_BOX(hbox), sd->button_stop, FALSE, FALSE, 5);
-	gtk_widget_show(sd->button_stop);
 
 	search_status_update(sd);
 	search_progress_update(sd, FALSE, -1.0);
