@@ -72,7 +72,7 @@ static void image_sim_channel_expand(guint8 *pix, gint len)
 {
 	guint8 l, h;
 	gint i;
-	gfloat scale;
+	gdouble scale;
 
 	/* set the start values */
 	l = h = pix[0];
@@ -87,7 +87,7 @@ static void image_sim_channel_expand(guint8 *pix, gint len)
 	/* calc scale from range */
 	if (l != h)
 		{
-		scale = 255.0 / (gfloat)(h - l);
+		scale = 255.0 / (gdouble)(h - l);
 		}
 	else
 		{
@@ -96,7 +96,7 @@ static void image_sim_channel_expand(guint8 *pix, gint len)
 
 	for (i = 0; i < len; i++)
 		{
-		pix[i] = (guint8)((gfloat)pix[i] - l * scale);
+		pix[i] = (guint8)((gdouble)pix[i] - l * scale);
 		}
 }
 #endif
@@ -146,7 +146,7 @@ static void image_sim_channel_norm(guint8 *pix, gint len)
 {
 	guint8 l, h;
 	gint i;
-	gfloat scale;
+	gdouble scale;
 
 	l = h = pix[0];
 
@@ -156,11 +156,11 @@ static void image_sim_channel_norm(guint8 *pix, gint len)
 		if (pix[i] > h) h = pix[i];
 		}
 
-	scale = (h-l !=0) ? 255.0 / (gfloat)(h - l) : 1.0;
+	scale = (h-l !=0) ? 255.0 / (gdouble)(h - l) : 1.0;
 
 	for (i = 0; i < len; i++)
 		{
-		pix[i] = (guint8)((gfloat)(pix[i] - l) * scale);
+		pix[i] = (guint8)((gdouble)(pix[i] - l) * scale);
 		}
 }
 
@@ -245,7 +245,7 @@ void image_sim_fill_data(ImageSimilarityData *sd, GdkPixbuf *pixbuf)
 
 	for (ys = 0; ys < 32; ys++)
 		{
-		if (y_small) j = (float)h / 32 * ys;
+		if (y_small) j = (gdouble)h / 32 * ys;
 
 		i = 0;
 
@@ -255,7 +255,7 @@ void image_sim_fill_data(ImageSimilarityData *sd, GdkPixbuf *pixbuf)
 			gint r, g, b;
 			gint t;
 
-			if (x_small) i = (float)w / 32 * xs;
+			if (x_small) i = (gdouble)w / 32 * xs;
 
 			r = g = b = 0;
 
@@ -301,7 +301,7 @@ ImageSimilarityData *image_sim_new_from_pixbuf(GdkPixbuf *pixbuf)
 }
 
 #ifdef ALTERNATE_INCLUDE_COMPARE_CHANGE
-static gfloat alternate_image_sim_compare_fast(ImageSimilarityData *a, ImageSimilarityData *b, gfloat min)
+static gdouble alternate_image_sim_compare_fast(ImageSimilarityData *a, ImageSimilarityData *b, gdouble min)
 {
 	gint sim;
 	gint i;
@@ -331,14 +331,14 @@ static gfloat alternate_image_sim_compare_fast(ImageSimilarityData *a, ImageSimi
 			ld = cd / 3;
 			}
 		/* check for abort, if so return 0.0 */
-		if ((float)sim / (255.0 * 1024.0 * 4.0) > min) return 0.0;
+		if ((gdouble)sim / (255.0 * 1024.0 * 4.0) > min) return 0.0;
 		}
 
-	return (1.0 - ((float)sim / (255.0 * 1024.0 * 4.0)) );
+	return (1.0 - ((gdouble)sim / (255.0 * 1024.0 * 4.0)) );
 }
 #endif
 
-gfloat image_sim_compare(ImageSimilarityData *a, ImageSimilarityData *b)
+gdouble image_sim_compare(ImageSimilarityData *a, ImageSimilarityData *b)
 {
 	gint sim;
 	gint i;
@@ -354,13 +354,13 @@ gfloat image_sim_compare(ImageSimilarityData *a, ImageSimilarityData *b)
 		sim += abs(a->avg_b[i] - b->avg_b[i]);
 		}
 
-	return 1.0 - ((float)sim / (255.0 * 1024.0 * 3.0));
+	return 1.0 - ((gdouble)sim / (255.0 * 1024.0 * 3.0));
 }
 
 /* this uses a cutoff point so that it can abort early when it gets to
  * a point that can simply no longer make the cut-off point.
  */
-gfloat image_sim_compare_fast(ImageSimilarityData *a, ImageSimilarityData *b, gfloat min)
+gdouble image_sim_compare_fast(ImageSimilarityData *a, ImageSimilarityData *b, gdouble min)
 {
 	gint sim;
 	gint i;
@@ -384,8 +384,8 @@ gfloat image_sim_compare_fast(ImageSimilarityData *a, ImageSimilarityData *b, gf
 			sim += abs(a->avg_b[i] - b->avg_b[i]);
 			}
 		/* check for abort, if so return 0.0 */
-		if ((float)sim / (255.0 * 1024.0 * 3.0) > min) return 0.0;
+		if ((gdouble)sim / (255.0 * 1024.0 * 3.0) > min) return 0.0;
 		}
 
-	return (1.0 - ((float)sim / (255.0 * 1024.0 * 3.0)) );
+	return (1.0 - ((gdouble)sim / (255.0 * 1024.0 * 3.0)) );
 }
