@@ -14,9 +14,9 @@
 #include "thumb.h"
 
 #include "cache.h"
-#include "globals.h"
 #include "image-load.h"
 #include "pixbuf_util.h"
+#include "thumb_standard.h"
 #include "ui_fileops.h"
 
 #include <utime.h>
@@ -128,11 +128,13 @@ static gint thumb_loader_mark_failure(ThumbLoader *tl)
 	return success;
 }
 
-static void thumb_loader_percent_cb(ImageLoader *il, gfloat percent, gpointer data)
+static void thumb_loader_percent_cb(ImageLoader *il, gdouble percent, gpointer data)
 {
 	ThumbLoader *tl = data;
 
-	if (tl->func_percent) tl->func_percent(tl, percent, tl->data_percent);
+	tl->percent_done = percent;
+
+	if (tl->func_progress) tl->func_progress(tl, tl->data);
 }
 
 static void thumb_loader_done_cb(ImageLoader *il, gpointer data)
@@ -155,11 +157,11 @@ static void thumb_loader_done_cb(ImageLoader *il, gpointer data)
 	pw = gdk_pixbuf_get_width(pixbuf);
 	ph = gdk_pixbuf_get_height(pixbuf);
 
-	if (tl->from_cache && pw != tl->max_w && ph != tl->max_h)
+	if (tl->cache_hit && pw != tl->max_w && ph != tl->max_h)
 		{
 		/* requested thumbnail size may have changed, load original */
 		if (debug) printf("thumbnail size mismatch, regenerating: %s\n", tl->path);
-		tl->from_cache = FALSE;
+		tl->cache_hit = FALSE;
 
 		thumb_loader_setup(tl, tl->path);
 
@@ -204,12 +206,12 @@ static void thumb_loader_done_cb(ImageLoader *il, gpointer data)
 		}
 
 	/* save it ? */
-	if (enable_thumb_caching && save)
+	if (tl->cache_enable && save)
 		{
 		thumb_loader_save_to_cache(tl);
 		}
 
-	if (tl->func_done) tl->func_done(tl, tl->data_done);
+	if (tl->func_done) tl->func_done(tl, tl->data);
 }
 
 static void thumb_loader_error_cb(ImageLoader *il, gpointer data)
@@ -228,7 +230,7 @@ static void thumb_loader_error_cb(ImageLoader *il, gpointer data)
 	image_loader_free(tl->il);
 	tl->il = NULL;
 
-	if (tl->func_error) tl->func_error(tl, tl->data_error);
+	if (tl->func_error) tl->func_error(tl, tl->data);
 }
 
 static gint thumb_loader_done_delay_cb(gpointer data)
@@ -237,14 +239,14 @@ static gint thumb_loader_done_delay_cb(gpointer data)
 
 	tl->idle_done_id = -1;
 
-	if (tl->func_done) tl->func_done(tl, tl->data_done);
+	if (tl->func_done) tl->func_done(tl, tl->data);
 
 	return FALSE;
 }
 
 static void thumb_loader_delay_done(ThumbLoader *tl)
 {
-	if (tl->idle_done_id == -1) tl->idle_done_id = gtk_idle_add(thumb_loader_done_delay_cb, tl);
+	if (tl->idle_done_id == -1) tl->idle_done_id = g_idle_add(thumb_loader_done_delay_cb, tl);
 }
 
 static void thumb_loader_setup(ThumbLoader *tl, gchar *path)
@@ -252,40 +254,74 @@ static void thumb_loader_setup(ThumbLoader *tl, gchar *path)
 	image_loader_free(tl->il);
 	tl->il = image_loader_new(path);
 
+#if 0
+	/* this will speed up jpegs by up to 3x in some cases */
+	image_loader_set_requested_size(tl->max_w, tl->max_h);
+#endif
+
 	image_loader_set_error_func(tl->il, thumb_loader_error_cb, tl);
-	if (tl->func_percent) image_loader_set_percent_func(tl->il, thumb_loader_percent_cb, tl);
+	if (tl->func_progress) image_loader_set_percent_func(tl->il, thumb_loader_percent_cb, tl);
 }
 
-void thumb_loader_set_error_func(ThumbLoader *tl,
-				 void (*func_error)(ThumbLoader *, gpointer),
-				 gpointer data_error)
+void thumb_loader_set_callbacks(ThumbLoader *tl,
+				ThumbLoaderFunc func_done,
+				ThumbLoaderFunc func_error,
+				ThumbLoaderFunc func_progress,
+				gpointer data)
 {
 	if (!tl) return;
 
+	if (tl->standard_loader)
+		{
+		thumb_loader_std_set_callbacks((ThumbLoaderStd *)tl,
+					       (ThumbLoaderStdFunc) func_done,
+					       (ThumbLoaderStdFunc) func_error,
+					       (ThumbLoaderStdFunc) func_progress,
+					       data);
+		return;
+		}
+
+	tl->func_done = func_done;
 	tl->func_error = func_error;
-	tl->data_error = data_error;
+	tl->func_progress = func_progress;
+
+	tl->data = data;
 }
 
-void thumb_loader_set_percent_func(ThumbLoader *tl,
-				   void (*func_percent)(ThumbLoader *, gfloat, gpointer),
-				   gpointer data_percent)
+void thumb_loader_set_cache(ThumbLoader *tl, gint enable_cache, gint local, gint retry_failed)
 {
-	if (!tl) return;
+        if (!tl) return;
 
-	tl->func_percent = func_percent;
-	tl->data_percent = data_percent;
+	if (tl->standard_loader)
+		{
+		thumb_loader_std_set_cache((ThumbLoaderStd *)tl, enable_cache, local, retry_failed);
+		return;
+		}
+
+	tl->cache_enable = enable_cache;
+#if 0
+	tl->cache_local = local;
+	tl->cache_retry = retry_failed;
+#endif
 }
 
-gint thumb_loader_start(ThumbLoader *tl, void (*func_done)(ThumbLoader *, gpointer), gpointer data_done)
+
+gint thumb_loader_start(ThumbLoader *tl, const gchar *path)
 {
 	gchar *cache_path = NULL;
 
-	if (!tl || !tl->path) return FALSE;
+	if (!tl) return FALSE;
 
-	tl->func_done = func_done;
-	tl->data_done = data_done;
+	if (tl->standard_loader)
+		{
+		return thumb_loader_std_start((ThumbLoaderStd *)tl, path);
+		}
 
-	if (enable_thumb_caching)
+	if (!tl->path && !path) return FALSE;
+
+	if (!tl->path) tl->path = g_strdup(path);
+
+	if (tl->cache_enable)
 		{
 		cache_path = cache_find_location(CACHE_TYPE_THUMB, tl->path);
 
@@ -326,7 +362,7 @@ gint thumb_loader_start(ThumbLoader *tl, void (*func_done)(ThumbLoader *, gpoint
 		{
 		thumb_loader_setup(tl, cache_path);
 		g_free(cache_path);
-		tl->from_cache = TRUE;
+		tl->cache_hit = TRUE;
 		}
 	else
 		{
@@ -336,16 +372,16 @@ gint thumb_loader_start(ThumbLoader *tl, void (*func_done)(ThumbLoader *, gpoint
 	if (!image_loader_start(tl->il, thumb_loader_done_cb, tl))
 		{
 		/* try from original if cache attempt */
-		if (tl->from_cache)
+		if (tl->cache_hit)
 			{
-			tl->from_cache = FALSE;
+			tl->cache_hit = FALSE;
 			print_term(_("Thumbnail image in cache failed to load, trying to recreate.\n"));
 
 			thumb_loader_setup(tl, tl->path);
 			if (image_loader_start(tl->il, thumb_loader_done_cb, tl)) return TRUE;
 			}
 		/* mark failed thumbnail in cache with 0 byte file */
-		if (enable_thumb_caching)
+		if (tl->cache_enable)
 			{
 			thumb_loader_mark_failure(tl);
 			}
@@ -358,6 +394,7 @@ gint thumb_loader_start(ThumbLoader *tl, void (*func_done)(ThumbLoader *, gpoint
 	return TRUE;
 }
 
+#if 0
 gint thumb_loader_to_pixmap(ThumbLoader *tl, GdkPixmap **pixmap, GdkBitmap **mask)
 {
 	if (!tl || !tl->pixbuf) return -1;
@@ -366,11 +403,17 @@ gint thumb_loader_to_pixmap(ThumbLoader *tl, GdkPixmap **pixmap, GdkBitmap **mas
 
 	return thumb_loader_get_space(tl);
 }
+#endif
 
 GdkPixbuf *thumb_loader_get_pixbuf(ThumbLoader *tl, gint with_fallback)
 {
 	GdkPixbuf *pixbuf;
 
+	if (tl && tl->standard_loader)
+		{
+		return thumb_loader_std_get_pixbuf((ThumbLoaderStd *)tl, with_fallback);
+		}
+
 	if (tl && tl->pixbuf)
 		{
 		pixbuf = tl->pixbuf;
@@ -380,7 +423,7 @@ GdkPixbuf *thumb_loader_get_pixbuf(ThumbLoader *tl, gint with_fallback)
 		{
 		gint w, h;
 
-		pixbuf = gdk_pixbuf_new_from_xpm_data(img_unknown);
+		pixbuf = pixbuf_inline(PIXBUF_INLINE_BROKEN);
 		w = gdk_pixbuf_get_width(pixbuf);
 		h = gdk_pixbuf_get_height(pixbuf);
 		if ((w > tl->max_w || h > tl->max_h) &&
@@ -401,6 +444,7 @@ GdkPixbuf *thumb_loader_get_pixbuf(ThumbLoader *tl, gint with_fallback)
 	return pixbuf;
 }
 
+#if 0
 gint thumb_loader_get_space(ThumbLoader *tl)
 {
 	if (!tl) return 0;
@@ -409,16 +453,22 @@ gint thumb_loader_get_space(ThumbLoader *tl)
 
 	return tl->max_w;
 }
+#endif
 
-ThumbLoader *thumb_loader_new(gchar *path, gint width, gint height)
+ThumbLoader *thumb_loader_new(gint width, gint height)
 {
 	ThumbLoader *tl;
 
-	if (!path) return NULL;
+	if (thumbnail_spec_standard)
+		{
+		return (ThumbLoader *)thumb_loader_std_new(width, height);
+		}
 
 	tl = g_new0(ThumbLoader, 1);
-	tl->path = g_strdup(path);
-	tl->from_cache = FALSE;
+	tl->standard_loader = FALSE;
+	tl->path = NULL;
+	tl->cache_enable = enable_thumb_caching;
+	tl->cache_hit = FALSE;
 	tl->percent_done = 0.0;
 	tl->max_w = width;
 	tl->max_h = height;
@@ -434,15 +484,22 @@ void thumb_loader_free(ThumbLoader *tl)
 {
 	if (!tl) return;
 
+	if (tl->standard_loader)
+		{
+		thumb_loader_std_free((ThumbLoaderStd *)tl);
+		return;
+		}
+
 	if (tl->pixbuf) gdk_pixbuf_unref(tl->pixbuf);
 	image_loader_free(tl->il);
 	g_free(tl->path);
 
-	if (tl->idle_done_id != -1) gtk_idle_remove(tl->idle_done_id);
+	if (tl->idle_done_id != -1) g_source_remove(tl->idle_done_id);
 
 	g_free(tl);
 }
 
+#if 0
 gint thumb_from_xpm_d(const char **data, gint max_w, gint max_h, GdkPixmap **pixmap, GdkBitmap **mask)
 {
 	GdkPixbuf *pixbuf;
@@ -468,6 +525,7 @@ gint thumb_from_xpm_d(const char **data, gint max_w, gint max_h, GdkPixmap **pix
 
 	return w;
 }
+#endif
 
 /*
  *-----------------------------------------------------------------------------
@@ -522,10 +580,10 @@ static guchar *load_xv_thumbnail(gchar *filename, gint *widthp, gint *heightp)
 
 static gint normalize_thumb(gint *width, gint *height, gint max_w, gint max_h)
 {
-	gfloat scale;
+	gdouble scale;
 	gint new_w, new_h;
 
-	scale = MIN((gfloat) max_w / *width, (gfloat) max_h / *height);
+	scale = MIN((gdouble) max_w / *width, (gdouble) max_h / *height);
 	new_w = *width * scale;
 	new_h = *height * scale;
 
