@@ -33,6 +33,7 @@
 #include "ui_bookmark.h"
 #include "ui_fileops.h"
 #include "ui_menu.h"
+#include "ui_misc.h"
 #include "ui_utildlg.h"
 #include "ui_tabcomp.h"
 #include "ui_tree_edit.h"
@@ -45,6 +46,11 @@
 
 #define PATH_SEL_USE_HEADINGS FALSE
 
+enum {
+	FILTER_COLUMN_NAME = 0,
+	FILTER_COLUMN_FILTER
+};
+
 typedef struct _Dest_Data Dest_Data;
 struct _Dest_Data
 {
@@ -416,13 +422,13 @@ static gint dest_view_rename_cb(TreeEditData *ted, const gchar *old, const gchar
 	if (isname(new_path))
 		{
 		buf = g_strdup_printf(_("A file with name %s already exists."), new);
-		warning_dialog("Rename failed", buf, dd->entry);
+		warning_dialog("Rename failed", buf, GTK_STOCK_DIALOG_INFO, dd->entry);
 		g_free(buf);
 		}
 	else if (!rename_file(old_path, new_path))
 		{
 		buf = g_strdup_printf(_("Failed to rename %s to %s."), old, new);
-		warning_dialog("Rename failed", buf, dd->entry);
+		warning_dialog("Rename failed", buf, GTK_STOCK_DIALOG_ERROR, dd->entry);
 		g_free(buf);
 		}
 	else
@@ -478,7 +484,7 @@ static void dest_view_delete_dlg_ok_cb(GenericDialog *gd, gpointer data)
 	if (!unlink_file(dl->path))
 		{
 		gchar *text = g_strdup_printf(_("Unable to delete file:\n%s"), dl->path);
-		warning_dialog(_("File deletion failed"), text, dl->dd->entry);
+		warning_dialog(_("File deletion failed"), text, GTK_STOCK_DIALOG_WARNING, dl->dd->entry);
 		g_free(text);
 		}
 	else if (dl->dd->path)
@@ -520,13 +526,16 @@ static void dest_view_delete(Dest_Data *dd, GtkTreeView *view)
 		generic_dialog_close(gd);
 		}
 
-	text = g_strdup_printf(_("About to delete the file:\n %s"), path);
-	dd->gd = generic_dialog_new(_("Delete file"), text, "SLIK", "dlg_confirm",
+	dd->gd = generic_dialog_new(_("Delete file"), PACKAGE, "dlg_confirm",
 				    dd->entry, TRUE,
 				    dest_view_delete_dlg_cancel, dl);
-	g_free(text);
 
-	generic_dialog_add_stock(dd->gd, _("Delete"), GTK_STOCK_DELETE, dest_view_delete_dlg_ok_cb, TRUE);
+	generic_dialog_add_button(dd->gd, GTK_STOCK_DELETE, NULL, dest_view_delete_dlg_ok_cb, TRUE);
+
+	text = g_strdup_printf(_("About to delete the file:\n %s"), path);
+	generic_dialog_add_message(dd->gd, GTK_STOCK_DIALOG_QUESTION,
+				   _("Delete file"), text);
+	g_free(text);
 
 	gtk_widget_show(dd->gd->dialog);
 }
@@ -739,7 +748,7 @@ static void dest_new_dir_cb(GtkWidget *widget, gpointer data)
 		gchar *text;
 
 		text = g_strdup_printf(_("Unable to create folder:\n%s"), filename_from_path(path));
-		warning_dialog(_("Error creating folder"), text, dd->entry);
+		warning_dialog(_("Error creating folder"), text, GTK_STOCK_DIALOG_ERROR, dd->entry);
 		g_free(text);
 		}
 	else
@@ -873,36 +882,44 @@ static void dest_entry_changed_cb(GtkEditable *editable, gpointer data)
 
 static void dest_filter_list_sync(Dest_Data *dd)
 {
+	GtkWidget *entry;
+	GtkListStore *store;
 	gchar *old_text;
-	GList *clist;
 	GList *fwork;
-	GList *cwork;
+	GList *twork;
 
 	if (!dd->filter_list || !dd->filter_combo) return;
 
-	old_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(dd->filter_combo)->entry)));
+	entry = GTK_BIN(dd->filter_combo)->child;
+	old_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(entry)));
 
-	gtk_combo_set_popdown_strings(GTK_COMBO(dd->filter_combo), dd->filter_text_list);
-	clist = gtk_container_get_children(GTK_CONTAINER(GTK_COMBO(dd->filter_combo)->list));
+	store = GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(dd->filter_combo)));
+	gtk_list_store_clear(store);
 
 	fwork = dd->filter_list;
-	cwork = clist;
-	while (fwork && cwork)
+	twork = dd->filter_text_list;
+	while (fwork && twork)
 		{
-		gchar *filter = fwork->data;
+		GtkTreeIter iter;
+		gchar *name;
+		gchar *filter;
 
-		gtk_combo_set_item_string(GTK_COMBO(dd->filter_combo), GTK_ITEM(cwork->data), filter);
+		name = twork->data;
+		filter = fwork->data;
+
+		gtk_list_store_append(store, &iter);
+		gtk_list_store_set(store, &iter, FILTER_COLUMN_NAME, name,
+						 FILTER_COLUMN_FILTER, filter, -1);
 
 		if (strcmp(old_text, filter) == 0)
 			{
-			gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dd->filter_combo)->entry), filter);
+			gtk_combo_box_set_active_iter(GTK_COMBO_BOX(dd->filter_combo), &iter);
 			}
 
 		fwork = fwork->next;
-		cwork = cwork->next;
+		twork = twork->next;
 		}
 
-	g_list_free(clist);
 	g_free(old_text);
 }
 
@@ -915,13 +932,13 @@ static void dest_filter_add(Dest_Data *dd, const gchar *filter, const gchar *des
 	if (!filter) return;
 
 	work = dd->filter_list;
-	while(work)
+	while (work)
 		{
 		gchar *f = work->data;
 
 		if (strcmp(f, filter) == 0)
 			{
-			if (set) gtk_combo_set_value_in_list(GTK_COMBO(dd->filter_combo), c, FALSE);
+			if (set) gtk_combo_box_set_active(GTK_COMBO_BOX(dd->filter_combo), c);
 			return;
 			}
 		work = work->next;
@@ -940,7 +957,7 @@ static void dest_filter_add(Dest_Data *dd, const gchar *filter, const gchar *des
 		}
 	dd->filter_text_list = uig_list_insert_link(dd->filter_text_list, g_list_last(dd->filter_text_list), buf);
 
-	if (set) gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dd->filter_combo)->entry), filter);
+	if (set) gtk_entry_set_text(GTK_ENTRY(GTK_BIN(dd->filter_combo)->child), filter);
 	dest_filter_list_sync(dd);
 }
 
@@ -958,11 +975,12 @@ static void dest_filter_clear(Dest_Data *dd)
 static void dest_filter_changed_cb(GtkEditable *editable, gpointer data)
 {
 	Dest_Data *dd = data;
+	GtkWidget *entry;
 	const gchar *buf;
 	gchar *path;
 
-	buf = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(dd->filter_combo)->entry));
-	if (GTK_WIDGET_VISIBLE(GTK_COMBO(dd->filter_combo)->list) && strlen(buf) == 0) return;
+	entry = GTK_BIN(dd->filter_combo)->child;
+	buf = gtk_entry_get_text(GTK_ENTRY(entry));
 
 	g_free(dd->filter);
 	dd->filter = NULL;
@@ -999,7 +1017,6 @@ GtkWidget *path_selection_new_with_files(GtkWidget *entry, const gchar *path,
 	GtkWidget *hbox2;
 	Dest_Data *dd;
 	GtkWidget *scrolled;
-	GtkWidget *button;
 	GtkWidget *table;
 	GtkWidget *paned;
 	GtkListStore *store;
@@ -1014,29 +1031,19 @@ GtkWidget *path_selection_new_with_files(GtkWidget *entry, const gchar *path,
 	dd->gd = NULL;
 
 	table = gtk_table_new(4, (filter != NULL) ? 3 : 1, FALSE);
-	gtk_table_set_col_spacings(GTK_TABLE(table), 5);
-	gtk_table_set_row_spacing(GTK_TABLE(table), 0, 5);
+	gtk_table_set_col_spacings(GTK_TABLE(table), PREF_PAD_GAP);
+	gtk_table_set_row_spacing(GTK_TABLE(table), 0, PREF_PAD_GAP);
 	gtk_widget_show(table);
 
 	dd->entry = entry;
 	g_object_set_data(G_OBJECT(dd->entry), "destination_data", dd);
 
-	hbox2 = gtk_hbox_new(FALSE, 5);
-	gtk_table_attach(GTK_TABLE(table), hbox2, 0, 1, 0, 1,
-			 GTK_EXPAND | GTK_FILL, FALSE, 0, 0);
-	gtk_widget_show(hbox2);
-
-	button = gtk_button_new_with_label(_("Home"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(dest_home_cb), dd);
-	gtk_box_pack_start(GTK_BOX(hbox2), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
-
-	button = gtk_button_new_with_label(_("New folder"));
-	g_signal_connect(G_OBJECT(button), "clicked",
-			 G_CALLBACK(dest_new_dir_cb), dd);
-	gtk_box_pack_start(GTK_BOX(hbox2), button, FALSE, FALSE, 0);
-	gtk_widget_show(button);
+	hbox2 = pref_table_box(table, 0, 0, GTK_ORIENTATION_HORIZONTAL, NULL);
+	gtk_box_set_spacing(GTK_BOX(hbox2), PREF_PAD_BUTTON_GAP);
+	pref_button_new(hbox2, NULL, _("Home"), FALSE,
+			G_CALLBACK(dest_home_cb), dd);
+	pref_button_new(hbox2, NULL, _("New folder"), FALSE,
+			G_CALLBACK(dest_new_dir_cb), dd);
 
 	dd->hidden_button = gtk_check_button_new_with_label(_("Show hidden"));
 	g_signal_connect(G_OBJECT(dd->hidden_button), "clicked",
@@ -1044,7 +1051,7 @@ GtkWidget *path_selection_new_with_files(GtkWidget *entry, const gchar *path,
 	gtk_box_pack_end(GTK_BOX(hbox2), dd->hidden_button, FALSE, FALSE, 0);
 	gtk_widget_show(dd->hidden_button);
 
-	hbox2 = gtk_hbox_new(FALSE, 5);
+	hbox2 = gtk_hbox_new(FALSE, PREF_PAD_GAP);
 	if (filter)
 		{
 		paned = gtk_hpaned_new();
@@ -1119,19 +1126,24 @@ GtkWidget *path_selection_new_with_files(GtkWidget *entry, const gchar *path,
 	
 	if (filter)
 		{
-		GtkWidget *label;
+		GtkListStore *store;
 
-		hbox2 = gtk_hbox_new(FALSE, 5);
-		gtk_table_attach(GTK_TABLE(table), hbox2, 2, 3, 0, 1,
-				 GTK_EXPAND | GTK_FILL, FALSE, 0, 0);
-		gtk_widget_show(hbox2);
+		hbox2 = pref_table_box(table, 2, 0, GTK_ORIENTATION_HORIZONTAL, NULL);
+		pref_label_new(hbox2, _("Filter:"));
 
-		label = gtk_label_new(_("Filter:"));
-		gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
-		gtk_widget_show(label);
+		store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
 
-		dd->filter_combo = gtk_combo_new();
+		dd->filter_combo = gtk_combo_box_entry_new_with_model(GTK_TREE_MODEL(store),
+								      FILTER_COLUMN_FILTER);
+		g_object_unref(store);
+		gtk_cell_layout_clear(GTK_CELL_LAYOUT(dd->filter_combo));
+		renderer = gtk_cell_renderer_text_new();
+		gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(dd->filter_combo), renderer, TRUE);
+		gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(dd->filter_combo), renderer,
+					       "text", FILTER_COLUMN_NAME, NULL);
+#if 0
 		gtk_combo_set_case_sensitive(GTK_COMBO(dd->filter_combo), TRUE);
+#endif
 		gtk_box_pack_start(GTK_BOX(hbox2), dd->filter_combo, TRUE, TRUE, 0);
 		gtk_widget_show(dd->filter_combo);
 
@@ -1185,7 +1197,7 @@ GtkWidget *path_selection_new_with_files(GtkWidget *entry, const gchar *path,
 		dest_filter_clear(dd);
 		dest_filter_add(dd, filter, filter_desc, TRUE);
 
-		dd->filter = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(dd->filter_combo)->entry)));
+		dd->filter = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(dd->filter_combo)->child)));
 		}
 
 	if (path && path[0] == '/' && isdir(path))
@@ -1212,7 +1224,7 @@ GtkWidget *path_selection_new_with_files(GtkWidget *entry, const gchar *path,
 
 	if (dd->filter_combo)
 		{
-		g_signal_connect(G_OBJECT(GTK_COMBO(dd->filter_combo)->entry), "changed",
+		g_signal_connect(G_OBJECT(GTK_BIN(dd->filter_combo)->child), "changed",
 				 G_CALLBACK(dest_filter_changed_cb), dd);
 		}
 	g_signal_connect(G_OBJECT(dd->entry), "changed",
