@@ -584,21 +584,21 @@ static void tab_completion_button_pressed(GtkWidget *widget, gpointer data)
 
 static void tab_completion_button_size_allocate(GtkWidget *button, GtkAllocation *allocation, gpointer data)
 {
-	GtkWidget *entry = data;
+	GtkWidget *parent = data;
 
-	if (allocation->height > entry->requisition.height)
+	if (allocation->height > parent->allocation.height)
 		{
 		GtkAllocation button_allocation;
 
 		button_allocation = button->allocation;
-		button_allocation.height = entry->requisition.height;
-		button_allocation.y = entry->allocation.y +
-			(entry->allocation.height - entry->requisition.height) / 2;
+		button_allocation.height = parent->allocation.height;
+		button_allocation.y = parent->allocation.y +
+			(parent->allocation.height - parent->allocation.height) / 2;
 		gtk_widget_size_allocate(button, &button_allocation);
 		}
 }
 
-static GtkWidget *tab_completion_create_complete_button(GtkWidget *entry)
+static GtkWidget *tab_completion_create_complete_button(GtkWidget *entry, GtkWidget *parent)
 {
 	GtkWidget *button;
 	GtkWidget *icon;
@@ -607,7 +607,7 @@ static GtkWidget *tab_completion_create_complete_button(GtkWidget *entry)
 	button = gtk_button_new();
 	GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
 	g_signal_connect(G_OBJECT(button), "size_allocate",
-			 G_CALLBACK(tab_completion_button_size_allocate), entry);
+			 G_CALLBACK(tab_completion_button_size_allocate), parent);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(tab_completion_button_pressed), entry);
 
@@ -630,23 +630,33 @@ GtkWidget *tab_completion_new_with_history(GtkWidget **entry, const gchar *text,
 					   const gchar *history_key, gint max_levels,
 					   void (*enter_func)(const gchar *, gpointer), gpointer data)
 {
+	GtkWidget *box;
 	GtkWidget *combo;
+	GtkWidget *combo_entry;
 	GtkWidget *button;
-	GList *list;
+	GList *work;
 	TabCompData *td;
+	gint n = 0;
 
-	combo = gtk_combo_new();
+	box = gtk_hbox_new(FALSE, 0);
+
+	combo = gtk_combo_box_entry_new_text();
+	gtk_box_pack_start(GTK_BOX(box), combo, TRUE, TRUE, 0);
+	gtk_widget_show(combo);
+
+	combo_entry = GTK_BIN(combo)->child;
+#if 0
 	gtk_combo_set_case_sensitive(GTK_COMBO(combo), TRUE);
 	gtk_combo_set_use_arrows(GTK_COMBO(combo), FALSE);
+#endif
 
-	button = tab_completion_create_complete_button(GTK_COMBO(combo)->entry);
-	gtk_box_pack_start(GTK_BOX(combo), button, FALSE, FALSE, 0);
-	gtk_box_reorder_child(GTK_BOX(combo), button, 1);
+	button = tab_completion_create_complete_button(combo_entry, combo);
+	gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
-	
-	tab_completion_add_to_entry(GTK_COMBO(combo)->entry, enter_func, data);
 
-	td = g_object_get_data(G_OBJECT(GTK_COMBO(combo)->entry), "tab_completion_data");
+	tab_completion_add_to_entry(combo_entry, enter_func, data);
+
+	td = g_object_get_data(G_OBJECT(combo_entry), "tab_completion_data");
 	if (!td) return NULL; /* this should never happen! */
 
 	td->combo = combo;
@@ -654,16 +664,27 @@ GtkWidget *tab_completion_new_with_history(GtkWidget **entry, const gchar *text,
 	td->history_key = g_strdup(history_key);
 	td->history_levels = max_levels;
 
-	list = history_list_get_by_key(td->history_key);
-	if (list)
+	work = history_list_get_by_key(td->history_key);
+
+	work = history_list_get_by_key(history_key);
+	while (work)
 		{
-		gtk_combo_set_popdown_strings(GTK_COMBO(combo), list);
+		gtk_combo_box_append_text(GTK_COMBO_BOX(combo), (gchar *)work->data);
+		work = work->next;
+		n++;
 		}
 
-	if (text) gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry), text);
+	if (text)
+		{
+		gtk_entry_set_text(GTK_ENTRY(combo_entry), text);
+		}
+	else if (n > 0)
+		{
+		gtk_combo_box_set_active(GTK_COMBO_BOX(combo), 0);
+		}
 
-	if (entry) *entry = GTK_COMBO(combo)->entry;
-	return combo;
+	if (entry) *entry = combo_entry;
+	return box;
 }
 
 const gchar *tab_completion_set_to_last_history(GtkWidget *entry)
@@ -684,26 +705,28 @@ const gchar *tab_completion_set_to_last_history(GtkWidget *entry)
 
 void tab_completion_append_to_history(GtkWidget *entry, const gchar *path)
 {
-	TabCompData *td = g_object_get_data(G_OBJECT(entry), "tab_completion_data");
-	GList *list;
+	TabCompData *td;
+	GtkTreeModel *store;
+	GList *work;
+
+	td = g_object_get_data(G_OBJECT(entry), "tab_completion_data");
 
 	if (!path) return;
 
 	if (!td || !td->has_history) return;
 
 	history_list_add_to_key(td->history_key, path, td->history_levels);
-	list = history_list_get_by_key(td->history_key);
-	if (list)
-		{
-		gchar *buf;
 
-		buf = g_strdup(gtk_entry_get_text(GTK_ENTRY(td->entry)));
-		gtk_combo_set_popdown_strings(GTK_COMBO(td->combo), list);
-		if (strcmp(buf, gtk_entry_get_text(GTK_ENTRY(td->entry))) != 0)
-			{
-			gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
-			}
-		g_free(buf);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(td->combo), -1);
+
+	store = gtk_combo_box_get_model(GTK_COMBO_BOX(td->combo));
+	gtk_list_store_clear(GTK_LIST_STORE(store));
+
+	work = history_list_get_by_key(td->history_key);
+	while (work)
+		{
+		gtk_combo_box_append_text(GTK_COMBO_BOX(td->combo), (gchar *)work->data);
+		work = work->next;
 		}
 }
 
@@ -721,7 +744,7 @@ GtkWidget *tab_completion_new(GtkWidget **entry, const gchar *text,
 	gtk_box_pack_start(GTK_BOX(hbox), newentry, TRUE, TRUE, 0);
 	gtk_widget_show(newentry);
 
-	button = tab_completion_create_complete_button(newentry);
+	button = tab_completion_create_complete_button(newentry, newentry);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
@@ -788,10 +811,6 @@ static void tab_completion_select_cancel_cb(FileDialog *fd, gpointer data)
 {
 	TabCompData *td = data;
 
-#if 0
-	gtk_widget_set_sensitive(td->fd_button, TRUE);
-#endif
-
 	td->fd = NULL;
 	file_dialog_close(fd);
 }
@@ -803,6 +822,8 @@ static void tab_completion_select_ok_cb(FileDialog *fd, gpointer data)
 	gtk_entry_set_text(GTK_ENTRY(td->entry), gtk_entry_get_text(GTK_ENTRY(fd->entry)));
 
 	tab_completion_select_cancel_cb(fd, data);
+
+	tab_completion_emit_enter_signal(td);
 }
 
 static void tab_completion_select_show(TabCompData *td)
@@ -816,16 +837,14 @@ static void tab_completion_select_show(TabCompData *td)
 		return;
 		}
 
-#if 0
-	gtk_widget_set_sensitive(td->fd_button, FALSE);
-#endif
-
 	title = (td->fd_title) ? td->fd_title : _("Select path");
-	td->fd = file_dialog_new(title, NULL, "SLIK", "select_path", td->entry,
+	td->fd = file_dialog_new(title, PACKAGE, "select_path", td->entry,
 				 tab_completion_select_cancel_cb, td);
-	file_dialog_add_button_stock(td->fd, NULL, GTK_STOCK_OK,
+	file_dialog_add_button(td->fd, GTK_STOCK_OK, NULL,
 				 tab_completion_select_ok_cb, TRUE);
 
+	generic_dialog_add_message(GENERIC_DIALOG(td->fd), NULL, title, NULL);
+
 	path = gtk_entry_get_text(GTK_ENTRY(td->entry));
 	if (strlen(path) == 0) path = NULL;
 	if (td->fd_folders_only)
@@ -849,9 +868,12 @@ static void tab_completion_select_pressed(GtkWidget *widget, gpointer data)
 
 void tab_completion_add_select_button(GtkWidget *entry, const gchar *title, gint folders_only)
 {
-	TabCompData *td = g_object_get_data(G_OBJECT(entry), "tab_completion_data");
+	TabCompData *td;
+	GtkWidget *parent;
 	GtkWidget *hbox;
 
+	td = g_object_get_data(G_OBJECT(entry), "tab_completion_data");
+
 	if (!td) return;
 
 	g_free(td->fd_title);
@@ -860,19 +882,18 @@ void tab_completion_add_select_button(GtkWidget *entry, const gchar *title, gint
 
 	if (td->fd_button) return;
 
-	hbox = gtk_widget_get_parent(td->entry);
+	parent = (td->combo) ? td->combo : td->entry;
+
+	hbox = gtk_widget_get_parent(parent);
 	if (!GTK_IS_BOX(hbox)) return;
 
 	td->fd_button = gtk_button_new_with_label("...");
 	g_signal_connect(G_OBJECT(td->fd_button), "size_allocate",
-			 G_CALLBACK(tab_completion_button_size_allocate), td->entry);
+			 G_CALLBACK(tab_completion_button_size_allocate), parent);
 	g_signal_connect(G_OBJECT(td->fd_button), "clicked",
 			 G_CALLBACK(tab_completion_select_pressed), td);
 
 	gtk_box_pack_start(GTK_BOX(hbox), td->fd_button, FALSE, FALSE, 0);
-#if 0
-	gtk_box_reorder_child(GTK_BOX(hbox), td->fd_button, 0);
-#endif
 
 	gtk_widget_show(td->fd_button);
 }
