@@ -24,6 +24,7 @@
 #include "search.h"
 #include "ui_bookmark.h"
 #include "ui_fileops.h"
+#include "ui_misc.h"
 #include "ui_tabcomp.h"
 
 
@@ -36,12 +37,13 @@
 
 void file_maint_renamed(const gchar *source, const gchar *dest)
 {
+	cache_maint_moved(source, dest);
+	collection_maint_renamed(source, dest);
+
 	layout_maint_renamed(source, dest);
 	view_window_maint_moved(source, dest);
-	collection_maint_renamed(source, dest);
 	dupe_maint_renamed(source, dest);
 	search_maint_renamed(source, dest);
-	cache_maint_moved(source, dest);
 }
 
 /* under most cases ignore_list should be NULL */
@@ -49,21 +51,23 @@ void file_maint_removed(const gchar *path, GList *ignore_list)
 {
 	layout_maint_removed(path, ignore_list);
 	view_window_maint_removed(path, ignore_list);
-	collection_maint_removed(path);
 	dupe_maint_removed(path);
 	search_maint_removed(path);
+
+	collection_maint_removed(path);
 	cache_maint_removed(path);
 }
 
 /* special case for correct main window behavior */
 void file_maint_moved(const gchar *source, const gchar *dest, GList *ignore_list)
 {
+	cache_maint_moved(source, dest);
+	collection_maint_renamed(source, dest);
+
 	layout_maint_moved(source, dest, ignore_list);
 	view_window_maint_moved(source, dest);
-	collection_maint_renamed(source, dest);
 	dupe_maint_renamed(source, dest);
 	search_maint_renamed(source, dest);
-	cache_maint_moved(source, dest);
 }
 
 void file_maint_copied(const gchar *source, const gchar *dest)
@@ -135,42 +139,58 @@ struct _FileDataSingle
 #define DIALOG_DEF_IMAGE_DIM_X 200
 #define DIALOG_DEF_IMAGE_DIM_Y 150
 
-static void generic_dialog_image_add(GenericDialog *gd, const gchar *path1, const gchar *path2)
+static void generic_dialog_add_image(GenericDialog *gd, const gchar *path1, const gchar *header1,
+				     const gchar *path2, const gchar *header2,
+				     gint show_filename)
 {
 	ImageWindow *imd;
 	GtkWidget *hbox = NULL;
 	GtkWidget *vbox;
-	GtkWidget *label;
+	GtkWidget *label = NULL;
 
 	if (path2)
 		{
-		hbox = gtk_hbox_new(TRUE, 5);
-		gtk_box_pack_start(GTK_BOX(gd->vbox), hbox, TRUE, TRUE, 5);
-		gtk_widget_show(hbox);
+		hbox = pref_box_new(gd->vbox, TRUE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_SPACE);
 		}
 
 	/* image 1 */
 
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_vbox_new(FALSE, PREF_PAD_GAP);
 	if (hbox)
 		{
+		GtkWidget *sep;
+
 		gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
+
+		sep = gtk_vseparator_new();
+		gtk_box_pack_start(GTK_BOX(hbox), sep, FALSE, FALSE, 0);
+		gtk_widget_show(sep);
 		}
 	else
 		{
-		gtk_box_pack_start(GTK_BOX(gd->vbox), vbox, TRUE, TRUE, 5);
+		gtk_box_pack_start(GTK_BOX(gd->vbox), vbox, TRUE, TRUE, PREF_PAD_GAP);
 		}
 	gtk_widget_show(vbox);
 
-	imd = image_new(TRUE);
+	if (header1)
+		{
+		GtkWidget *head;
+
+		head = pref_label_new(vbox, header1);
+		pref_label_bold(head, TRUE, FALSE);
+		gtk_misc_set_alignment(GTK_MISC(head), 0.0, 0.5);
+		}
+
+	imd = image_new(FALSE);
 	gtk_widget_set_size_request(imd->widget, DIALOG_DEF_IMAGE_DIM_X, DIALOG_DEF_IMAGE_DIM_Y);
 	gtk_box_pack_start(GTK_BOX(vbox), imd->widget, TRUE, TRUE, 0);
 	image_change_path(imd, path1, 0.0);
 	gtk_widget_show(imd->widget);
 
-	label = gtk_label_new((path1 == NULL) ? "" : filename_from_path(path1));
-	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
+	if (show_filename)
+		{
+		label = pref_label_new(vbox, (path1 == NULL) ? "" : filename_from_path(path1));
+		}
 
 	/* only the first image is stored (for use in gd_image_set) */
 	g_object_set_data(G_OBJECT(gd->dialog), "img_image", imd);
@@ -181,19 +201,24 @@ static void generic_dialog_image_add(GenericDialog *gd, const gchar *path1, cons
 
 	if (hbox && path2)
 		{
-		vbox = gtk_vbox_new(FALSE, 0);
-		gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
-		gtk_widget_show(vbox);
+		vbox = pref_box_new(hbox, TRUE, GTK_ORIENTATION_VERTICAL, PREF_PAD_GAP);
 
-		imd = image_new(TRUE);
+		if (header2)
+			{
+			GtkWidget *head;
+
+			head = pref_label_new(vbox, header2);
+			pref_label_bold(head, TRUE, FALSE);
+			gtk_misc_set_alignment(GTK_MISC(head), 0.0, 0.5);
+			}
+
+		imd = image_new(FALSE);
 		gtk_widget_set_size_request(imd->widget, DIALOG_DEF_IMAGE_DIM_X, DIALOG_DEF_IMAGE_DIM_Y);
 		gtk_box_pack_start(GTK_BOX(vbox), imd->widget, TRUE, TRUE, 0);
 		image_change_path(imd, path2, 0.0);
 		gtk_widget_show(imd->widget);
 
-		label = gtk_label_new(filename_from_path(path2));
-		gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
-		gtk_widget_show(label);
+		pref_label_new(vbox, filename_from_path(path2));
 		}
 }
 
@@ -205,10 +230,10 @@ static void generic_dialog_image_set(GenericDialog *gd, const gchar *path)
 	imd = g_object_get_data(G_OBJECT(gd->dialog), "img_image");
 	label = g_object_get_data(G_OBJECT(gd->dialog), "img_label");
 
-	if (!imd || !label) return;
+	if (!imd) return;
 
 	image_change_path(imd, path, 0.0);
-	gtk_label_set_text(GTK_LABEL(label), filename_from_path(path));
+	if (label) gtk_label_set_text(GTK_LABEL(label), filename_from_path(path));
 }
 
 /*
@@ -217,14 +242,14 @@ static void generic_dialog_image_set(GenericDialog *gd, const gchar *path)
  *--------------------------------------------------------------------------
  */
 
-GenericDialog *file_util_gen_dlg(const gchar *title, const gchar *message,
+GenericDialog *file_util_gen_dlg(const gchar *title,
 				 const gchar *wmclass, const gchar *wmsubclass,
 				 GtkWidget *parent, gint auto_close,
 				 void (*cancel_cb)(GenericDialog *, gpointer), gpointer data)
 {
 	GenericDialog *gd;
 
-	gd = generic_dialog_new(title, message, wmclass, wmsubclass, parent, auto_close, cancel_cb, data);
+	gd = generic_dialog_new(title, wmclass, wmsubclass, parent, auto_close, cancel_cb, data);
 	if (place_dialogs_under_mouse)
 		{
 		gtk_window_set_position(GTK_WINDOW(gd->dialog), GTK_WIN_POS_MOUSE);
@@ -233,14 +258,14 @@ GenericDialog *file_util_gen_dlg(const gchar *title, const gchar *message,
 	return gd;
 }
 
-FileDialog *file_util_file_dlg(const gchar *title, const gchar *message,
+FileDialog *file_util_file_dlg(const gchar *title,
 			       const gchar *wmclass, const gchar *wmsubclass,
 			       GtkWidget *parent,
 			       void (*cancel_cb)(FileDialog *, gpointer), gpointer data)
 {
 	FileDialog *fd;
 
-	fd = file_dialog_new(title, message, wmclass, wmsubclass, parent, cancel_cb, data);
+	fd = file_dialog_new(title, wmclass, wmsubclass, parent, cancel_cb, data);
 	if (place_dialogs_under_mouse)
 		{
 		gtk_window_set_position(GTK_WINDOW(GENERIC_DIALOG(fd)->dialog), GTK_WIN_POS_MOUSE);
@@ -258,12 +283,14 @@ static void file_util_warning_dialog_ok_cb(GenericDialog *gd, gpointer data)
 	/* no op */
 }
 
-GenericDialog *file_util_warning_dialog(const gchar *title, const gchar *message, GtkWidget *parent)
+GenericDialog *file_util_warning_dialog(const gchar *heading, const gchar *message,
+					const gchar *icon_stock_id, GtkWidget *parent)
 {
 	GenericDialog *gd;
 
-	gd = file_util_gen_dlg(title, message, "GQview", "warning", parent, TRUE, NULL, NULL);
-	generic_dialog_add_stock(gd, _("Ok"), GTK_STOCK_OK, file_util_warning_dialog_ok_cb, TRUE);
+	gd = file_util_gen_dlg(heading, "GQview", "warning", parent, TRUE, NULL, NULL);
+	generic_dialog_add_message(gd, icon_stock_id, heading, message);
+	generic_dialog_add_button(gd, GTK_STOCK_OK, NULL, file_util_warning_dialog_ok_cb, TRUE);
 	if (place_dialogs_under_mouse)
 		{
 		gtk_window_set_position(GTK_WINDOW(gd->dialog), GTK_WIN_POS_MOUSE);
@@ -438,21 +465,23 @@ static void file_util_move_multiple_rename_cb(GtkWidget *widget, gpointer data)
 static GenericDialog *file_util_move_multiple_confirm_dialog(FileDataMult *fdm)
 {
 	GenericDialog *gd;
-	gchar *text;
 	GtkWidget *hbox;
 
-	text = g_strdup_printf(_("Overwrite file:\n %s\n with:\n %s"), fdm->dest, fdm->source);
-	gd = file_util_gen_dlg(_("Overwrite file"), text, "GQview", "dlg_confirm",
+	gd = file_util_gen_dlg(_("Overwrite file"), "GQview", "dlg_confirm",
 				NULL, TRUE,
 				file_util_move_multiple_cancel_cb, fdm);
-	g_free(text);
 
-	generic_dialog_add_stock(gd, _("Yes"), GTK_STOCK_YES, file_util_move_multiple_ok_cb, TRUE);
-	fdm->yes_all_button = generic_dialog_add(gd, _("Yes to all"),
-						 file_util_move_multiple_all_cb, FALSE);
-	generic_dialog_add_stock(gd, _("Skip"), GTK_STOCK_GO_FORWARD, file_util_move_multiple_skip_cb, FALSE);
-	generic_dialog_add_stock(gd, _("Skip all"), GTK_STOCK_GOTO_LAST, file_util_move_multiple_skip_all_cb, FALSE);
-	generic_dialog_image_add(gd, fdm->dest, fdm->source);
+	generic_dialog_add_message(gd, GTK_STOCK_DIALOG_QUESTION,
+				   _("Overwrite file?"),
+				   _("Replace existing file with new file."));
+	pref_spacer(gd->vbox, 0);
+
+	generic_dialog_add_button(gd, GTK_STOCK_YES, _("_Overwrite"), file_util_move_multiple_ok_cb, TRUE);
+	fdm->yes_all_button = generic_dialog_add_button(gd, NULL, _("Overwrite _all"),
+							file_util_move_multiple_all_cb, FALSE);
+	generic_dialog_add_button(gd, GTK_STOCK_GOTO_LAST, _("S_kip all"), file_util_move_multiple_skip_all_cb, FALSE);
+	generic_dialog_add_button(gd, GTK_STOCK_GO_FORWARD, _("_Skip"), file_util_move_multiple_skip_cb, FALSE);
+	generic_dialog_add_image(gd, fdm->dest, _("Existing file"), fdm->source, _("New file"), TRUE);
 
 	/* rename option */
 
@@ -460,9 +489,7 @@ static GenericDialog *file_util_move_multiple_confirm_dialog(FileDataMult *fdm)
 	fdm->rename_all = FALSE;
 	fdm->rename_auto = FALSE;
 
-	hbox = gtk_hbox_new(FALSE, 5);
-	gtk_box_pack_start(GTK_BOX(gd->vbox), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
+	hbox = pref_box_new(gd->vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
 
 	fdm->rename_auto_box = gtk_check_button_new_with_label(_("Auto rename"));
 	g_signal_connect(G_OBJECT(fdm->rename_auto_box), "clicked",
@@ -470,9 +497,7 @@ static GenericDialog *file_util_move_multiple_confirm_dialog(FileDataMult *fdm)
 	gtk_box_pack_start(GTK_BOX(hbox), fdm->rename_auto_box, FALSE, FALSE, 0);
 	gtk_widget_show(fdm->rename_auto_box);
 
-	hbox = gtk_hbox_new(FALSE, 5);
-	gtk_box_pack_start(GTK_BOX(gd->vbox), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
+	hbox = pref_box_new(gd->vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
 
 	fdm->rename_box = gtk_check_button_new_with_label(_("Rename"));
 	g_signal_connect(G_OBJECT(fdm->rename_box), "clicked",
@@ -524,11 +549,12 @@ static void file_util_move_multiple(FileDataMult *fdm)
 					text = g_strdup_printf(_("Unable to move file:\n%s\nto itself."), fdm->dest);
 					}
 
-				gd = file_util_gen_dlg(title, text, "GQview", "dlg_confirm",
+				gd = file_util_gen_dlg(title, "GQview", "dlg_confirm",
 							NULL, TRUE,
 							file_util_move_multiple_cancel_cb, fdm);
+				generic_dialog_add_message(gd, GTK_STOCK_DIALOG_WARNING, title, text);
 				g_free(text);
-				generic_dialog_add_stock(gd, _("Continue"), GTK_STOCK_GO_FORWARD,
+				generic_dialog_add_button(gd, GTK_STOCK_GO_FORWARD, _("Co_ntinue"),
 							 file_util_move_multiple_continue_cb, TRUE);
 
 				gtk_widget_show(gd->dialog);
@@ -576,7 +602,7 @@ static void file_util_move_multiple(FileDataMult *fdm)
 				{
 				if (fdm->copy)
 					{
-					if (copy_file(fdm->source, fdm->dest));
+					if (copy_file(fdm->source, fdm->dest))
 						{
 						success = TRUE;
 						file_maint_copied(fdm->source, fdm->dest);
@@ -593,9 +619,6 @@ static void file_util_move_multiple(FileDataMult *fdm)
 				}
 			}
 
-		g_free(fdm->dest);
-		fdm->dest = NULL;
-
 		if (!success)
 			{
 			GenericDialog *gd;
@@ -612,15 +635,21 @@ static void file_util_move_multiple(FileDataMult *fdm)
 				title = _("Error moving file");
 				text = g_strdup_printf(_("Unable to move file:\n%s\nto:\n%s\nduring multiple file move."), fdm->source, fdm->dest);
 				}
-			gd = file_util_gen_dlg(title, text, "GQview", "dlg_confirm",
+			gd = file_util_gen_dlg(title, "GQview", "dlg_confirm",
 						NULL, TRUE,
 						file_util_move_multiple_cancel_cb, fdm);
+			generic_dialog_add_message(gd, GTK_STOCK_DIALOG_WARNING, title, text);
 			g_free(text);
 
-			generic_dialog_add_stock(gd, _("Continue"), GTK_STOCK_GO_FORWARD, file_util_move_multiple_continue_cb, TRUE);
+			generic_dialog_add_button(gd, GTK_STOCK_GO_FORWARD, _("Co_ntinue"),
+						  file_util_move_multiple_continue_cb, TRUE);
 			gtk_widget_show(gd->dialog);
-			return;
 			}
+
+		g_free(fdm->dest);
+		fdm->dest = NULL;
+
+		if (!success) return;
 		}
 
 	file_data_multiple_free(fdm);
@@ -743,32 +772,32 @@ static void file_util_move_single(FileDataSingle *fds)
 	if (fds->dest && fds->source && strcmp(fds->dest, fds->source) == 0)
 		{
 		file_util_warning_dialog(_("Source matches destination"),
-					 _("Source and destination are the same, operation cancelled."), NULL);
+					 _("Source and destination are the same, operation cancelled."),
+					 GTK_STOCK_DIALOG_INFO, NULL);
 		}
 	else if (isfile(fds->dest) && !fds->confirmed)
 		{
 		GenericDialog *gd;
-		gchar *text;
-
 		GtkWidget *hbox;
 
-		text = g_strdup_printf(_("Overwrite file:\n%s\n with:\n%s"), fds->dest, fds->source);
-		gd = file_util_gen_dlg(_("Overwrite file"), text, "GQview", "dlg_confirm",
+		gd = file_util_gen_dlg(_("Overwrite file"), "GQview", "dlg_confirm",
 					NULL, TRUE,
 					file_util_move_single_cancel_cb, fds);
-		g_free(text);
 
-		generic_dialog_add_stock(gd, _("Overwrite"), GTK_STOCK_OK, file_util_move_single_ok_cb, TRUE);
-		generic_dialog_image_add(gd, fds->dest, fds->source);
+		generic_dialog_add_message(gd, GTK_STOCK_DIALOG_QUESTION,
+					   _("Overwrite file?"),
+					   _("Replace existing file with new file."));
+		pref_spacer(gd->vbox, 0);
+
+		generic_dialog_add_button(gd, GTK_STOCK_OK, _("_Overwrite"), file_util_move_single_ok_cb, TRUE);
+		generic_dialog_add_image(gd, fds->dest, _("Existing file"), fds->source, _("New file"), TRUE);
 
 		/* rename option */
 
 		fds->rename = FALSE;
 		fds->rename_auto = FALSE;
 
-		hbox = gtk_hbox_new(FALSE, 5);
-		gtk_box_pack_start(GTK_BOX(gd->vbox), hbox, FALSE, FALSE, 0);
-		gtk_widget_show(hbox);
+		hbox = pref_box_new(gd->vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
 
 		fds->rename_auto_box = gtk_check_button_new_with_label(_("Auto rename"));
 		g_signal_connect(G_OBJECT(fds->rename_auto_box), "clicked",
@@ -776,9 +805,7 @@ static void file_util_move_single(FileDataSingle *fds)
 		gtk_box_pack_start(GTK_BOX(hbox), fds->rename_auto_box, FALSE, FALSE, 0);
 		gtk_widget_show(fds->rename_auto_box);
 
-		hbox = gtk_hbox_new(FALSE, 5);
-		gtk_box_pack_start(GTK_BOX(gd->vbox), hbox, FALSE, FALSE, 0);
-		gtk_widget_show(hbox);
+		hbox = pref_box_new(gd->vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
 
 		fds->rename_box = gtk_check_button_new_with_label(_("Rename"));
 		g_signal_connect(G_OBJECT(fds->rename_box), "clicked",
@@ -800,7 +827,7 @@ static void file_util_move_single(FileDataSingle *fds)
 		gint success = FALSE;
 		if (fds->copy)
 			{
-			if(copy_file(fds->source, fds->dest));
+			if (copy_file(fds->source, fds->dest))
 				{
 				success = TRUE;
 				file_maint_copied(fds->source, fds->dest);
@@ -828,7 +855,7 @@ static void file_util_move_single(FileDataSingle *fds)
 				title = _("Error moving file");
 				text = g_strdup_printf(_("Unable to move file:\n%s\nto:\n%s"), fds->source, fds->dest);
 				}
-			file_util_warning_dialog(title, text, NULL);
+			file_util_warning_dialog(title, text, GTK_STOCK_DIALOG_ERROR, NULL);
 			g_free(text);
 			}
 		}
@@ -871,11 +898,12 @@ static void file_util_move_check(FileDialog *fd)
 			{
 			file_util_warning_dialog(_("Invalid destination"),
 						 _("When operating with multiple files, please select\na folder, not a file."),
-						 NULL);
+						 GTK_STOCK_DIALOG_INFO, NULL);
 			}
 		else
 			file_util_warning_dialog(_("Invalid folder"),
-						 _("Please select an existing folder."), NULL);
+						 _("Please select an existing folder."),
+						 GTK_STOCK_DIALOG_INFO, NULL);
 		return;
 		}
 
@@ -896,9 +924,10 @@ static void real_file_util_move(const gchar *source_path, GList *source_list,
 				const gchar *dest_path, gint copy, GtkWidget *parent)
 {
 	FileDialog *fd;
+	GtkWidget *label;
 	gchar *path = NULL;
 	gint multiple;
-	gchar *text;
+	const gchar *text;
 	const gchar *title;
 	const gchar *op_text;
 	const gchar *stock_id;
@@ -925,29 +954,50 @@ static void real_file_util_move(const gchar *source_path, GList *source_list,
 	if (copy)
 		{
 		title = _("Copy - GQview");
-		op_text = _("Copy");
+		op_text = _("_Copy");
 		if (path)
-			text = g_strdup_printf(_("Copy file:\n%s\nto:"), path);
+			{
+			text = _("Copy file");
+			}
 		else
-			text = g_strdup(_("Copy multiple files to:"));
+			{
+			text = _("Copy multiple files");
+			}
 		stock_id = GTK_STOCK_COPY;
 		}
 	else
 		{
 		title = _("Move - GQview");
-		op_text = _("Move");
+		op_text = _("_Move");
 		if (path)
-			text = g_strdup_printf(_("Move file:\n%s\nto:"), path);
+			{
+			text = _("Move file");
+			}
 		else
-			text = g_strdup(_("Move multiple files to:"));
+			{
+			text = _("Move multiple files");
+			}
 		stock_id = GTK_STOCK_OK;
 		}
 
-	fd = file_util_file_dlg(title, text, "GQview", "dlg_copymove", parent,
+	fd = file_util_file_dlg(title, "GQview", "dlg_copymove", parent,
 				file_util_move_cancel_cb, NULL);
-	g_free(text);
+	generic_dialog_add_message(GENERIC_DIALOG(fd), NULL, text, NULL);
 
-	file_dialog_add_button_stock(fd, op_text, stock_id, file_util_move_cb, TRUE);
+	if (path)
+		{
+		GtkWidget *box;
+
+		box = pref_box_new(GENERIC_DIALOG(fd)->vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_SPACE);
+		pref_label_new(box, _("File name:"));
+		pref_label_new(box, filename_from_path(path));
+		}
+
+	label = pref_label_new(GENERIC_DIALOG(fd)->vbox, _("Choose the destination folder."));
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+	pref_spacer(GENERIC_DIALOG(fd)->vbox, 0);
+
+	file_dialog_add_button(fd, stock_id, op_text, file_util_move_cb, TRUE);
 
 	file_dialog_add_path_widgets(fd, NULL, dest_path, "move_copy", NULL, NULL);
 
@@ -1071,7 +1121,8 @@ static gint file_util_safe_number(gint64 free_space)
 		if (!unlink_file(fd->path) && !warned)
 			{
 			file_util_warning_dialog(_("Delete failed"),
-						 _("Unable to remove old file from trash folder"), NULL);
+						 _("Unable to remove old file from trash folder"),
+						 GTK_STOCK_DIALOG_WARNING, NULL);
 			warned = TRUE;
 			}
 		total -= fd->size;
@@ -1159,7 +1210,7 @@ static gint file_util_unlink(const gchar *path)
 		gchar *buf;
 
 		buf = g_strdup_printf(_("Unable to access or create the trash folder.\n\"%s\""), safe_delete_path);
-		gd = file_util_warning_dialog(result, buf, NULL);
+		gd = file_util_warning_dialog(result, buf, GTK_STOCK_DIALOG_WARNING, NULL);
 		g_free(buf);
 
 		button = gtk_check_button_new_with_label(_("Turn off safe delete"));
@@ -1177,20 +1228,15 @@ static gint file_util_unlink(const gchar *path)
 
 static void box_append_safe_delete_status(GenericDialog *gd)
 {
-	GtkWidget *hbox;
 	GtkWidget *label;
 	gchar *buf;
 
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(gd->vbox), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
-
 	buf = g_strdup_printf(_("Safe delete: %s"), (safe_delete_enable) ? _("on") : _("off"));
-	label = gtk_label_new(buf);
-	gtk_widget_set_sensitive(label, FALSE);
+	label = pref_label_new(gd->vbox, buf);
 	g_free(buf);
-	gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 5);
-	gtk_widget_show(label);
+
+	gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+	gtk_widget_set_sensitive(label, FALSE);
 }
 
 /*
@@ -1223,13 +1269,16 @@ static void file_util_delete_multiple_ok_cb(GenericDialog *gd, gpointer data)
 				GenericDialog *d;
 				gchar *text;
 
-				text = g_strdup_printf(_("Unable to delete file:\n %s\n Continue multiple delete operation?"), path);
-				d = file_util_gen_dlg(_("Delete failed"), text, "GQview", "dlg_confirm",
+				d = file_util_gen_dlg(_("Delete failed"), "GQview", "dlg_confirm",
 						      NULL, TRUE,
 						      file_util_delete_multiple_cancel_cb, source_list);
+
+				text = g_strdup_printf(_("Unable to delete file:\n %s\n Continue multiple delete operation?"), path);
+				generic_dialog_add_message(d, GTK_STOCK_DIALOG_WARNING, NULL, text);
 				g_free(text);
 
-				generic_dialog_add_stock(d, _("Continue"), GTK_STOCK_GO_FORWARD, file_util_delete_multiple_ok_cb, TRUE);
+				generic_dialog_add_button(d, GTK_STOCK_GO_FORWARD, _("Co_ntinue"),
+							  file_util_delete_multiple_ok_cb, TRUE);
 				gtk_widget_show(d->dialog);
 				}
 			else
@@ -1237,7 +1286,7 @@ static void file_util_delete_multiple_ok_cb(GenericDialog *gd, gpointer data)
 				gchar *text;
 				
 				text = g_strdup_printf(_("Unable to delete file:\n%s"), path);
-				file_util_warning_dialog(_("Delete failed"), text, NULL);
+				file_util_warning_dialog(_("Delete failed"), text, GTK_STOCK_DIALOG_ERROR, NULL);
 				g_free(text);
 				}
 			g_free(path);
@@ -1360,55 +1409,40 @@ static void file_util_delete_multiple(GList *source_list, GtkWidget *parent)
 		GenericDialog *gd;
 		GtkWidget *hbox;
 		GtkWidget *button;
-		GtkWidget *arrow;
 		GtkWidget *label;
 		ImageWindow *imd;
 		gchar *buf;
 
-		gd = file_util_gen_dlg(_("Delete files - GQview"), _("About to delete multiple files..."),
+		gd = file_util_gen_dlg(_("Delete files - GQview"),
 					"GQview", "dlg_confirm", parent, TRUE,
 					file_util_delete_multiple_cancel_cb, source_list);
 
-		generic_dialog_image_add(gd, NULL, NULL);
+		generic_dialog_add_message(gd, NULL, _("Delete multiple files"), NULL);
+
+		generic_dialog_add_image(gd, NULL, NULL, NULL, NULL, TRUE);
 		imd = g_object_get_data(G_OBJECT(gd->dialog), "img_image");
 		image_set_button_func(imd, file_util_delete_multiple_review_button_cb, gd);
 		image_set_scroll_func(imd, file_util_delete_multiple_review_scroll_cb, gd);
 
-		hbox = gtk_hbox_new(FALSE, 5);
-		gtk_box_pack_start(GTK_BOX(gd->vbox), hbox, FALSE, FALSE, 0);
-		gtk_widget_show(hbox);
+		hbox = pref_box_new(gd->vbox, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_BUTTON_GAP);
 
-		button = gtk_button_new();
-		arrow = gtk_image_new_from_stock(GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON);
-		gtk_container_add(GTK_CONTAINER(button), arrow);
-		gtk_widget_show(arrow);
-		g_signal_connect(G_OBJECT(button), "clicked",
-				 G_CALLBACK(file_util_delete_multiple_review_back), gd);
+		button = pref_button_new(hbox, GTK_STOCK_GO_BACK, NULL, TRUE,
+					 G_CALLBACK(file_util_delete_multiple_review_back), gd);
 		gtk_widget_set_sensitive(button, FALSE);
-		gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-		gtk_widget_show(button);
 		g_object_set_data(G_OBJECT(gd->dialog), "button_back", button);
 
-		button = gtk_button_new();
-		arrow = gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON);
-		gtk_container_add(GTK_CONTAINER(button), arrow);
-		gtk_widget_show(arrow);
-		g_signal_connect(G_OBJECT(button), "clicked",
-				 G_CALLBACK(file_util_delete_multiple_review_next), gd);
-		gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
-		gtk_widget_show(button);
+		button = pref_button_new(hbox, GTK_STOCK_GO_FORWARD, NULL, TRUE,
+					 G_CALLBACK(file_util_delete_multiple_review_next), gd);
 		g_object_set_data(G_OBJECT(gd->dialog), "button_next", button);
 
 		buf = g_strdup_printf(_("Review %d files"), g_list_length(source_list) );
-		label = gtk_label_new(buf);
+		label = pref_label_new(hbox, buf);
 		g_free(buf);
-		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-		gtk_widget_show(label);
 		g_object_set_data(G_OBJECT(gd->dialog), "button_label", label);
 
 		box_append_safe_delete_status(gd);
 
-		generic_dialog_add_stock(gd, _("Delete"), GTK_STOCK_DELETE, file_util_delete_multiple_ok_cb, TRUE);
+		generic_dialog_add_button(gd, GTK_STOCK_DELETE, NULL, file_util_delete_multiple_ok_cb, TRUE);
 
 		gtk_widget_show(gd->dialog);
 		}
@@ -1425,7 +1459,7 @@ static void file_util_delete_ok_cb(GenericDialog *gd, gpointer data)
 	if (!file_util_unlink(path))
 		{
 		gchar *text = g_strdup_printf(_("Unable to delete file:\n%s"), path);
-		file_util_warning_dialog(_("File deletion failed"), text, NULL);
+		file_util_warning_dialog(_("File deletion failed"), text, GTK_STOCK_DIALOG_ERROR, NULL);
 		g_free(text);
 		}
 	else
@@ -1454,19 +1488,31 @@ static void file_util_delete_single(const gchar *path, GtkWidget *parent)
 	else
 		{
 		GenericDialog *gd;
-		gchar *text;
+		GtkWidget *table;
+		gchar *base;
 
-		text = g_strdup_printf(_("About to delete the file:\n %s"), buf);
-		gd = file_util_gen_dlg(_("Delete file - GQview"), text, "GQview", "dlg_confirm",
+		gd = file_util_gen_dlg(_("Delete file - GQview"), "GQview", "dlg_confirm",
 					parent, TRUE,
 					file_util_delete_cancel_cb, buf);
-		g_free(text);
 
-		generic_dialog_image_add(gd, path, NULL);
+		generic_dialog_add_message(gd, NULL, _("Delete file?"), NULL);
+
+		table = pref_table_new(gd->vbox, 2, 2, FALSE, FALSE);
+
+		pref_table_label(table, 0, 0, _("File name:"), 1.0);
+		pref_table_label(table, 1, 0, filename_from_path(path), 0.0);
+
+		pref_table_label(table, 0, 1, _("Location:"), 1.0);
+
+		base = remove_level_from_path(path);
+		pref_table_label(table, 1, 1, base, 0.0);
+		g_free(base);
+
+		generic_dialog_add_image(gd, path, NULL, NULL, NULL, FALSE);
 
 		box_append_safe_delete_status(gd);
 
-		generic_dialog_add_stock(gd, _("Delete"), GTK_STOCK_DELETE, file_util_delete_ok_cb, TRUE);
+		generic_dialog_add_button(gd, GTK_STOCK_DELETE, NULL, file_util_delete_ok_cb, TRUE);
 
 		gtk_widget_show(gd->dialog);
 		}
@@ -1590,16 +1636,18 @@ static void file_util_rename_multiple(RenameDataMult *rd)
 	if (isfile(fd->dest_path) && !fd->type)
 		{
 		GenericDialog *gd;
-		gchar *text;
 
-		text = g_strdup_printf(_("Overwrite file:\n%s\nby renaming:\n%s"), fd->dest_path, fd->source_path);
-		gd = file_util_gen_dlg(_("Overwrite file"), text, "GQview", "dlg_confirm",
+		gd = file_util_gen_dlg(_("Overwrite file"), "GQview", "dlg_confirm",
 					NULL, TRUE,
 					file_util_rename_multiple_cancel_cb, rd);
-		g_free(text);
 
-		generic_dialog_add_stock(gd, _("Overwrite"), GTK_STOCK_OK, file_util_rename_multiple_ok_cb, TRUE);
-		generic_dialog_image_add(gd, fd->dest_path, fd->source_path);
+		generic_dialog_add_message(gd, GTK_STOCK_DIALOG_QUESTION,
+					   _("Overwrite file?"),
+					   _("Replace existing file by renaming new file."));
+		pref_spacer(gd->vbox, 0);
+
+		generic_dialog_add_button(gd, GTK_STOCK_OK, _("_Overwrite"), file_util_rename_multiple_ok_cb, TRUE);
+		generic_dialog_add_image(gd, fd->dest_path, _("Existing file"), fd->source_path, _("New file"), TRUE);
 
 		gtk_widget_hide(GENERIC_DIALOG(fd)->dialog);
 
@@ -1613,7 +1661,7 @@ static void file_util_rename_multiple(RenameDataMult *rd)
 			gchar *text = g_strdup_printf(_("Unable to rename file:\n%s\n to:\n%s"),
 						      filename_from_path(fd->source_path),
 						      filename_from_path(fd->dest_path));
-			file_util_warning_dialog(_("Error renaming file"), text, NULL);
+			file_util_warning_dialog(_("Error renaming file"), text, GTK_STOCK_DIALOG_ERROR, NULL);
 			g_free(text);
 			}
 		else
@@ -1695,9 +1743,9 @@ static void file_util_rename_multiple_auto(RenameDataMult *rd)
 
 	if (!success)
 		{
-		warning_dialog(_("Auto rename"),
+		file_util_warning_dialog(_("Auto rename"),
 			       _("Can not auto rename with the selected\nnumber set, one or more files exist that\nmatch the resulting name list.\n"),
-			       NULL);
+			       GTK_STOCK_DIALOG_WARNING, NULL);
 		return;
 		}
 
@@ -1759,7 +1807,7 @@ static void file_util_rename_multiple_auto(RenameDataMult *rd)
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(rd->auto_spin_start), (float)n);
 
 		buf = g_strdup_printf(_("Failed to rename\n%s\nThe number was %d."), filename_from_path(rd->fd->source_path), n);
-		warning_dialog(_("Auto rename"), buf, NULL);
+		file_util_warning_dialog(_("Auto rename"), buf, GTK_STOCK_DIALOG_ERROR, NULL);
 		g_free(buf);
 
 		return;
@@ -1882,7 +1930,7 @@ static void file_util_rename_multiple_preview_order_cb(GtkTreeModel *treemodel,
 
 	if (rd->rename_auto && rd->update_idle_id == -1)
 		{
-		rd->update_idle_id = gtk_idle_add(file_util_rename_multiple_idle_cb, rd);
+		rd->update_idle_id = g_idle_add(file_util_rename_multiple_idle_cb, rd);
 		}
 }
 
@@ -1892,7 +1940,7 @@ static void file_util_rename_multiple_preview_entry_cb(GtkWidget *entry, gpointe
 	file_util_rename_multiple_preview_update(rd);
 }
 
-static void file_util_rename_multiple_preview_adj_cb(GtkAdjustment *adj, gpointer data)
+static void file_util_rename_multiple_preview_adj_cb(GtkWidget *spin, gpointer data)
 {
 	RenameDataMult *rd = data;
 	file_util_rename_multiple_preview_update(rd);
@@ -1921,22 +1969,6 @@ static void file_util_rename_mulitple_auto_toggle(GtkWidget *widget, gpointer da
 	gtk_tree_view_column_set_visible(column, rd->rename_auto);
 }
 
-static GtkWidget *furm_simple_label(GtkWidget *box, const gchar *text)
-{
-	GtkWidget *hbox;
-	GtkWidget *label;
-
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(box), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
-
-	label = gtk_label_new(text);
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
-	gtk_widget_show(label);
-
-	return label;
-}
-
 static GtkWidget *furm_simple_vlabel(GtkWidget *box, const gchar *text, gint expand)
 {
 	GtkWidget *vbox;
@@ -1974,7 +2006,7 @@ static void file_util_rename_multiple_destroy_cb(GtkWidget *widget, gpointer dat
 {
 	RenameDataMult *rd = data;
 
-	if (rd->update_idle_id != -1) gtk_idle_remove(rd->update_idle_id);
+	if (rd->update_idle_id != -1) g_source_remove(rd->update_idle_id);
 
 	g_free(rd);
 }
@@ -1990,17 +2022,17 @@ static void file_util_rename_multiple_do(GList *source_list, GtkWidget *parent)
 	GtkWidget *hbox;
 	GtkWidget *vbox;
 	GtkWidget *box2;
-	GtkWidget *label;
-	GtkObject *adj;
+	GtkWidget *table;
 	GtkWidget *combo;
 	GList *work;
 
 	rd = g_new0(RenameDataMult, 1);
 
-	rd->fd = file_util_file_dlg(_("Rename - GQview"), _("Rename multiple files:"),
+	rd->fd = file_util_file_dlg(_("Rename - GQview"),
 				    "GQview", "dlg_rename", parent,
 				    file_util_rename_multiple_close_cb, rd);
-	file_dialog_add_button_stock(rd->fd, _("Rename"), GTK_STOCK_OK, file_util_rename_multiple_cb, TRUE);
+	generic_dialog_add_message(GENERIC_DIALOG(rd->fd), NULL, _("Rename multiple files"), NULL);
+	file_dialog_add_button(rd->fd, GTK_STOCK_OK, _("_Rename"), file_util_rename_multiple_cb, TRUE);
 
 	rd->fd->source_path = g_strdup(source_list->data);
 	rd->fd->dest_path = NULL;
@@ -2024,6 +2056,9 @@ static void file_util_rename_multiple_do(GList *source_list, GtkWidget *parent)
 	rd->listview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(rd->listview), TRUE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(rd->listview), FALSE);
+
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(rd->listview));
 	gtk_tree_selection_set_mode(GTK_TREE_SELECTION(selection), GTK_SELECTION_SINGLE);
 	gtk_tree_selection_set_select_function(selection, file_util_rename_multiple_select_cb, rd, NULL);
@@ -2069,28 +2104,26 @@ static void file_util_rename_multiple_do(GList *source_list, GtkWidget *parent)
 	gtk_box_pack_end(GTK_BOX(hbox), rd->button_auto, FALSE, FALSE, 0);
 	gtk_widget_show(rd->button_auto);
 
-	rd->rename_box = gtk_vbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), rd->rename_box, FALSE, FALSE, 0);
-	gtk_widget_show(rd->rename_box);
+	rd->rename_box = pref_box_new(vbox, FALSE, GTK_ORIENTATION_VERTICAL, 0);
+	table = pref_table_new(rd->rename_box, 2, 2, FALSE, FALSE);
 
-	furm_simple_label(rd->rename_box, _("Rename:"));
-	rd->rename_label = furm_simple_label(rd->rename_box, filename_from_path(rd->fd->source_path));
-	furm_simple_label(rd->rename_box, _("to:"));
+	pref_table_label(table, 0, 0, _("Original name:"), 1.0);
+	rd->rename_label = pref_table_label(table, 1, 0, filename_from_path(rd->fd->source_path), 0.0);
+
+	pref_table_label(table, 0, 1, _("New name:"), 1.0);
 
 	rd->rename_entry = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(rd->rename_entry), filename_from_path(rd->fd->source_path));
-	gtk_box_pack_start(GTK_BOX(rd->rename_box), rd->rename_entry, FALSE, FALSE, 0);
+	gtk_table_attach(GTK_TABLE(table), rd->rename_entry, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, FALSE, 0, 0);
 	generic_dialog_attach_default(GENERIC_DIALOG(rd->fd), rd->rename_entry);
 	gtk_widget_grab_focus(rd->rename_entry);
 	gtk_widget_show(rd->rename_entry);
 
-	rd->auto_box = gtk_vbox_new(FALSE, 0);
+	rd->auto_box = gtk_vbox_new(FALSE, PREF_PAD_GAP);
 	gtk_box_pack_start(GTK_BOX(vbox), rd->auto_box, FALSE, FALSE, 0);
 	/* do not show it here */
 
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(rd->auto_box), hbox, FALSE, FALSE, 0);
-	gtk_widget_show(hbox);
+	hbox = pref_box_new(rd->auto_box, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_GAP);
 
 	box2 = furm_simple_vlabel(hbox, _("Begin text"), TRUE);
 
@@ -2102,12 +2135,9 @@ static void file_util_rename_multiple_do(GList *source_list, GtkWidget *parent)
 	
 	box2 = furm_simple_vlabel(hbox, _("Start #"), FALSE);
 
-	adj = gtk_adjustment_new(0.0, 0.0, 1000000.0, 1.0, 1.0, 10.0);
-	rd->auto_spin_start = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1.0, 0);
-	g_signal_connect(G_OBJECT(adj), "value_changed",
-			 G_CALLBACK(file_util_rename_multiple_preview_adj_cb), rd);
-	gtk_box_pack_start(GTK_BOX(box2), rd->auto_spin_start, FALSE, FALSE, 0);
-	gtk_widget_show(rd->auto_spin_start);
+	rd->auto_spin_start = pref_spin_new(box2, NULL, NULL,
+					    0.0, 1000000.0, 1.0, 0, 0.0,
+					    G_CALLBACK(file_util_rename_multiple_preview_adj_cb), rd);
 
 	box2 = furm_simple_vlabel(hbox, _("End text"), TRUE);
 
@@ -2117,20 +2147,9 @@ static void file_util_rename_multiple_do(GList *source_list, GtkWidget *parent)
 	gtk_box_pack_start(GTK_BOX(box2), combo, TRUE, TRUE, 0);
 	gtk_widget_show(combo);
 
-	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(rd->auto_box), hbox, FALSE, FALSE, 5);
-	gtk_widget_show(hbox);
-
-	label = gtk_label_new(_("Padding:"));
-	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
-	gtk_widget_show(label);
-
-	adj = gtk_adjustment_new(1.0, 1.0, 8.0, 1.0, 1.0, 1.0);
-	rd->auto_spin_pad = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1.0, 0);
-	g_signal_connect(G_OBJECT(adj), "value_changed",
-			 G_CALLBACK(file_util_rename_multiple_preview_adj_cb), rd);
-	gtk_box_pack_start(GTK_BOX(hbox), rd->auto_spin_pad, FALSE, FALSE, 0);
-	gtk_widget_show(rd->auto_spin_pad);
+	rd->auto_spin_pad = pref_spin_new(rd->auto_box, _("Padding:"), NULL,
+					  1.0, 8.0, 1.0, 0, 1.0,
+					  G_CALLBACK(file_util_rename_multiple_preview_adj_cb), rd);
 
 	image_change_path(rd->imd, rd->fd->source_path, 0.0);
 
@@ -2164,16 +2183,18 @@ static void file_util_rename_single(FileDataSingle *fds)
 	if (isfile(fds->dest) && !fds->confirmed)
 		{
 		GenericDialog *gd;
-		gchar *text;
 
-		text = g_strdup_printf(_("Overwrite file:\n%s\nby renaming:\n%s"), fds->dest, fds->source);
-		gd = file_util_gen_dlg(_("Overwrite file"), text, "GQview", "dlg_confirm",
+		gd = file_util_gen_dlg(_("Overwrite file"), "GQview", "dlg_confirm",
 					NULL, TRUE,
 					file_util_rename_single_cancel_cb, fds);
-		g_free(text);
 
-		generic_dialog_add_stock(gd, _("Overwrite"), GTK_STOCK_OK, file_util_rename_single_ok_cb, TRUE);
-		generic_dialog_image_add(gd, fds->dest, fds->source);
+		generic_dialog_add_message(gd, GTK_STOCK_DIALOG_QUESTION,
+					   _("Overwrite file?"),
+					   _("Replace existing file by renaming new file."));
+		pref_spacer(gd->vbox, 0);
+
+		generic_dialog_add_button(gd, GTK_STOCK_OK, _("_Overwrite"), file_util_rename_single_ok_cb, TRUE);
+		generic_dialog_add_image(gd, fds->dest, _("Existing file"), fds->source, _("New file"), TRUE);
 
 		gtk_widget_show(gd->dialog);
 
@@ -2184,7 +2205,7 @@ static void file_util_rename_single(FileDataSingle *fds)
 		if (!rename_file(fds->source, fds->dest))
 			{
 			gchar *text = g_strdup_printf(_("Unable to rename file:\n%s\nto:\n%s"), filename_from_path(fds->source), filename_from_path(fds->dest));
-			file_util_warning_dialog(_("Error renaming file"), text, NULL);
+			file_util_warning_dialog(_("Error renaming file"), text, GTK_STOCK_DIALOG_ERROR, NULL);
 			g_free(text);
 			}
 		else
@@ -2223,19 +2244,28 @@ static void file_util_rename_single_close_cb(FileDialog *fd, gpointer data)
 static void file_util_rename_single_do(const gchar *source_path, GtkWidget *parent)
 {
 	FileDialog *fd;
+	GtkWidget *table;
 
-	fd = file_util_file_dlg(_("Rename - GQview"), _("Rename file:"), "GQview", "dlg_rename", parent,
+	fd = file_util_file_dlg(_("Rename - GQview"), "GQview", "dlg_rename", parent,
 			     file_util_rename_single_close_cb, NULL);
 
-	generic_dialog_image_add(GENERIC_DIALOG(fd), source_path, NULL);
+	generic_dialog_add_message(GENERIC_DIALOG(fd), NULL, _("Rename file"), NULL);
+	generic_dialog_add_image(GENERIC_DIALOG(fd), source_path, NULL, NULL, NULL, FALSE);
 
-	file_dialog_add_button_stock(fd, _("Rename"), GTK_STOCK_OK, file_util_rename_single_cb, TRUE);
+	file_dialog_add_button(fd, GTK_STOCK_OK, _("_Rename"), file_util_rename_single_cb, TRUE);
 
 	fd->source_path = g_strdup(source_path);
 	fd->dest_path = remove_level_from_path(source_path);
 
+	table = pref_table_new(GENERIC_DIALOG(fd)->vbox, 2, 2, FALSE, FALSE);
+
+	pref_table_label(table, 0, 0, _("Original name:"), 1.0);
+	pref_table_label(table, 1, 0, filename_from_path(fd->source_path), 0.0);
+
+	pref_table_label(table, 0, 1, _("New name:"), 1.0);
+
 	fd->entry = gtk_entry_new();
-	gtk_box_pack_start(GTK_BOX(GENERIC_DIALOG(fd)->vbox), fd->entry, FALSE, FALSE, 0);
+	gtk_table_attach(GTK_TABLE(table), fd->entry, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, FALSE, 0, 0);
 	gtk_entry_set_text(GTK_ENTRY(fd->entry), filename_from_path(fd->source_path));
 	gtk_editable_select_region(GTK_EDITABLE(fd->entry), 0, strlen(gtk_entry_get_text(GTK_ENTRY(fd->entry))));
 	generic_dialog_attach_default(GENERIC_DIALOG(fd), fd->entry);
@@ -2279,13 +2309,13 @@ static void file_util_create_dir_do(const gchar *base, const gchar *name)
 	if (isdir(path))
 		{
 		gchar *text = g_strdup_printf(_("The folder:\n%s\nalready exists."), name);
-		file_util_warning_dialog(_("Folder exists"), text, NULL);
+		file_util_warning_dialog(_("Folder exists"), text, GTK_STOCK_DIALOG_INFO, NULL);
 		g_free(text);
 		}
 	else if (isname(path))
 		{
 		gchar *text = g_strdup_printf(_("The path:\n%s\nalready exists as a file."), name);
-		file_util_warning_dialog(_("Could not create folder"), text, NULL);
+		file_util_warning_dialog(_("Could not create folder"), text, GTK_STOCK_DIALOG_INFO, NULL);
 		g_free(text);
 		}
 	else
@@ -2293,7 +2323,7 @@ static void file_util_create_dir_do(const gchar *base, const gchar *name)
 		if (!mkdir_utf8(path, 0755))
 			{
 			gchar *text = g_strdup_printf(_("Unable to create folder:\n%s"), name);
-			file_util_warning_dialog(_("Error creating folder"), text, NULL);
+			file_util_warning_dialog(_("Error creating folder"), text, GTK_STOCK_DIALOG_ERROR, NULL);
 			g_free(text);
 			}
 		}
@@ -2336,12 +2366,14 @@ void file_util_create_dir(const gchar *path, GtkWidget *parent)
 
 	if (!isdir(path)) return;
 
-	text = g_strdup_printf(_("Create folder in:\n%s\nnamed:"), path);
-	fd = file_util_file_dlg(_("New folder - GQview"), text, "GQview", "dlg_newdir", parent,
+	fd = file_util_file_dlg(_("New folder - GQview"), "GQview", "dlg_newdir", parent,
 			     file_util_create_dir_close_cb, NULL);
+
+	text = g_strdup_printf(_("Create folder in:\n%s\nnamed:"), path);
+	generic_dialog_add_message(GENERIC_DIALOG(fd), NULL, NULL, text);
 	g_free(text);
 
-	file_dialog_add_button_stock(fd, _("Create"), GTK_STOCK_OK, file_util_create_dir_cb, TRUE);
+	file_dialog_add_button(fd, GTK_STOCK_OK, NULL, file_util_create_dir_cb, TRUE);
 
 	fd->dest_path = g_strdup(path);
 
