@@ -493,7 +493,7 @@ static void tip_show(ViewFileIcon *vfi)
 	gdk_window_get_pointer(NULL, &x, &y, NULL);
 
 	if (!GTK_WIDGET_REALIZED(vfi->tip_window)) gtk_widget_realize(vfi->tip_window);
-	gdk_window_move(vfi->tip_window->window, x + 16, y + 16);
+	gtk_window_move(GTK_WINDOW(vfi->tip_window), x + 16, y + 16);
 	gtk_widget_show(vfi->tip_window);
 }
 
@@ -528,13 +528,13 @@ static void tip_schedule(ViewFileIcon *vfi)
 
 	if (vfi->tip_delay_id != -1)
 		{
-		gtk_timeout_remove(vfi->tip_delay_id);
+		g_source_remove(vfi->tip_delay_id);
 		vfi->tip_delay_id = -1;
 		}
 
 	if (!vfi->show_text)
 		{
-		vfi->tip_delay_id = gtk_timeout_add(VFICON_TIP_DELAY, tip_schedule_cb, vfi);
+		vfi->tip_delay_id = g_timeout_add(VFICON_TIP_DELAY, tip_schedule_cb, vfi);
 		}
 }
 
@@ -542,7 +542,7 @@ static void tip_unschedule(ViewFileIcon *vfi)
 {
 	tip_hide(vfi);
 
-	if (vfi->tip_delay_id != -1) gtk_timeout_remove(vfi->tip_delay_id);
+	if (vfi->tip_delay_id != -1) g_source_remove(vfi->tip_delay_id);
 	vfi->tip_delay_id = -1;
 }
 
@@ -553,7 +553,7 @@ static void tip_update(ViewFileIcon *vfi, FileData *fd)
 		gint x, y;
 
 		gdk_window_get_pointer(NULL, &x, &y, NULL);
-		gdk_window_move(vfi->tip_window->window, x + 16, y + 16);
+		gtk_window_move(GTK_WINDOW(vfi->tip_window), x + 16, y + 16);
 
 		if (fd != vfi->tip_fd)
 			{
@@ -1731,7 +1731,7 @@ void vficon_sort_set(ViewFileIcon *vfi, SortType type, gint ascend)
 
 static gint vficon_thumb_next(ViewFileIcon *vfi);
 
-static void vficon_thumb_status(ViewFileIcon *vfi, gfloat val, const gchar *text)
+static void vficon_thumb_status(ViewFileIcon *vfi, gdouble val, const gchar *text)
 {
 	if (vfi->func_thumb_status)
 		{
@@ -1769,7 +1769,7 @@ static void vficon_thumb_do(ViewFileIcon *vfi, ThumbLoader *tl, FileData *fd)
 	vficon_set_thumb(vfi, fd, pixbuf);
 	g_object_unref(pixbuf);
 
-	vficon_thumb_status(vfi, (gfloat)(vfi->thumbs_count) / g_list_length(vfi->list), _("Loading thumbs..."));
+	vficon_thumb_status(vfi, (gdouble)(vfi->thumbs_count) / g_list_length(vfi->list), _("Loading thumbs..."));
 }
 
 static void vficon_thumb_error_cb(ThumbLoader *tl, gpointer data)
@@ -1861,10 +1861,14 @@ static gint vficon_thumb_next(ViewFileIcon *vfi)
 
 	thumb_loader_free(vfi->thumbs_loader);
 
-	vfi->thumbs_loader = thumb_loader_new(fd->path, thumb_max_width, thumb_max_height);
-	thumb_loader_set_error_func(vfi->thumbs_loader, vficon_thumb_error_cb, vfi);
+	vfi->thumbs_loader = thumb_loader_new(thumb_max_width, thumb_max_height);
+	thumb_loader_set_callbacks(vfi->thumbs_loader,
+				   vficon_thumb_done_cb,
+				   vficon_thumb_error_cb,
+				   NULL,
+				   vfi);
 
-	if (!thumb_loader_start(vfi->thumbs_loader, vficon_thumb_done_cb, vfi))
+	if (!thumb_loader_start(vfi->thumbs_loader, fd->path))
 		{
 		/* set icon to unknown, continue */
 		if (debug) printf("thumb loader start failed %s\n", vfi->thumbs_loader->path);
@@ -2251,6 +2255,7 @@ ViewFileIcon *vficon_new(const gchar *path)
 	gtk_tree_selection_set_mode(GTK_TREE_SELECTION(selection), GTK_SELECTION_NONE);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(vfi->listview), FALSE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(vfi->listview), FALSE);
 
 	for (i = 0; i < VFICON_MAX_COLUMNS; i++)
 		{
@@ -2299,7 +2304,7 @@ void vficon_set_status_func(ViewFileIcon *vfi,
 }
 
 void vficon_set_thumb_status_func(ViewFileIcon *vfi,
-				  void (*func)(ViewFileIcon *vfi, gfloat val, const gchar *text, gpointer data),
+				  void (*func)(ViewFileIcon *vfi, gdouble val, const gchar *text, gpointer data),
 				  gpointer data)
 {
 	vfi->func_thumb_status = func;
