@@ -445,19 +445,19 @@ static gint vflist_row_rename_cb(TreeEditData *td, const gchar *old, const gchar
 	if (strchr(new, '/') != NULL)
 		{
 		gchar *text = g_strdup_printf(_("Invalid file name:\n%s"), new);
-		file_util_warning_dialog(_("Error renaming file"), text, vfl->listview);
+		file_util_warning_dialog(_("Error renaming file"), text, GTK_STOCK_DIALOG_ERROR, vfl->listview);
 		g_free(text);
 		}
 	else if (isfile(new_path))
 		{
 		gchar *text = g_strdup_printf(_("A file with name %s already exists."), new);
-		file_util_warning_dialog(_("Error renaming file"), text, vfl->listview);
+		file_util_warning_dialog(_("Error renaming file"), text, GTK_STOCK_DIALOG_ERROR, vfl->listview);
 		g_free(text);
 		}
 	else if (!rename_file(old_path, new_path))
 		{
 		gchar *text = g_strdup_printf(_("Unable to rename file:\n%s\nto:\n%s"), old, new);
-		file_util_warning_dialog(_("Error renaming file"), text, vfl->listview);
+		file_util_warning_dialog(_("Error renaming file"), text, GTK_STOCK_DIALOG_ERROR, vfl->listview);
 		g_free(text);
 		}
 	else
@@ -650,6 +650,7 @@ static void vflist_select_image(ViewFileList *vfl, gint row)
 	const gchar *read_ahead_path = NULL;
 
 	path = vflist_index_get_path(vfl, row);
+	if (!path) return;
 
 	if (path && enable_read_ahead)
 		{
@@ -697,7 +698,7 @@ static gint vflist_select_idle_cb(gpointer data)
 
 static void vflist_select_idle_cancel(ViewFileList *vfl)
 {
-	if (vfl->select_idle_id != -1) gtk_idle_remove(vfl->select_idle_id);
+	if (vfl->select_idle_id != -1) g_source_remove(vfl->select_idle_id);
 	vfl->select_idle_id = -1;
 }
 
@@ -720,7 +721,7 @@ static gboolean vflist_select_cb(GtkTreeSelection *selection, GtkTreeModel *stor
 	if (vfl->layout &&
 	    vfl->select_idle_id == -1)
 		{
-		vfl->select_idle_id = gtk_idle_add(vflist_select_idle_cb, vfl);
+		vfl->select_idle_id = g_idle_add(vflist_select_idle_cb, vfl);
 		}
 
 	return TRUE;
@@ -773,7 +774,7 @@ void vflist_sort_set(ViewFileList *vfl, SortType type, gint ascend)
 
 static gint vflist_thumb_next(ViewFileList *vfl);
 
-static void vflist_thumb_status(ViewFileList *vfl, gfloat val, const gchar *text)
+static void vflist_thumb_status(ViewFileList *vfl, gdouble val, const gchar *text)
 {
 	if (vfl->func_thumb_status)
 		{
@@ -808,12 +809,11 @@ static void vflist_thumb_do(ViewFileList *vfl, ThumbLoader *tl, FileData *fd)
 
 	if (fd->pixbuf) g_object_unref(fd->pixbuf);
 	fd->pixbuf = thumb_loader_get_pixbuf(tl, TRUE);
-	if (fd->pixbuf) g_object_ref(fd->pixbuf);
 
 	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(vfl->listview)));
 	gtk_list_store_set(store, &iter, FILE_COLUMN_THUMB, fd->pixbuf, -1);
 
-	vflist_thumb_status(vfl, (gfloat)(vfl->thumbs_count) / g_list_length(vfl->list), _("Loading thumbs..."));
+	vflist_thumb_status(vfl, (gdouble)(vfl->thumbs_count) / g_list_length(vfl->list), _("Loading thumbs..."));
 }
 
 static void vflist_thumb_error_cb(ThumbLoader *tl, gpointer data)
@@ -894,10 +894,14 @@ static gint vflist_thumb_next(ViewFileList *vfl)
 
 	thumb_loader_free(vfl->thumbs_loader);
 
-	vfl->thumbs_loader = thumb_loader_new(fd->path, thumb_max_width, thumb_max_height);
-	thumb_loader_set_error_func(vfl->thumbs_loader, vflist_thumb_error_cb, vfl);
+	vfl->thumbs_loader = thumb_loader_new(thumb_max_width, thumb_max_height);
+	thumb_loader_set_callbacks(vfl->thumbs_loader,
+				   vflist_thumb_done_cb,
+				   vflist_thumb_error_cb,
+				   NULL,
+				   vfl);
 
-	if (!thumb_loader_start(vfl->thumbs_loader, vflist_thumb_done_cb, vfl))
+	if (!thumb_loader_start(vfl->thumbs_loader, fd->path))
 		{
 		/* set icon to unknown, continue */
 		if (debug) printf("thumb loader start failed %s\n", vfl->thumbs_loader->path);
@@ -1325,6 +1329,8 @@ static void vflist_populate_view(ViewFileList *vfl)
 
 				gtk_list_store_set(store, &iter, FILE_COLUMN_THUMB, (thumbs) ? fd->pixbuf : NULL, -1);
 
+				if (vfl->select_fd == old_fd) vfl->select_fd = fd;
+
 				if (valid) valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter);
 
 				done = TRUE;
@@ -1543,6 +1549,7 @@ ViewFileList *vflist_new(const gchar *path, gint thumbs)
 	gtk_tree_selection_set_select_function(selection, vflist_select_cb, vfl, NULL);
 
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(vfl->listview), FALSE);
+	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(vfl->listview), FALSE);
 
 	vflist_listview_add_column(vfl, FILE_COLUMN_THUMB, "", TRUE, FALSE);
 	vflist_listview_add_column(vfl, FILE_COLUMN_NAME, _("Name"), FALSE, FALSE);
@@ -1575,7 +1582,7 @@ void vflist_set_status_func(ViewFileList *vfl,
 }
 
 void vflist_set_thumb_status_func(ViewFileList *vfl,
-				  void (*func)(ViewFileList *vfl, gfloat val, const gchar *text, gpointer data),
+				  void (*func)(ViewFileList *vfl, gdouble val, const gchar *text, gpointer data),
 				  gpointer data)
 {
 	vfl->func_thumb_status = func;
